# Copyright (C) 2006  Novell, Inc.  www.novell.com/linux
#
# This library is distributed under the terms of the Ruby license.
# You can freely distribute/modify this library.
#
# Author: Nathan Younger <nyounger@novell.com>
#
module CASA
  # CASA error codes and error code lookup Hash
  module Errors
    NSSCS_SUCCESS				   = 0
    NSSCS_E_OBJECT_NOT_FOUND	   = -800
    NSSCS_E_NICI_FAILURE		   = -801
    NSSCS_E_INVALID_SECRET_ID 	   = -802
    NSSCS_E_SYSTEM_FAILURE		   = -803
    NSSCS_E_ACCESS_DENIED  		   = -804
    NSSCS_E_NDS_INTERNAL_FAILURE   = -805
    NSSCS_E_SECRET_UNINITIALIZED   = -806
    NSSCS_E_BUFFER_LEN			   = -807
    NSSCS_E_INCOMPATIBLE_VERSION   = -808
    NSSCS_E_CORRUPTED_STORE		   = -809
    NSSCS_E_SECRET_ID_EISTS		   = -810
    NSSCS_E_NDS_PWORD_CHANGED	   = -811
    NSSCS_E_INVALID_TARGET_OBJECT  = -812
    NSSCS_E_STORE_NOT_FOUND		   = -813
    NSSCS_E_SERVICE_NOT_FOUND	   = -814
    NSSCS_E_SECRET_ID_TOO_LONG	   = -815
    NSSCS_E_ENUM_BUFF_TOO_SHORT	   = -816
    NSSCS_E_NOT_AUTHENTICATED	   = -817
    NSSCS_E_NOT_SUPPORTED	       = -818
    NSSCS_E_NDS_PWORD_INVALID	   = -819
    NSSCS_E_NICI_OUTOF_SYNC		   = -820
    NSSCS_E_SERVICE_NOT_SUPPORTED  = -821
    NSSCS_E_TOKEN_NOT_SUPPORTED	   = -822
    NSSCS_E_UNICODE_OP_FAILURE	   = -823
    NSSCS_E_TRANSPORT_FAILURE	   = -824
    NSSCS_E_CRYPTO_OP_FAILURE	   = -825
    NSSCS_E_SERVER_CONN_FAILURE	   = -826
    NSSCS_E_CONN_ACCESS_FAILURE	   = -827
    NSSCS_E_ENUM_BUFF_TOO_LONG	   = -828
    NSSCS_E_SECRET_BUFF_TOO_LONG   = -829
    NSSCS_E_SECRET_ID_TOO_SHORT	   = -830
    NSSCS_E_CORRUPTED_PACKET_DATA  = -831
    NSSCS_E_EP_ACCESS_DENIED	   = -832
    NSSCS_E_SCHEMA_NOT_ETENDED	   = -833
    NSSCS_E_ATTR_NOT_FOUND		   = -834
    NSSCS_E_MIGRATION_NEEDED	   = -835
    NSSCS_E_MP_PWORD_INVALID	   = -836
    NSSCS_E_MP_PWORD_NOT_SET	   = -837
    NSSCS_E_MP_PWORD_NOT_ALLOWED   = -838
    NSSCS_E_WRONG_REPLICA_TYPE     = -839
    NSSCS_E_ATTR_VAL_NOT_FOUND	   = -840
    NSSCS_E_INVALID_PARAM		   = -841
    NSSCS_E_NEED_SECURE_CHANNEL	   = -842
    NSSCS_E_CONFIG_NOT_SUPPORTED   = -843
    NSSCS_E_STORE_NOT_LOCKED	   = -844
    NSSCS_E_TIME_OUT_OF_SYNC	   = -845
    NSSCS_E_VERSION_MISMATCH	   = -846
    NSSCS_E_SECRET_BUFF_TOO_SHORT  = -847
    NSSCS_E_SH_SECRET_FAILURE	   = -848
    NSSCS_E_PARSER_FAILURE		   = -849
    NSSCS_E_UTF8_OP_FAILURE		   = -850
    NSSCS_E_CT_LESS_CN_NOT_UNIQUE  = -851
    NSSCS_E_UNSUPPORTED_BIND_CRED  = -852
    NSSCS_E_CERTIFICATE_NOT_FOUND  = -853
    NSSCS_E_CANT_OPEN_CLIENT_CACHE = -854
    NSSCS_E_WRONG_SH_SEC_TYPE	   = -855
    NSSCS_E_STORE_IS_LOCKED		   = -856
    
    NSSCS_E_NOT_IMPLEMENTED		   = -888
    NSSCS_E_BETA_EPIRED			   = -899
    	
    # Hash.  On initialize creates a hash table of CASA error codes to 
    # short discription mappings.
    class ErrorTranslator < Hash
      def initialize
        self[NSSCS_E_OBJECT_NOT_FOUND] = "Can't find the target object DN in NDS. (Resolve name failed.)"
        self[NSSCS_E_NICI_FAILURE] = "NICI operations have failed."
        self[NSSCS_E_INVALID_SECRET_ID] = "Secret ID is not in the User Secret Store."
        self[NSSCS_E_SYSTEM_FAILURE] = "Some internal operating system services have not been available."
        self[NSSCS_E_ACCESS_DENIED] = "Access to the target Secret Store has been denied!"
        self[NSSCS_E_NDS_INTERNAL_FAILURE] = "Some internal NDS services have not been available."
        self[NSSCS_E_SECRET_UNINITIALIZED] = "Secret has not been initialized with a write."
        self[NSSCS_E_BUFFER_LEN] = "Size of the buffer is not in a nominal range between minimum and maimum."
        self[NSSCS_E_INCOMPATIBLE_VERSION] = "Client and server components are not of the compatible versions."
        self[NSSCS_E_CORRUPTED_STORE] = "Secret Store data on the server has been corrupted."
        self[NSSCS_E_SECRET_ID_EISTS] = "Secret ID already eists in the Secret Store."
        self[NSSCS_E_NDS_PWORD_CHANGED] = "User NDS password has been changed by the administrator."
        self[NSSCS_E_INVALID_TARGET_OBJECT] = "Target NDS User object not found."
        self[NSSCS_E_STORE_NOT_FOUND] = "Target NDS User object does not have a Secret Store."
        self[NSSCS_E_SERVICE_NOT_FOUND] = "Secret Store not on the Network."
        self[NSSCS_E_SECRET_ID_TOO_LONG] = "Lenght of the Secret ID buffer eceeds the limit."
        self[NSSCS_E_ENUM_BUFF_TOO_SHORT] = "Lenght of the Enumeration buffer too short."
        self[NSSCS_E_NOT_AUTHENTICATED] =  "User not authenticated."
        self[NSSCS_E_NOT_SUPPORTED] = "Not supported operations."
        self[NSSCS_E_NDS_PWORD_INVALID] = "Typed in NDS password not valid."
        self[NSSCS_E_NICI_OUTOF_SYNC] = "Session keys of the client and server NICI are out of sync."
        self[NSSCS_E_SERVICE_NOT_SUPPORTED] = "Requested service not supported yet."
        self[NSSCS_E_TOKEN_NOT_SUPPORTED] = "NDS authentication type not supported."
        self[NSSCS_E_UNICODE_OP_FAILURE] = "Unicode tet conversion operation failed."
        self[NSSCS_E_TRANSPORT_FAILURE] = "Connection to server is lost."
        self[NSSCS_E_CRYPTO_OP_FAILURE] = "Cryptographic operation failed."
        self[NSSCS_E_SERVER_CONN_FAILURE] = "Opening a connection to the server failed."
        self[NSSCS_E_CONN_ACCESS_FAILURE] = "Access to server connection failed."
        self[NSSCS_E_ENUM_BUFF_TOO_LONG] = "Size of the enumeration buffer eceeds the limit."
        self[NSSCS_E_SECRET_BUFF_TOO_LONG] = "Size of the Secret buffer eceeds the limit."
        self[NSSCS_E_SECRET_ID_TOO_SHORT] = "Lenght of the Secret ID should be greater than zero."
        self[NSSCS_E_CORRUPTED_PACKET_DATA] = "Protocol data corrupted on the wire."
        self[NSSCS_E_EP_ACCESS_DENIED] = "EP password validation failed. Access to the secret denied!"
        self[NSSCS_E_SCHEMA_NOT_ETENDED] = "Schema is not etended to support SecreStore on the target tree."
        self[NSSCS_E_ATTR_NOT_FOUND] = "One of the optional service attributes is not instantiated."
        self[NSSCS_E_MIGRATION_NEEDED] = "Server has been upgraded and user SecretStore should be updated."
        self[NSSCS_E_MP_PWORD_INVALID] = "Master passwrod could not be verified to read or unlock the secrets."
        self[NSSCS_E_MP_PWORD_NOT_SET] = "Master password has not been set on the SecretStore."
        self[NSSCS_E_MP_PWORD_NOT_ALLOWED] = "Ability to use master password has been disabled."
        self[NSSCS_E_WRONG_REPLICA_TYPE] = "Not a writeable replica of NDS."
        self[NSSCS_E_ATTR_VAL_NOT_FOUND] = "Target attrbute is not instantiated in NDS."
        self[NSSCS_E_INVALID_PARAM] = "API parameter is not initialized."
        self[NSSCS_E_NEED_SECURE_CHANNEL] = "Connection to the SecretStore needs to be over SSL."
        self[NSSCS_E_CONFIG_NOT_SUPPORTED] = "No server to support the given override configuration is found."
        self[NSSCS_E_STORE_NOT_LOCKED] = "Attempt to unlock SecretStore failed because the store is not locked."
        self[NSSCS_E_TIME_OUT_OF_SYNC] = "NDS Replica on the server that holds SecretStore is out of sync with the replica ring."
        self[NSSCS_E_VERSION_MISMATCH] = "Versions of the client dlls don't match."
        self[NSSCS_E_SECRET_BUFF_TOO_SHORT] = "Buffer supplied for the secret is too short (minimum NSSCS_MIN_IDLIST_BUF_LEN)."
        self[NSSCS_E_SH_SECRET_FAILURE] = "Shared Secret processing and operations failed."
        self[NSSCS_E_PARSER_FAILURE] = "Shared Secret parser operations failed."
        self[NSSCS_E_UTF8_OP_FAILURE] = "Utf8 string operations failed."
        self[NSSCS_E_CT_LESS_CN_NOT_UNIQUE] = "Contetless name for LDAP bind does not resolve to a unique DN"
        self[NSSCS_E_UNSUPPORTED_BIND_CRED] = "login credential for advanced bind is not supported"
        self[NSSCS_E_CERTIFICATE_NOT_FOUND] = "LDAP Root Cert required for Bind operations not found"
        self[NSSCS_E_WRONG_SH_SEC_TYPE] = "Unrecognized or unknown shared secret tag."
        self[NSSCS_E_STORE_IS_LOCKED] = "Indicates that the user locked the store to prevent access."
        self[NSSCS_E_NOT_IMPLEMENTED] = "Feature not implemented yet."
        self[NSSCS_E_BETA_EPIRED] = "Product's BETA life has epired! Official release copy should be purchased."
      end
    end
  end
end