# Copyright (C) [2006-2009] Novell, Inc.  All Rights Reserved.

# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# IT MAY NOT BE USED, COPIED, DISTRIBUTED, DISCLOSED, ADAPTED, PERFORMED,
# DISPLAYED, COLLECTED, COMPILED, OR LINKED WITHOUT NOVELL'S PRIOR WRITTEN
# CONSENT.  USE OR EXPLOITATION OF THIS WORK WITHOUT AUTHORIZATION COULD
# SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.

# NOVELL PROVIDES THE WORK "AS IS," WITHOUT ANY EXPRESS OR IMPLIED WARRANTY,
# INCLUDING WITHOUT THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE, AND NON-INFRINGEMENT. NOVELL, THE AUTHORS OF THE WORK,
# AND THE OWNERS OF COPYRIGHT IN THE WORK ARE NOT LIABLE FOR ANY CLAIM, DAMAGES,
# OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT, OR OTHERWISE,
# ARISING FROM, OUT OF, OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER
# DEALINGS IN THE WORK.
require 'pty'
require 'expect'
require 'timeout'

#$:.unshift File.expand_path(File.join(File.dirname(__FILE__)))
#require 'safe_pty'
#$:.shift
PWDPATH = "/var/novell/migration/"

module Migration
  def Migration.getDefaultLDAPContext ip_addr, useSecure=true, port=nil
    value = nil
    # Get the host string 
    host = getHostString ip_addr, useSecure, port

    result =`ldapsearch  -b ""  -s base -H #{host} -x 2>&1`
    result.each do |line|
      if line.include?("rootDomainNamingContext:")
        name,value = line.split(':')
        return value.strip!
      end
    end
    return value
  end

  def Migration.winldapsearch ip_addr, ldap_name, context, name, passwd, opt = false, attrs="",useSecure=true
                return1 = nil
    readiostr = ""
    cmd = ""
    options = {}
    options[:password] = passwd
    if useSecure
      host = "ldaps://#{ip_addr}"
    else
      host = "ldap://#{ip_addr}"
    end

    if opt == false
      if name == nil or name == ""
        cmd = "LC_ALL=en_US;ldapsearch -LLL -b \"#{context}\" -s sub -H #{host} -x -D #{ldap_name} -W #{attrs}"
      else
        cmd = "LC_ALL=en_US;ldapsearch -LLL -b \"#{context}\" -s sub -H #{host} -x -D #{ldap_name} -W \"#{name}\" #{attrs}"
      end
    else
      if name == nil or name == ""
        cmd = "LC_ALL=en_US;ldapsearch -b \"#{context}\" -s sub -H #{host} -x -D #{ldap_name} -W"
      else
        cmd = "LC_ALL=en_US;ldapsearch -b \"#{context}\" -s sub -H #{host} -x -D #{ldap_name} -W \"#{name}\""
      end
    end
    # Here execute the command ... and return the result... :-)
    return executeLdapCmd(cmd, options)
  end

  def Migration.ldapsearch ip_addr, ldap_name, context, name, passwd, opt = false, attrs="",useSecure=true, port=nil
    return1 = nil
    readiostr = ""
    cmd = ""
    options = {}
    options[:password] = passwd
    host = getHostString ip_addr, useSecure, port
    if context == "\"\"" or context.include?("'")
      esContext = "\"#{context}\""
    else
      esContext = "'#{context}'"
    end 
    if opt == false
      if name == nil or name == ""
        cmd = "LC_ALL=en_US;ldapsearch -LLL -b #{esContext} -s base -H #{host} -x -D #{ldap_name} -W #{attrs}"
      else
        if name.include?("'")
          esName = "\"#{name}\""
        else
          esName = "'#{name}'"
        end
        cmd = "LC_ALL=en_US;ldapsearch -LLL -b #{esContext} -s one -H #{host} -x -D #{ldap_name} -W #{esName} #{attrs}"
      end
    else
      if name == nil or name == ""
        cmd = "LC_ALL=en_US;ldapsearch -b #{esContext} -s base -H #{host} -x -D #{ldap_name} -W"
      else
        if name.include?("'")
          esName = "\"#{name}\""
        else
          esName = "'#{name}'"
        end
        cmd = "LC_ALL=en_US;ldapsearch -b #{ecContext} -s one -H #{host} -x -D #{ldap_name} -W #{esName}"
      end
    end
    return executeLdapCmd(cmd, options)
  end

  def Migration.ldapadd ip_addr, ldap_name, data, passwd, useSecure=true, port=nil
    f = File.open("/tmp/migdata.ldif", File::CREAT|File::WRONLY|File::TRUNC, 0600)
    f.write(data)
    f.close
    cmd = ""
    host = getHostString ip_addr, useSecure, port

    options = {}
    options[:password] = passwd
#    cmd = "LC_ALL=en_US;ldapadd -H #{host} -W -D #{ldap_name} -c -x -f /tmp/migdata.ldif  1>/dev/null"
    # Combining the both buffers, otherwise /dev/null is not listening in OES11 server
    cmd = "LC_ALL=en_US;ldapadd -H #{host} -W -D #{ldap_name} -c -x -f /tmp/migdata.ldif  2>&1"
    # Here execute ldapsearch
    print_message(DEBUG, "Executing #{cmd} with #{data}")
    return executeLdapCmd(cmd, options)
  end

  def Migration.ldapmod ip_addr, ldap_name, data, passwd, useSecure=true, port=nil
    f = File.open("/tmp/migdata.ldif", File::CREAT|File::WRONLY|File::TRUNC, 0600)
    f.write(data)
    f.close
    options = {}
    options[:password] = passwd
    host = getHostString ip_addr, useSecure, port
    # cmd = "LC_ALL=en_US;ldapmodify -H #{host} -W -D #{ldap_name} -c -x -f /tmp/migdata.ldif 1>/dev/null"
    # Combining the both buffers, otherwise /dev/null is not listening in OES11 server
    cmd = "LC_ALL=en_US;ldapmodify -H #{host} -W -D #{ldap_name} -c -x -f /tmp/migdata.ldif 2>&1"
    print_message(DEBUG, "Executing #{cmd} with #{data}")
    return executeLdapCmd(cmd, options)
  end
     
  def getHostString ip_addr, useSecure, port
    if useSecure
      part_string = "ldaps"
    else
      part_string = "ldap"
    end
    if port
      host = "#{part_string}://#{ip_addr}:#{port}"
    else
      host = "#{part_string}://#{ip_addr}"
    end
    return host
  end

  def executeLdapCmd cmd, options
  # Made the following changes to fix the error redirection issue, bug id: 737677 
  # export LDAPTLS_REQCERT=allow is required for ldapsearch when talking to different tree. Fix for Bug#749531
  # Fix for BugZilla#803151, the index of the command fails when server name has -W embedded in it.
  # Preserve the original command passed to this method to print in the logs. This is to avoid printing the password to the logs. This is the fix for the bug #847998
    ldapCommand = cmd
    index = cmd.index(" -W")
    rep_cmd = cmd[0...index]+" -w"+" \'#{options[:password]}\'"
    rem_cmd = cmd[index+3,cmd.length]
    cmd = rep_cmd + rem_cmd
    cmd += " 2>/tmp/mig-err.txt>&1"
    #The process of spawning the LdapSearch command is put it in a different method - spawnLdapSearch, bug #758481
    #Pass the original command passed to this method to spawnLdapSearch method. There it will be used to print in the logs. This change is done to avoid printing the password in the logs.
    #This is the fix for the bug #847998
    retVal = spawnLdapSearch cmd, ldapCommand
    if not retVal.nil? and retVal.include? "Can't contact LDAP server" #if it returns this value it means LDAP authentication failure
      cmd = "export \"LDAPTLS_REQCERT=never\" ;" + cmd + ";" + "export \"LDAPTLS_REQCERT=""\""
      ret = spawnRetry cmd # calling the spawnRetry with LDAPTLS_REQCERT=never
      return ret
    end
    return retVal
  end

  #This method is called if LDAP authentication is failed in different tree scenario, this method is written because
  #PTY.spawn was not giving the desired results if we invoke it second time. This change is made for bug #758481
  #This method executes the ldapsearch command and returns the results.
  def spawnRetry spwnCmd
    result = []
    cmdresult = `#{spwnCmd}`
    if not cmdresult.nil?
      cmdresult.each_line { | line |
        result << line
      }
    end
    return result 	
  end

  #This method spawns the ldapsearch command and returns the results. This spawning process is put in different method to provide
  #the solution for the bug #758481
  def spawnLdapSearch ldapCmd, ldapCommand
    io_value = ""
    values = [] unless block_given?
    begin
      PTY.spawn(ldapCmd) do |read_io, write_io, pid |

       # commented the below lines to fix the error redirection issue, bug id:737677
       # read_io.expect %r/Password.*:/ do
       # write_io.puts "#{options[:password]}\r\n"
       # end
        begin
          while io_value = read_io.gets
            io_value.rstrip! unless io_value == nil
            if block_given?
              yield io_value
            else
              values << io_value if io_value != ""
            end
          end
        rescue PTY::ChildExited => e
        # If child has exited,
          printLdapError(e, ldapCommand, values) if e.status != 0
          return nil if e.status != 0
        rescue
          # If we receive EIO or any other exception while reading
          # data, wait for the child process to finish
	  # Check the error message. If it is LDAP authentication failure, then return the error to the caller
          errors = ""
          if File.exist?("/tmp/mig-err.txt") and File.size("/tmp/mig-err.txt") > 0
            File.readlines("/tmp/mig-err.txt").each do |line|
              errors << " " + line.strip!
            end
          end
          if errors.include? "Can't contact LDAP server"
            return errors
          end
          Process.wait
          printLdapError($!, ldapCommand, values) if $? != 0
            return nil if $? != 0
        end # inner begin
     end # spawn
    rescue PTY::ChildExited => e
      # After reading the data, if we get ChildExited Exception...
      printLdapError(e, ldapCommand, values) if e.status != 0
        return nil if e.status != 0
    rescue
      begin
        # If we get any other exception, wait for child process to finish
        # first.
        Process.wait
        printLdapError($!, ldapCommand, values) if $? != 0
          return nil if $? != 0
        # This rescue block is for Process.wait, Means if the child process
        # is exited before we call Process.wait, then the call Process.wait
        # may through exception
      rescue
        printLdapError($!, ldapCommand, values) if $? != 0
          return nil if $? != 0
      end # above begin
    end # first begin
  return values unless block_given?    
  end


  def printLdapError excep, cmd, errorMsg
    
    errors = ""
    if File.exist?("/tmp/mig-err.txt") and File.size("/tmp/mig-err.txt") > 0
      File.readlines("/tmp/mig-err.txt").each do |line|
        errors << " " + line.strip!  
      end
      File.delete("/tmp/mig-err.txt")
    elsif errorMsg.to_s.include? "no such entry"
      errors = "No such object exists"
    else
      errors = excep.message
    end
    raise LdapAuthError.new(errors.to_s), caller if errors.include? "Invalid credentials" or errors.include? "failed authentication"
     lines = []
     lines = File.readlines("/tmp/migdata.ldif") if File.exist?("/tmp/migdata.ldif") and File.size("/tmp/migdata.ldif") > 0
     $globalLdapErrorMsg = "command #{cmd} failed, #{errors}, contents of input LDIF file: #{lines}"
  end    

  def checkLdapIsSSlEnabled ip_addr, username, passwd
    # First try with SSL 
    options = {}
    options[:password] = passwd
    cmd = "LC_ALL=en_US ldapsearch -LLL -b \"cn=Security\" -s base -H ldaps:\/\/#{ip_addr} -x -D #{username} -W"
                res = executeLdapCmd(cmd, options)
    if res == nil 
      # Try ldap without SSL
      cmd = "LC_ALL=en_US ldapsearch -LLL -b \"cn=Security\" -s base -H ldap:\/\/#{ip_addr} -x -D #{username} -W"
      res = executeLdapCmd(cmd, options)
      if res == nil
        # Ldap is not working, return nil
        $globalLdapErrorMsg = "command #{cmd} failed"
        return nil
      else
        print_message(WARN, "Unable to use LDAP over SSL(ldaps). Using LDAP over TCP(ldap)")
        return false
      end
    else
      return true
    end
  end
end
