# Copyright (C) [2006-2007] Novell, Inc.  All Rights Reserved.

# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# IT MAY NOT BE USED, COPIED, DISTRIBUTED, DISCLOSED, ADAPTED, PERFORMED,
# DISPLAYED, COLLECTED, COMPILED, OR LINKED WITHOUT NOVELL'S PRIOR WRITTEN
# CONSENT.  USE OR EXPLOITATION OF THIS WORK WITHOUT AUTHORIZATION COULD
# SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.

# NOVELL PROVIDES THE WORK "AS IS," WITHOUT ANY EXPRESS OR IMPLIED WARRANTY,
# INCLUDING WITHOUT THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE, AND NON-INFRINGEMENT. NOVELL, THE AUTHORS OF THE WORK,
# AND THE OWNERS OF COPYRIGHT IN THE WORK ARE NOT LIABLE FOR ANY CLAIM, DAMAGES,
# OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT, OR OTHERWISE,
# ARISING FROM, OUT OF, OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER
# DEALINGS IN THE WORK.
require 'pty'
require 'expect'
require 'timeout'

$:.unshift File.expand_path(File.join(File.dirname(__FILE__)))
require 'safe_pty'
$:.shift

module Migration
	
  TARGET_DIR = "/usr/novell"
  MNT_DIR = "/tmp/migrate"
  TIME_OUT = 300 #5 minutes

  #Cifs mount
  def Migration.cifs_mount( source_host, source_share, source_user, password, time_out = TIME_OUT )
    begin
      Timeout::timeout( time_out ) do
        result = `mkdir -p #{MNT_DIR} 2>&1`
        raise SystemCallError.new(result,Errno::EPERM::Errno) unless result == ""        

        # mount -t cifs -o user=Administrator //ip/share local/mnt/
        PTY.safe_spawn( "mount -t cifs  -o user=#{source_user} \/\/#{source_host}\/#{source_share} #{MNT_DIR}", 
          { :retry_count => 5,
            :password => password }) do |line|
          raise SystemCallError.new("cifs_mount failed to execute command 'mount -t cifs -o user=#{source_host}//#{source_share} #{MNT_DIR}': Permission denied", Errno::EPERM::Errno) if line.include?( 'mount: only root can do that')
        end
      end
    rescue
      raise
    end
    
    true
  end  

def Migration.smbfs_mount( source_host, source_share, source_user, password, time_out = TIME_OUT )
    begin
      Timeout::timeout( time_out ) do
        result = `mkdir -p #{MNT_DIR} 2>&1`
        raise SystemCallError.new(result,Errno::EPERM::Errno) unless result == ""

        `mount -t smbfs -o username=#{source_user},password=#{password} \/\/#{source_host}\/#{source_share} #{MNT_DIR}`
        if $? != 0
          raise SystemCallError.new("cifs_mount failed to execute command 'mount -t smbfs -o username=#{source_host}//#{source_share} #{MNT_DIR}'", Errno::EPERM::Errno)
        end
      end
    rescue
      raise
    end

    true
  end

  
  def Migration.win_mount( source_host, source_user, password, time_out = TIME_OUT)
    found_password = false
    begin
      Timeout::timeout( time_out ) do
        result = `mkdir -p #{MNT_DIR} 2>&1`
        raise SystemCallError.new(result,Errno::EPERM::Errno) unless result == ""        
  
        #puts "PTY.spawn( mount #{source_host}:/ #{MNT_DIR} ) do | read_io, write_io, pid |"
        PTY.spawn( "mount #{source_host}:/ #{MNT_DIR}" ) do | read_io, write_io, pid |
          read_io.expect %r/Password.*:/ do 
            found_password = true
            write_io.puts "#{password}\r\n"
          end
        
          begin 
            read_io.gets while 1
          rescue
            raise SystemCallError.new("win_mount could not find 'Password:' prompt for server #{source_host}.",Migration::EPWD) if not found_password
            raise SystemCallError.new("win_mount failed for server #{source_host} failed.",Migration::EPWD) if not $?.exitstatus == 0      
          end
        end
      end
    rescue
      raise
    end
    
    true
  end

  #Use the nclmount command to mount the server specified. 
  def Migration.ncl_login( source_host, source_user, password, time_out = TIME_OUT)
    found_password = false
    begin
      Timeout::timeout( time_out ) do
	ENV['NWPassword'] = password
	print_message(INFO,"Executing command: /opt/novell/ncl/bin/nwlogin -s #{source_host} -u #{source_user} -E ")
        PTY.spawn( "/opt/novell/ncl/bin/nwlogin -s #{source_host} -u #{source_user} -E " ) do | read_io, write_io, error_io, pid |
        
          begin 
            read_io.gets while 1
          rescue
	    print_message(ERROR,"nwlogin failed with error #{$?.exitstatus}");
            #raise SystemCallError.new("nwlogin for server #{source_host} failed.",Migration::EPWD) if not $?.exitstatus == 0      
          end
        end #PTY
   
      end #Timeout
    rescue
      raise
    end
    true
  end
  
def Migration.ncl_mount( source_host, source_user, password, mount_path, volname, time_out = TIME_OUT)
    found_password = false
    begin

      Timeout::timeout( time_out ) do
	#`/opt/novell/ncl/bin/nwlogout -f -s #{source_host}`
	ENV['NWPassword'] = password
        # nwmap -s 164.99.102.164 -d /var/opt/novell/migration/NewProj0/fs/mnt/source/NSSDATA2 -v NSSDATA2 -u admin.users.novell -p novell
        print_message(INFO,"Executing command: /opt/novell/ncl/bin/nwmap -s #{source_host} -d #{mount_path}/#{volname} -v #{volname} -E")
        PTY.spawn( "/opt/novell/ncl/bin/nwmap -s #{source_host} -d \"#{mount_path}/#{volname}\" -v #{volname} -u \"#{source_user}\" -E" ) do | read_io, write_io, error_io, pid |
        
          begin 
	        while io_val = read_io.gets
              if io_val != nil and io_val != ""
                io_val.strip!
                print "#{io_val}\n"
              end
            end
          rescue Errno::EIO
          rescue
            print_message(ERROR, "nwmap for server #{source_host} failed.") if not $?.exitstatus == 0
          end
        end #PTY
     
      end
    rescue
      raise
    end
    true
  end

  def ncl_umount( source_host, mount_path, time_out = TIME_OUT)
	print_message(INFO,"Executing command:/opt/novell/ncl/bin/nwlogout -f -s #{source_host}")
	result = `/opt/novell/ncl/bin/nwlogout -f -s #{source_host}`
        print_message(INFO,"Command Output: #{result}")
	print_message(INFO,"Executing command: rm #{mount_path}/*")
	`rm \"#{mount_path}/*\"`
  end

  def cifs_umount( time_out = TIME_OUT)
    begin
      Timeout::timeout( time_out ) do
        result = `umount -t cifs #{MNT_DIR} 2>&1`
        raise SystemCallError.new("#{result}", Errno::EEXIST::Errno) unless result == ""
      end	
	rescue Exception => failed
		raise SystemCallError.new("cifs_umount failed, #{failed.message}", failed.errno)
	end
  end
  
  alias umount ncl_umount
  module_function :ncl_umount, :umount  

  def mnt_dir
	  return MNT_DIR
  end

  def target_dir
	  return TARGET_DIR
  end

  def mnt_vol_dir
	  return MNT_VOL_DIR
  end

  MNT_VOL_DIR="/mnt/nwservers/"
  
  #Use the volmount command to mount the server specified. 
  def Migration.vol_mount( source_host, source_volume, mount_dir, source_user, password, time_out = TIME_OUT)
	#p "migmount.rb::vol_umount(source_host: #{source_host}, mount_dir: #{mount_dir}, source_user: #{source_user}, password: #{password})"
	#mnt_dir = vol_dir source_host, mount_dir
	mnt_dir = mount_dir	
    found_password = false
    #begin
       #Timeout::timeout( time_out ) do
        result = `mkdir -p #{mnt_dir} 2>&1`
        raise "vol_mount: mkdir -p #{mnt_dir} failed" unless result == ""        
 		
		#p "PTY.spawn( ncpmount -A #{source_host} -S #{source_host} -V #{source_volume} -U #{source_user} -P #{password} #{mnt_dir} " 
        #PTY.spawn( "ncpmount -A #{source_host} -S #{source_host} -V #{source_volume} -U #{source_user} #{mnt_dir}" ) do | read_io, write_io, pid |
        PTY.spawn( "ncpmount -A #{source_host} -S #{source_host} -U #{source_user} #{mnt_dir}" ) do | read_io, write_io, pid |
          read_io.expect %r/Password.*:/ do 
            found_password = true
            write_io.puts "#{password}\r\n"
          end
        
          begin 
            read_io.gets while 1
          rescue RuntimeError
            raise
          rescue
            raise "vol_mount could not find 'Password:' prompt for server #{source_host}." if not found_password
            raise "vol_mount for server #{source_host} failed." if not $?.exitstatus == 0      
          end
        end
      #end
    #rescue
      #raise
    #end
    true
  end
  
  #Unmount the volmount specified with MNT_DIR
  def Migration.vol_umount(mnt_dir, time_out = TIME_OUT)
	Timeout::timeout( time_out ) do
		#p "migmount.rb::vol_umount #{mnt_dir}" 
		result = `umount #{mnt_dir} 2>&1`
		raise SystemCallError.new("vol_umount failed\n", Migration::ESRCVOLUMOUNTFAIL) unless result == ""

		Dir.delete(mnt_dir)
	end
  end

  def Migration.vol_persmount source_host, source_volume, mount_dir, source_user, source_pwd
	fstab = nil
	File.open("/etc/fstab", File::RDONLY) do |f|
		fstab = f.readlines
		fstab_str = "#{source_host}/#{source_user}	#{mount_dir}	ncp uid=root,gid=root,mode=660,owner=root,A=#{source_host},P=#{source_pwd}	0 0\n"
		unless fstab.include? fstab_str 
			fstab << fstab_str
		end
	end

	File.open("/etc/fstab", File::WRONLY|File::TRUNC) do |f|
		f.write(fstab)	
	end
  end

  def Migration.vol_persumount(source_host, source_user, source_pwd, mount_dir)
	fstab = nil
	File.open("/etc/fstab", File::RDONLY) do |f|
		fstab = f.readlines
		fstab_str = "#{source_host}/#{source_user}	#{mount_dir}	ncp uid=root,gid=root,mode=660,owner=root,A=#{source_host},P=#{source_pwd}	0 0\n"
		if fstab.include? fstab_str 
			idx = fstab.index fstab_str
			fstab.slice! idx
		end

		fstab = fstab.join
	end

	File.open("/etc/fstab", File::WRONLY|File::TRUNC) do |f|
		f.write(fstab)	
	end
  end

  def Migration.vol_dir source, volume
	  new_vol = source.slice(source.index(".")+1, source.length)
	  new_vol = new_vol.slice(new_vol.index(".")+1, new_vol.length)
	  new_vol = new_vol.gsub(/\./,"-")
	  
	  volume = volume.downcase

	  #puts "new_vol: #{new_vol}"
	  
	  new_vol = new_vol + "-" + volume.slice!(0, 16 - new_vol.length + 1)
	  #puts "new_vol: #{new_vol}"
	  return MNT_VOL_DIR + new_vol
  end

  def Migration.target_vol_dir source, volume
	  return TARGET_DIR + "/" + vol_name(source, volume) 	  
  end

  def Migration.shadow_vol_dir source, volume
	  #return vol_dir(source,volume) + "/" + volume 	
	  return MNT_VOL_DIR + source + "/" + volume
  end

  def Migration.vol_name source, volume
	  volume_name = vol_dir(source, volume)
	  return volume_name.slice!(MNT_VOL_DIR.length,volume_name.length)
  end
end
