 # (C) Copyright 1995 - 2021 Micro Focus or one of its affiliates.
 
 # The only warranties for products and services of Micro Focus and its affiliates and licensors
 # (“Micro Focus”) are as may be set forth in the express warranty statements accompanying such
 # products and services. Nothing herein should be construed as constituting an additional
 # warranty. Micro Focus shall not be liable for technical or editorial errors or omissions contained
 # herein. The information contained herein is subject to change without notice.
 
 # Except as specifically indicated otherwise, this document contains confidential information
 # and a valid license is required for possession, use or copying. If this work is provided to the
 # U.S. Government, consistent with FAR 12.211 and 12.212, Commercial Computer Software,
 # Computer Software Documentation, and Technical Data for Commercial Items  are licensed
 # to the U.S. Government under vendor's standard commercial license.

# Copyright (C) [2006-2009] Novell, Inc.  All Rights Reserved.

# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# IT MAY NOT BE USED, COPIED, DISTRIBUTED, DISCLOSED, ADAPTED, PERFORMED,
# DISPLAYED, COLLECTED, COMPILED, OR LINKED WITHOUT NOVELL'S PRIOR WRITTEN
# CONSENT.  USE OR EXPLOITATION OF THIS WORK WITHOUT AUTHORIZATION COULD
# SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.

# NOVELL PROVIDES THE WORK "AS IS," WITHOUT ANY EXPRESS OR IMPLIED WARRANTY,
# INCLUDING WITHOUT THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE, AND NON-INFRINGEMENT. NOVELL, THE AUTHORS OF THE WORK,
# AND THE OWNERS OF COPYRIGHT IN THE WORK ARE NOT LIABLE FOR ANY CLAIM, DAMAGES,
# OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT, OR OTHERWISE,
# ARISING FROM, OUT OF, OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER
# DEALINGS IN THE WORK.
require 'open3'
#require 'net/ssh'

LDAPCONF_FILE = "/tmp/ldap.conf"
ENV['LDAPCONF'] = LDAPCONF_FILE

module Migration

def remove_duplication object
  @hash[object] = object
end

# This class is a dummy logger class, which will avoid writing IF conditions
# wherever we log the message.
class DummyLogger
  attr_accessor :progname
    def fatal ; end
    def error ; end
    def warn ; end
    def debug ; end
    def info ; end
    def unknown ; end
  def close ; end
end

# Constants for message types...
FATAL = 0
ERROR = 1
WARN = 2
DEBUG = 3
INFO = 4
UNKNOWN = 5
PROGRESS= 6

NSSPERMISSION = ["S","M","F","A","E","C"," ","W","R"]
NSSBITVAL = [256,128,64,32,16,8,4,2,1]

# Constant which says how many objects should be loaded in one call to YAML.load_documents
NO_OF_OBJECTS_PER_RECORD = 200

# Supporting dc object for migration. Fix for BugZilla#696616
CONTAINER_HASH = {'c' => 'country', 'st' => 'locality', 'l' => 'locality', 'o' => 'Organization', 'ou' => 'organizationalUnit', 'dc' => 'domainController'}

def convert_number_to_netware_permission(bit_value)
  permission = ""

  int_value = bit_value.to_f.to_int

  if int_value == 0
    return 1
  elsif int_value > 511
    return 1
  end

  i = 0
  NSSBITVAL.each do |bitval|
    if int_value/bitval > 0
      permission = permission + NSSPERMISSION[i]
    end
    int_value = int_value % bitval
    i = i+1
  end

  return permission
end

PERMISSION = [4,4,2,4,4,4,2,4,2]
BITVAL = [256,128,64,32,16,8,4,2,1]

def nw_rights_to_linux_permissions(bit_value, type)
  permission = 0

  int_value = bit_value.to_f.to_int
  
  if int_value == 0 
    return 1
  elsif int_value > 511
    return 1
  end

  i = 0
  BITVAL.each do |bitval|
    if int_value/bitval > 0 
      permission = permission | PERMISSION[i]
    end  
    int_value = int_value % bitval
    i = i+1
  end

  if type == "user"
    return permission * 100
  else
    return permission * 10
  end  
end

def nw_attributes_to_linux_permission(attrs)
  permission = 0664
  if attrs & READ_ONLY_BIT != 0
    permission = 0440
  end
  if attrs & EXECUTE_BIT != 0
    permissions = permissions | 0111
  end
  return permission
end


def linux_name ldap_name, type
  #max length of a linux name is 32 characters
  ldap_name.downcase!
  #puts "ldap_name: #{ldap_name}"
  if ldap_name != "[root]" and ldap_name != "[supervisor]" and ldap_name != "[public]" and ldap_name != "[adminstrator]"
    if type == "user"
      index = ldap_name.index(",")
      if index == nil
        index = ldap_name.length
      end
      #puts "index:#{index}"
      name = ldap_name[0, index]
      name  = name[name.index("=")+1,name.length]
      #common_name = user.subject[/CN=(\s*)\./,1]
      #cn = group_name[3,group_name.index(",")-3]
    else
      #max length of a linux name is 32 characters
      #puts "ldap_name: #{ldap_name}"
      name = ldap_name.sub(/\w*=/,"").gsub(/,\w*=/,"_").slice(0,31) 
    end
    if name.index(/^[0-9]/, 0)
      name = name[/([0-9]*)(.*)/,2] + "_" +  name[/([0-9]*)(.*)/,1]
    end
  else
    name = "root" 
  end
  return name.gsub(/[^A-Za-z0-9_\.\-]/,"_")
end

def edir_name_to_ldap_name edir_name
  #puts "edir_name: #{edir_name}"
  #ldap_name = edir_name.gsub(/\.(\w*=)/,",\1")  
  ldap_name = edir_name.gsub(/\./,",")  
  ldap_name.downcase
end

def is_valid_ldap_container? ldap_name
  ldapComponents = ldap_name.split(",")
  keys = CONTAINER_HASH.keys
  orgName = ldapComponents.last.split("=")
  if orgName.length != 2
    return false
# Supporting dc object for migration. Fix for BugZilla#696616
  elsif orgName[0].downcase != "o" and orgName[0].downcase != "c" and orgName[0].downcase != "dc"
    return false
  end
  last = orgName[0].downcase
  i = 0
  prev = ""
  ldapComponents.each do |component|
    i = i + 1
    orgName = component.split("=")
    if orgName.length != 2
      return false
    elsif not keys.include?(orgName[0].downcase)
      return false
    elsif orgName[0].downcase == 'c' and i != ldapComponents.length
      #found c before the end
      return false
    elsif (orgName[0].downcase == 'o' and prev == 'o') or
      (orgName[0].downcase == 'c' and prev == 'c')
      return false
    elsif (orgName[0].downcase == 'ou' and prev == 'o')
      #o under ou
      return false
    end
    prev = orgName[0]
  end
  
  return true
end

def is_valid_ldap_name? ldap_name
  #TODO: need to implement this
  if ldap_name.index("=") == nil
    return false
  elsif ldap_name.match(/\..*=/)
    return false
  else
    return true
  end
end

def is_valid_activeDir_context? activeDir_context
  user_context = activeDir_context.split(",")
  user_context.each do |context|
    context_comp = context.split("=")
    if context_comp.length != 2
      return false
    elsif context_comp[0].downcase != "cn" and context_comp[0].downcase != "dc" and context_comp[0].downcase != "ou" and context_comp[0].downcase != "o"
      return false
    else
      next
    end
  end
  return true
end

R1 = "NCP Engine Platform: 1:"
def is_src_linux? source, username
  ENV['OES_DATA3'] = username
  ENV['OES_DATA4'] = source
  r = `/opt/novell/ncpserv/sbin/ncpshell --fsinfo`
  if r.include?("error") or r.include?("rc=")
    raise MigrationException.new("ncpshell: #{r}")
  end
  if r.include? R1
    return true
  else
    return false
  end
end

def isSource51? source, username
  ENV['OES_DATA3'] = username
  ENV['OES_DATA4'] = source
  r = `/opt/novell/ncpserv/sbin/ncpshell --fsinfo`
  if r.include?("error") or r.include?("rc=")
    raise MigrationException.new("ncpshell: #{r}")
  end
  if r[r.index("Product Version: v") + "Product Version: v".length, 1] == "5"
    return true
  else
    return false
  end
end

def isSource60? source, username
  ENV['OES_DATA3'] = username
  ENV['OES_DATA4'] = source
  r = `/opt/novell/ncpserv/sbin/ncpshell --fsinfo`
  if r.include?("error") or r.include?("rc=")
    raise MigrationException.new("ncpshell: #{r}")
  end
  if r[r.index("Product Version: v") + "Product Version: v".length, 3] == "6.0"
    return true
  else
    return false
  end
end
def file_copy_total path
  cd = Dir.pwd
  Dir.chdir path
  fa = Dir.glob("{#{path}}/**/*")
  Dir.chdir cd
  #fa.each do |f|
  #  p f
  #end
  return fa.length
end

def line_count file
  fc = 0
  File.open(file,File::RDONLY) do |f|
    la = f.readlines
    fc = la.length
  end
  return fc
end

def create_ncp_volume v, path
  #v.slice!(0,v.index("/")) unless v.index("/") == nil
  Dir.mkdir path unless File.exist? path
  #puts "ncpcon create volume #{v} #{path} 2>&1"
  `ncpcon create volume #{v} #{path} 2>&1`
end

def simple_context old_name, opt
  new_name = old_name
  unless opt == nil 
    unless old_name.index(",") == nil
      top_name = old_name.slice(0, old_name.index(",")+1) 
      new_name = top_name + opt
    end
  end
  #puts "new_name: #{new_name}"
  return new_name  
end

def parse_name ldap_name
  #puts ldap_name
  if ldap_name.index(",") == nil
    base_name = "\"\""
    first_name = ldap_name
  else
    first_name = ldap_name.slice(0,ldap_name.index(','))
    base_name = ldap_name.slice(ldap_name.index(',')+1,ldap_name.length)
  end
  #puts "first_name: #{first_name}"
  #puts "base_name: #{base_name}"
  return first_name, base_name
end

def ldap_exist? dest_server, dest_username, name, useSecure, port
  check_ldap_exist? dest_server, dest_username, name, useSecure, port
end

def check_ldap_exist? source, username, name, useSecure, port
#  cns, context = parse_name name
  result = Migration.ldapsearch source, username, name, "", @passwd, true, "", useSecure, port
  if result == nil
    return false
  end
  unless result.include? "No such object"
    return true
  else
    return false
  end
end

def ldap_attribute_exist? dest_server, dest_username, name, attribute, value, useSecure, port
#  cns, context = parse_name name
  result = Migration.ldapsearch dest_server, dest_username, name, "", @passwd, true, "", useSecure, port
  if result == nil
    return false
  end
  #puts "result: #{result}"
  unless result.include? "No such object"
    if result.include? "#{attribute}: #{value}"
      return true
    end
  end
  return false
end

def check_lum_exist? source, username, password, r
  cns, context = parse_name r['dn']
  cns = cns.slice(cns.index("=")+1, cns.length)
  if r['lum-group']
    #puts "namgrouplist -x #{context} \"#{cns}\" 2>&1"
    result = `namgrouplist -x #{context} \"#{cns}\" 2>&1`
  else
    #puts "namuserlist -x #{context} \"#{cns}\" 2>&1"
    result = `namuserlist -x #{context} \"#{cns}\" 2>&1`
  end
  #puts "result: #{result}"
  unless result.include? "No such object" 
    #puts "TRUE"
    return true
  else
    #puts "FALSE"
    return false
  end
end

def ldap_primary_group_name 
  if @opt['k']
    return "#{server_name}-linux-grp,#{@opt['k']}".downcase 
  else
    return "#{server_name}-linux-grp,#{server_context}".downcase 
  end
end

def server_name server_ip = nil
  if File.exist? "/opt/novell/eDirectory/bin/ndsstat"
    if server_ip == nil
      s = `/opt/novell/eDirectory/bin/ndsstat`
    else
      s = `/opt/novell/eDirectory/bin/ndsstat -h #{server_ip}`
    end
  else
    if server_ip == nil
      s = `ndsstat`
    else
      s = `ndsstat -h #{server_ip}`
    end
  end
  if $? != 0
    # ndsstat function failed, return nil
    return nil
  end
  s = s.slice(s.index("Server Name: .")+14,s.length)
  s = s.slice(0,s.index("."))    
end

def server_context server_ip = nil
  if File.exist? "/opt/novell/eDirectory/bin/ndsstat"
    if server_ip == nil
      s = `/opt/novell/eDirectory/bin/ndsstat`
    else
      s = `/opt/novell/eDirectory/bin/ndsstat -h #{server_ip}`
    end
  else
    if server_ip == nil
      s = `ndsstat`
    else
      s = `ndsstat -h #{server_ip}`
    end
  end
  s = s.slice(s.index("Server Name: .")+14,s.length)
  s = s.slice(0,s.rindex("T=")-1)
  s = s.slice(s.index(".")+1,s.length)
  s = s.gsub(/\./,",")
end

def get_nds_tree ip=""
  if ip != ""
    s = `/opt/novell/eDirectory/bin/ndsstat -h #{ip}`
  else
    s = `/opt/novell/eDirectory/bin/ndsstat`
  end
  if s.include?("Tree Name:")
    s.each_line { |line|
      if line.include?("Tree Name:")
        junk, tree = line.split(":")
        return tree.strip
      end
    }
  else
    raise MigrationException.new("get_nds_tree failed to execute command 'ndsstat -h #{ip}', #{s}")
  end
end

def check_posix_group_exist? name
  ret = true
  begin
    name = Etc.getgrnam(name)
  rescue ArgumentError
    ret = false
  end
  ret
end

def check_posix_user_exist? name
  ret = true
  begin
    name = Etc.getpwnam(name)
  rescue ArgumentError
    ret = false
  end
  ret
end

def is_compression_enabled? vol
  result = NSS.instance.get_vol_info(vol)
  result =~ %r{<enabledAttributes value=(.*)">(.*)</enabledAttributes>}
  if $2.include?("<compression/>")
    return true
  end
  return false
end

def get_enabled_attributes vol, adminfsFile=MANAGE
  result = NSS.instance.get_vol_info(vol, adminfsFile)
  result =~ %r{<enabledAttributes value=(.*)">(.*)</enabledAttributes>}
  return $2
end

def get_nss_vol_and_mnt_point_from_path path, adminfsFile=MANAGE
  if not File.exist?(MANAGE)
    print_message(DEBUG, "File #{MANAGE} does not exist. Probably NSS is not installed or it is not running")
    return nil, nil
  end
  vols = NSS.instance.list_volumes(adminfsFile)
  vols.each { |vol|
    result = NSS.instance.get_vol_info(vol, adminfsFile)
    result =~ %r{<mountPoint>(.*)</mountPoint>}
    if $1 != nil   #$1 will have the mount point
      if path == $1   #path and the mount point are the same
        return vol, $1
      elsif path.index($1+"/") == 0   #path has "mntpnt/" at its begining
        return vol, $1
      end
    end
  }
  return nil, nil
end

def get_ncp_vol_and_mnt_point_from_path path
  File.open("/etc/opt/novell/ncpserv.conf", "r") { |fp|
    fp.each_line { |line|
      if line.index(";") != 0
        if line.include?("VOLUME")
          words = line.split
          if path.index(words[2]) == 0
            return words[1], words[2]
          end
        end
      end
    }
    return nil, nil
  }
  return nil, nil
end

def get_ncp_vol_and_mntpt_from_remote_server(source_server, username, path, volGiven)
require 'net/ssh'
  volName = path
  if volGiven and path.include?(":")
    volName, extraPath = path.split(":")
  end
  actualUser = username
  if actualUser.include?(".")
    user = username.split(".")
    actualUser = user[0].strip
  end
  print_message(DEBUG, "Actualuser to start SSH session: #{actualUser}")
  begin
  Net::SSH.start( source_server, actualUser, ENV['OES_DATA'] ) do |session|
    session.process.open("cat /etc/opt/novell/ncpserv.conf") do |sshObj|
      sshObj.on_stdout do |obj, data|
        data.each do |line|
          if line.index(";") != 0
            if line.include?("VOLUME")
              words = line.split(" ")
              if volGiven
                if words[1].casecmp(volName) == 0
                  return words[1], words[2]
                end
              else
                if path.slice(0, words[2].size) == words[2]
                  if path.size == words[2].size
                    return words[1], words[2]
                  elsif path.size > words[2].size and path.slice(words[2].size, 1) == "/"
                    return words[1], words[2]
                  end
                end
              end
            end
          end
        end
        return nil, nil
      end # on_stdout
      sshObj.on_exit do |obj, status|
        if status != 0
          print_message(FATAL, "Failed to get mount point details of NCP volume from source server")
          exit 1
        end
      end # on_exit
    end # session.process
    session.loop
  end # Net::SSH.start
  rescue Net::SSH::AuthenticationFailed => e
    print_message(FATAL, "Authentication failed for user #{username}. Please check whether the user #{username} is LUM enabaled on source server")
    exit 1
  end  # Begin
end


def get_nss_vol_and_mnt_point_from_vol vol, adminfsFile=MANAGE
  if not File.exist?(MANAGE)
    print_message(DEBUG, "File #{MANAGE} does not exist. Probably NSS is not installed or it is not running")
    return nil, nil
  end
  vols = NSS.instance.list_volumes(adminfsFile)
  if vols.include?(vol) == false
    return nil, nil
  end

  result = NSS.instance.get_vol_info(vol, adminfsFile)
  result =~ %r{<mountPoint>(.*)</mountPoint>}
  if $1 != nil   #$1 will have the mount point
    return vol, $1
  end
end

def get_ncp_vol_and_mnt_point_from_vol vol
  File.open("/etc/opt/novell/ncpserv.conf", "r") { |fp|
    fp.each_line { |line|
      if line.index(";") != 0
        if line.include?("VOLUME")
          words = line.split
          if words[1].casecmp(vol) == 0
            return words[1], words[2]
          end
        end
      end
    }
    return nil, nil
  }
  return nil, nil
end

def convert_linux_path_to_nss_path path
  vol, mntpt = get_nss_vol_and_mnt_point_from_path(path)
  nss = false
  if vol == nil or mntpt == nil
    vol, mntpt = get_ncp_vol_and_mnt_point_from_path(path)
    if vol == nil or mntpt == nil
      return nil, nil
    end
  else
    nss = true
  end

  if path.index(mntpt) == 0
    return nss, vol + ":" + path.sub(mntpt,"")
  end
end

def checkIfMounted
  mount_check_cmd = "mount -l"
  Open3.popen3(mount_check_cmd) do |input,output,err|
    while 1
      line = output.gets
      #line.strip!
      if line == nil
        return true
        break
      elsif line =~ / #{MNT_DIR} /
        return false
        break
      end
    end
  end
  errorStrig = "Failed to check if the directory #{MNT_DIR} is mounted or not"
  raise MigrationException.new(errorString)
end

def error_log file_name, error_string
    if File.size?( file_name) != nil
      File.open( file_name, File::WRONLY | File::APPEND, 0600) { |fd|
      fd.write(error_string)
      fd.close
    }
    else
      File.open( file_name,  File::CREAT| File::WRONLY | File::APPEND, 0600) { |fd|
      fd.write(error_string)
      fd.close
    }
    end  
end

def initLog debugOpt, cmdName
  if debugOpt
    if not File.exist?("/var/opt/novell/log/migration")
      Dir.mkdir("/var/opt/novell/log/migration/")
    end
    $log = Logger.new("/var/opt/novell/log/migration/#{cmdName}.log");
    $log.level = Logger::DEBUG
    $log.datetime_format = "%d-%m-%Y %H:%M:%S"
    $log.progname=cmdName
  else
    # Create a object of DummyLogger class
    $log = DummyLogger.new();
  end
end

def print_message seviority, message
  case seviority
    when FATAL
      $log.fatal{message}
      $stderr.puts("Fatal: "+message)
    when ERROR
      $log.error{message}
      $stderr.puts("Error: "+message)
    when WARN
      $log.warn{message}
      $stderr.puts("Warning: "+message)
    when DEBUG
      $log.debug{message}
    when INFO
      $log.info{message}
      $stderr.puts("Information: "+message)
    when UNKNOWN
      $log.unknown{message}
      $stderr.puts("Unknown: "+message)
    when PROGRESS
      #$log.unknown{message}
      $stderr.puts("Progress: "+message)
    else
      $log.fatal{"Unknown seviority received..."}
      raise MigrationException("Fatal: Unknown seviority received...")
  end
end


# This funciton calculates the total number of objects present in given input yaml file

def getTotalObjs(inputFile)
  # Need to to return total number of objects
  totalObjs = `grep "^\\- " "#{inputFile}" | wc -l`
  totalObjs.strip!
  totalObjs = totalObjs.to_i
  return totalObjs
end

# This funciton starts timer, Once the timer expires it will send SIGALRM to parent
def startTimer interval
  tid = Thread.new{
    sleep interval
    # Send SIGALRM to parent and die
    Process.kill(:ALRM, $$)
    Thread.kill(tid)
  }
end

# This function writes the status information to the given session file
def writeToSessionFile done, fileCnt
  fileHandle = File.new(@opt['c'],  File::CREAT|File::TRUNC|File::WRONLY, 0600)
  if done == true
    fileHandle.write($session + "  status: Completed at #{`date`}" )
  else
    fileHandle.write($session + "  status: Stopped\n  stopped-at: #{fileCnt}")
  end
  fileHandle.close
end

def createLdapConfFile
  fileHandle = File.new(LDAPCONF_FILE,  File::CREAT|File::TRUNC|File::WRONLY, 0600)
  fileHandle.write("TLS_REQCERT never\n")
  fileHandle.close
end

def deleteLdapConfFile
  if File.exist?(LDAPCONF_FILE)
    File.delete(LDAPCONF_FILE)
  end
end

def getMountPointDetails result, searchString, volGiven, path
  found = false
  prev = ""
  type = ""
  result.each do |single|
    if volGiven
      if single.downcase.include?(searchString.downcase)
        # Found the volume. Now next line should give us details
        # regarding its type and mount point
        found = true
        next
      end
      if found == true
        mountPointString = single.split(":")
        if mountPointString == nil or mountPointString == "" or mountPointString.size != 2
          return nil, nil, nil
        end
        if mountPointString[1].include?("NSS")
          print_message(INFO, "Source volume type is NSS")
          mountPointDetails = mountPointString[1].split(" ")
          type = "NSS"
          if mountPointDetails == nil or mountPointDetails == "" or mountPointDetails.size != 2
            return nil, nil, nil
          end
          mountPoint = mountPointDetails[1].strip
        else
          type = "NCP"
          print_message(INFO, "Source volume type is NCP")
          mountPoint = mountPointString[1].slice(mountPointString[1].index("\/"), mountPointString[1].size).strip
        end
        return volGiven, mountPoint, type
      end
    else
      # Option X is given ...
      nss = false
      if single.include?("dn: ")
        prev = single
      elsif single.include?("dn:: ")
        # it is encoded...decode it..
        arr = single.split("::")
        if arr[1] != nil and arr[1] != ""
          strToBeDecoded = arr[1].strip!
          prev = Base64.decode64(strToBeDecoded)
          prev = "dn: "+prev
        else
          print_message(FATAL, "DN is in Encoded form, failed to decode it")
          return nil, nil, nil
        end
      end
      if single.include?("linuxNCPMountPoint:")
        # Now get the mount point and compare it with @opt['X']
        mountPointString = single.split(":")
        if mountPointString == nil or mountPointString == "" or mountPointString.size != 2
          return nil, nil, nil
        end
        if mountPointString[1].include?("NSS")
          type = "NSS"
          mountPointDetails = mountPointString[1].split(" ")
          if mountPointDetails == nil or mountPointDetails == "" or mountPointDetails.size != 2
            # It can be a cluster source, so try to get mount point assuming it as cluster source
            return nil, nil, nil
          end
          mountPoint = mountPointDetails[1].strip
          nss = true
        else
          mountPoint = mountPointString[1].slice(mountPointString[1].index("\/"), mountPointString[1].size).strip
          nss = false
          type = "NCP"
        end
        if path == mountPoint or path.index(mountPoint+"/") == 0
          if nss
            print_message(INFO, "Given volume is of type NSS")
          else
            print_message(INFO, "Given volume is of type NCP")
          end
          found = true
          server = server_name(@opt['s'])
          volName = prev.downcase.slice(server.size+5..prev.index(",")-1)
          # Here server will be cn=some* and prev string will be prepended wit "dn: " --> 3
          # and "_" --> 1. So slice should be done from +5 onwards
          if volName == nil
            return nil, nil, nil
          end
          return volName.upcase, mountPoint, type
        end
      end
    end
  end
  if found == false
    return nil, nil, nil
  end
end

def getDotUser username
  dotName = ""
  names = username.split(",")
  names.each { |elem|
    if elem.include?("=")
      dotName = dotName + elem[elem.index("=")+1, elem.length] + "."
    end
  }
  if dotName == ""
    return username
  else
    return dotName.chomp('.')
  end
end

def checkSMDRStatus
  # Appending the smdr status command with its full path. This is to provide fix for bug #831618
  result = `/usr/sbin/rcnovell-smdrd status`
  if not result.include?("running")
    return false
  end
  result = `/opt/novell/sms/bin/smsconfig -t`
  if $? != 0
    print_message(FATAL, "'command /opt/novell/sms/bin/smsconfig -t' failed")
    return false
  end
  if not result.include?("tsafs")
    return false
  end
  return true
end

def checkNFSLoadedOnSource sourceServer, srcVolume, user
  print_message(DEBUG, "ncpshell command executed as /opt/novell/ncpserv/sbin/ncpshell --ip=#{sourceServer} --u=#{user} --vinfo --parm1=\"#{srcVolume}\"")
  res = `LC_ALL=en_US.UTF-8 /opt/novell/ncpserv/sbin/ncpshell --ip=#{sourceServer} --u=#{user} --vinfo --parm1=\"#{srcVolume}\"`
  if res.include?("error") or res.include?("rc=")
    raise MigrationException.new("ncpshell: #{res}")
  end
  if $? != 0
      print_message(WARN, "Failed to check whether NFS Name Space is loaded on volume #{srcVolume} on source server #{sourceServer}")
      return true
  end
  res.lines.to_a.each do |line|
    if line.include?"NameSpaces=" and line.include?"NFS"
        return true
    end
  end
  return false
end

def killAllnbackups nbackupCmd, mls
  parentPid = nil
  cmd = "/opt/novell/sms/bin/nbackup"
  print_message(DEBUG, "Executing killAllnbackups function")
  nbackupCmd.gsub!("\"", "\\\"")
  res = `ps -aef | grep \"#{nbackupCmd}\"`
  print_message(DEBUG, "cmd = ps -aef | grep \"#{nbackupCmd}\"\n")
  if $? != 0
    print_message(DEBUG, "command ps -aef | grep \"#{nbackupCmd}\" failed" )
    return
  end
  res.each do |line|
    if not (line.include? "grep" or line.include? "ps -aef")
      splitInfo = line.split(" ")
      parentPid = splitInfo[1]
    end
  end
  if parentPid == "" or parentPid == nil
    print_message(DEBUG, "parentPid is nil")
    return
  end
  print_message(DEBUG, "Parent PID = #{parentPid}")
  if mls
    `kill -2 #{parentPid} 2>/dev/null`
    print_message(DEBUG, "Sent SIGINT signal to #{parentPid}")
    if $? != 0
      print_message(DEBUG, "kill -2 #{pid} command failed")
    end
    return
  end
  # Now search for nbackup command which are started by parent with pid parentPid
  res1 = `ps -aef | grep #{cmd} | grep #{parentPid}`
  if $? != 0
    print_message(DEBUG, "command ps -aef | grep #{cmd} | grep #{parentPid} failed" )
    return
  end
  res1.each do |line|
    splitInfo = line.split(" ")
    if splitInfo[7].chomp.casecmp(cmd) == 0
      pid = splitInfo[1]
      print_message(DEBUG, "Child PID = #{pid}\n")
      `kill -2 #{pid} 2>/dev/null`
      if $? != 0
        print_message(DEBUG, "kill -2 #{pid} command failed")
      end
      print_message(DEBUG, "Sent SIGINT signal to #{pid}")
    end
  end
end

def checkTSAFSVersion nbackupCmd
  majorVersion = -1
  minorVersion = -1
  begin
    Open3.popen3(nbackupCmd) do | input, output, err |
      while 1
        errline = err.gets
        if errline != "" and errline != nil
          errline.chomp!
          if errline.include?"Connection denied"
            raise MigrationException.new("nbackup command failed to execute: #{errline}")
          end
          print_message(ERROR, "#{errline}")
        end
        outline = output.gets
        outline.chomp! if outline != nil and outline != ""
        if outline != nil and outline != "" and (outline.include?("TSA Major") or outline.include?("TSA Minor"))
          # Process the output version should be 4.1 or greate if it is Linux else it should be
          # 3.1 or greater
          splitInfo = outline.split("=") if outline.include?"="
          if splitInfo[0].include?"TSA Major"
            majorVersion = splitInfo[1].chomp.to_i if splitInfo[1] != "" and splitInfo[1] != nil
          elsif splitInfo[0].include?"TSA Minor"
            minorVersion = splitInfo[1].chomp.to_i if splitInfo[1] != "" and splitInfo[1] != nil
          end
        end
        if outline == nil and errline == nil
          break
        end
      end
    end
  rescue Errno::EIO
  end
  return majorVersion, minorVersion
end

def getLocalIPAddress
  # Execute ndsconfig command to get the local IP address
  serverIPInfo = ""
  res1 = `/opt/novell/eDirectory/bin/ndsconfig get n4u.server.interfaces`
  res = res1.split("\n")

  if $? != 0 or (res == nil or res == "")
    return nil
  end
  res.each do |line|
    if line.include?"n4u.server.interfaces="
      sliceInfo = line.slice(line.index("=")+1, line.length-1)
      serverIPInfo = sliceInfo.split("@") if sliceInfo != nil and sliceInfo != ""
      if serverIPInfo[0] == nil or serverIPInfo == ""
        return nil
      else
        return serverIPInfo[0].strip
      end
    end
    end
  return nil
end
def get_nss_volume_list adminfsFile=MANAGE
  vols = NSS.instance.list_volumes(adminfsFile)  
  if vols.size > 0
    return vols
  else
    return nil
  end
end

def get_nss_pool_list adminfsFile=MANAGE
  pools = NSS.instance.list_pools(adminfsFile)  
  if pools.size > 0
    return pools
  else
    return nil
  end
end

def chktsafsCodeSet codepage
  found = false
  # First check whether smdr is running...
  if (!checkSMDRStatus())
    return false, "SMDR is not running on server"
  end
  cmd = "/opt/novell/sms/bin/smsconfig -t"
  result = `#{cmd}`
  if $? != 0 or result == "" or result == nil
    return false, "command #{cmd} failed"
  end
  # Now check the how tsafs is loaded (command line switch)
  result.each do |line|
    if line.include?("tsafs") and (line =~ /(usecodeset\s*)=(.*)--.*/i or line =~ /(usecodeset\s*)=(.*)/i)
      # Above condition is to match follwing 2 cases
      # 1. if tsafs is loaded with --usecodeset=cpXXX --tsamode=linux...etc
      # 2. if tsafs is loaded with --tsamode=linux --usecodeset=cpxxx 
        if codepage.casecmp($2.strip) == 0
          return true, "Matched the codepage"
        else
          return false, "Codepage of destination does not match with source"
        end
    end
  end
  # tsafs is not loaded with usecodeset switch. Check the tsafs.conf file for this switch
  File.readlines("/etc/opt/novell/sms/tsafs.conf").each do |line|
    if line =~ /^#/
      next
    elsif line =~ /usecodeset/i
      codeset = line.split("=", 2) if line.include?("=")
      codeset = line.split(":", 2) if line.include?(":")
      if (codeset != nil and codeset != "" and codeset.size ==2 and codeset[1] != "" and codeset[1] != nil)
        if codepage.casecmp(codeset[1].strip) == 0
          return true, "Matched the codepage"
        else
          return false, "Codepage of destination does not match with source"
        end
      end
    end
  end  
  return false, "tsafs is not loaded with any codepage"
end
# This function takes source and destination credential details from user
def getCredentialDetails isPosix, sourceServer, destServer
  credentialDetails = {} # To store and return credentila details of source and destination
  # Get souce credentials first
  if not isPosix
    # Source path is either NSS or NCP
    credentials = Migration::KeyStore.credential(sourceServer, :ldap_dn, @opt['use-casa'])
    credentialDetails['source-username'] = Migration::KeyStore.credential(@opt['s'], :nds_dn, @opt['use-casa'])[:username]
    credentialDetails['ldapUserDN'] = credentials[:username]
  else
    # Source path is POSIX
    credentials = Migration::KeyStore.credential(sourceServer, :other, @opt['use-casa'])
    credentialDetails['source-username'] = credentials[:username]
  end
  #ENV['OES_DATA'] = credentials[:password]
  credentialDetails['source-password'] = credentials[:password]
  credentials = nil

  if destServer != nil
    # Now take destination credential details...
    credentials = Migration::KeyStore.credential(destServer, :other, @opt['use-casa'])
    credentialDetails['dest-username'] = credentials[:username]
    credentialDetails['dest-password'] = credentials[:password]
  end
  credentials = nil
  print_message(DEBUG, "Successfully taken credential Details of source and destination server from user")
  return credentialDetails
end

def verifyAndFixDestVol volName
  vol = nil
  mntpt = nil
  nss = false
  if volName
    vol = volName
    voldup=volName.dup
    voldup.sub!(":\\/", ":")
    voldup.sub!(":\\", ":")
    if voldup.include?(":")
      vol, extraPath = voldup.split(":")
    end
  end
   # First see whether it is NSS
  volume, mntpt = get_nss_vol_and_mnt_point_from_vol vol
  if volume == nil or mntpt == nil
    # That means given volume is not NSS. Try for NCP
    vol, mntpt = get_ncp_vol_and_mnt_point_from_vol(vol)
    if vol == nil or mntpt == nil
      print_message(FATAL, "Given volume #{vol} is neither NSS nor NCP")
      return nil, nss
    else
      print_message(INFO, "Given destination volume is of type NCP")
    end
  else 
    nss = true
    print_message(INFO, "Given destination volume is of type NSS")
  end
  print_message(DEBUG, "Successfully retrieved mount point: #{mntpt} from a given given volume: #{volName}")
  if extraPath == nil or extraPath == ""
    retPath = mntpt.chomp("/") + "/"
  else
    retPath = mntpt.chomp("/") + "/" + extraPath.chomp("/") + "/"
  end
  return retPath, nss   #if the path ends with / it wont add /, else it will
end

def verifyAndFixDestPath destPath
  nss = false
  # Try for NSS
  vol, mntpt = get_nss_vol_and_mnt_point_from_path destPath
  if vol == nil or mntpt == nil
    # It is not NSS path, try for NCP
    vol, mntpt = get_ncp_vol_and_mnt_point_from_path(destPath)
    if vol == nil or mntpt == nil
      print_message(INFO, "Given destination path is POSIX")
    else
      print_message(INFO, "Given destination path is NCP")
    end
  else
    nss = true
    print_message(INFO, "Given destination path is NSS")
  end
  return destPath.chomp("/") + "/", nss
end

#returns volName, mount
def verifyAndFixSrcPath volMap, opt
  return nil, nil, nil if volMap == nil or volMap.empty?

  if not opt['P'] # Source is Linux and NSS/NCP
    print_message(DEBUG, "Source server type: Linux")
    if opt['V']
      if opt['V'].include?(":")
        volName, extraPath = opt['V'].split(":")
        volName.strip!
        extraPath = extraPath[1, extraPath.length] if extraPath != nil and extraPath[0,1] == "/"
      else
        volName = opt['V']
      end
      if volMap.has_key?(volName)
        mntPt = volMap[volName][1]
      else
        print_message(WARN, "Failed to get mount point details from source path #{volName}")
        print_message(WARN, "Trying /media/nss/#{volName}")
        mntPt = "/media/nss/#{volName}/"
      end
       if extraPath == nil or extraPath == ""
         return volName, mntPt.chomp("/") + "/", mntPt.chomp("/") + "/"
       else
         return volName, mntPt.chomp("/") + "/", mntPt.chomp("/") + "/" + extraPath.chomp("/") + "/"
       end
    else
      fullPath = opt['X'].chomp('/') + "/"
      volMap.each_pair {|key, value|
        if fullPath.index(value[1].chomp("/") + "/") == 0
          return key, value[1].chomp("/") + "/", fullPath
        end
      }
      print_message(WARN, "Failed to get mount point details from source path #{opt['X']}")
      if opt['X'].index("/media/nss/") == 0
        volume = opt['X'].split("\/")[3]
        print_message(WARN, "Trying /media/nss/#{volume}")
        return volume, "/media/nss/#{volume}/", opt['X'].chomp('/') + "/"
      else
        return nil, nil, nil
      end
    end
  else # Must be source POSIX
    # -X is given, so blindly return the fullPath
    opt['X'] = opt['X'].chomp('/') + "/"
    return nil, nil, opt['X']
  end
end

# To support NCP as source, nbackup should execute with the root credentials. So to 
# identify and return the source volume type to migfiles, the below method has been added. This is to provide fix for bug #824782
#returns volName, mount
def verifyAndReturnSrcType volMap, opt, isNCP
  return nil if volMap == nil or volMap.empty?
  if not opt['P'] # Source is Linux and NSS/NCP
    print_message(DEBUG, "Source server type: Linux")
    if opt['V']
      if opt['V'].include?(":")
        volName, extraPath = opt['V'].split(":")
        volName.strip!
      else
        volName = opt['V']
      end
      if volMap.has_key?(volName)
        srcType = volMap[volName][0]
        if srcType.include?("NCP")
           return true
        else
	   return false
        end
      end
    end
  end
  return false
end

def getClusterDn credentialDetails,sourceServer
  clusterDn = nil
  host = "ldaps://#{sourceServer}"
  searchString = "nCSnetworkaddress=* dn ncsnetworkaddress"
  options = {}
  options[:password] = credentialDetails['source-password']
  print_message(DEBUG, "getclusterDn: ldapsearch command executed as 'ldapsearch -LLL -s sub -H #{host} -x -D \"#{credentialDetails['ldapUserDN']}\" #{searchString} -W'")
  cmd = "ldapsearch -LLL -s sub -H #{host} -x -D \"#{credentialDetails['ldapUserDN']}\" #{searchString} -W"
  result = executeLdapCmd(cmd, options)
  if result == nil or result == [] or result == ""
    print_message(WARN, "Source server #{sourceServer} is not part of cluster, ignoring --cluster option and continuing migration.")
    return nil
  else
    # Here we got something in result, This will display the result in following format...
    # dn:
    # Ncsnetworkaddress:
    # repeats above 2 lines... for each node
    encoded = false
    result.each do |line|
      if line.include?"dn::"
        #the match is encoded
        print_message(DEBUG, "cluster DN is encoded. Encoded dn is #{line}")
        extra, clusterDn = line.split("::", 2)
        clusterDn.lstrip!
        encoded = true
      elsif line.include?"dn:"
        extra, clusterDn = line.split(":", 2)
        clusterDn.lstrip!
      elsif line.include?"ncsnetworkaddress"
        if line.include?"::"
           # Encoded
           extra, add = line.split("::",2)
           add.strip! if add != nil and add != ""
           addressTmp = Base64.decode64(add)
           address = "#{addressTmp[2].to_i}.#{addressTmp[3].to_i}.#{addressTmp[4].to_i}.#{addressTmp[5].to_i}"
           if address.casecmp(sourceServer) == 0
             print_message(DEBUG, "Matched the given address #{sourceServer} with node #{address} and dn is #{clusterDn} ") 
             break
           end
        end
      else
        print_message(DEBUG, "cluster DN spawns across multiple lines.... here next part of DN is #{line}")
        clusterDn << line[1, line.length]
      end
    end
    if clusterDn != nil and clusterDn != ""
      if encoded
        clusterDn = Base64.decode64(clusterDn)
        print_message(DEBUG, "Cluster DN after decoding #{clusterDn}")
      end
      if clusterDn !~ /cn=.*cn=.*/
        # Here no need to spilt, since the given IP is resource IP
        # Just return clusterDn without any splits...
        print_message(DEBUG, "Given source server #{sourceServer} does not seems to be physical node")
        return clusterDn
      end
      extra, cluster = clusterDn.split(",", 2)
      print_message(DEBUG, "Returning cluster DN #{cluster}")
      return cluster.strip if cluster != nil and cluster != ""
    end
  end
end

def checkForCluster credentialDetails, sourceServer, volName, path
  # First check for cluster....
  # First check whether this node is part of cluster? If it then of which cluster?
  clusterDn = nil
  print_message(DEBUG, "Calling function getclusterDn")
  clusterDn = getClusterDn(credentialDetails, sourceServer)
  if clusterDn == nil || clusterDn == ""
    return nil
  end 
  print_message(DEBUG, "getclusterDn returned #{clusterDn}")
  # Now check whether the given volume is part of cluster?
  host = "ldaps://#{sourceServer}"
  options = {}
  options[:password] = credentialDetails['source-password']
  
  searchString = "'(&(nCSNetWareCluster=#{clusterDn}) (nCSVolumes=*))' nCSVolumes networkAddress"
  cmd = "ldapsearch -LLL -s sub -H #{host} -x -D \"#{credentialDetails['ldapUserDN']}\" #{searchString} -W"
  print_message(DEBUG, "checkForCluster: ldapsearch exectued as #{cmd}")
  result = executeLdapCmd(cmd, options)
  if result == nil || result == "" || result == []
    print_message(WARN, "Could not find any active cluster volumes on given source server. Ignoring --cluster option and continuing migration.")
    return nil
  else
    # First let us check whether given volume is a cluster resource? If volume is a cluster resource then
    # Its name should be "Clustername_volumename". So check for this
    # Below 2 lines get us cluster name out of ClusterDn
    cluster, extra = clusterDn.split(",", 2)
    clusterName, extra = cluster[3..cluster.length].split(",", 2) if cluster != nil and cluster != ""
    clusterVol = false
    actAddress = nil
    result.each do |line|
      if line.include?"nCSVolumes:"
        print_message(DEBUG, "This cluster contains volume #{line}")
        extra, vname = line.split(":",2)
        vname.strip! if vname != nil and vname != ""
        # Here vname will be something like this 'cn=cluster_CVOL1,ou=servers,o=novell'. Since volume name
        # starts with cn=clusterName we need to slice the vname from clusterName.length+4 till we find ','
        # Below statement will give us plain volume name in this case it is 'CVOL1' 
        actvname = vname[clusterName.length+4..vname.index(",")-1]
        print_message(DEBUG, "Final volume name #{actvname}")
        if volName
          if volName.casecmp(actvname) == 0
            print_message(INFO, "Given volume is part of cluster resources")
            clusterVol = true
            break
          else
            next
          end
        else
           # X option is given, so need to get mount point also
           # Again form a ldap command and get mount point details for each source volume
           searchString = "cn=#{clusterName}_#{actvname} linuxNCPMountPoint"
           cmd = "ldapsearch -LLL -s sub -H #{host} -x -D \"#{credentialDetails['ldapUserDN']}\" #{searchString} -W"
           print_message(DEBUG, "checkForCluster: option 'X' is passed. ldapsearch command 'ldapsearch -LLL -s sub -H #{host} -x -D \"#{credentialDetails['ldapUserDN']}\" #{searchString} -W'")
           result = executeLdapCmd(cmd, options)
           vol, mntpt, type = getMountPointDetails(result, nil, false, path)
           if vol == nil or mntpt == nil
             next
           else
             print_message(INFO, "Given volume is part of cluster resources")
             clusterVol = true
             break
           end
        end
      end
      if line.include?"networkAddress"
        if line.include?"::"
          # Encoded
          ex, add = line.split("::",2)
          add.strip!
          address = Base64.decode64(add)
          actAddress = "#{address[4].to_i}.#{address[5].to_i}.#{address[6].to_i}.#{address[7].to_i}"
          print_message(DEBUG, "Network address of resource is #{actAddress}")
        end
      end
    end # result.each
  end
  if clusterVol and actAddress != nil
    return actAddress, clusterName
  else
    print_message(WARN, "Could not find given source volume in the list of active cluster volumes. Ignoring --cluster option and continuing migration.")
    return nil
  end
end

def sendForClusterChk credentialDetails, sourceServer, volName, fullPath
  resourceIp = nil
  if volName != nil and volName.include?(":")
    vol, extraPath = volName.split(":")
    vol.strip! if vol != nil and vol != ""
  end
  clusterName = nil
  resourceIp = nil
  resourceIp, clusterName = checkForCluster(credentialDetails, sourceServer, vol, fullPath)
  if resourceIp != nil and resourceIp != ""
    # Change the given IP address to resource IP which we got from above function
    print_message(INFO, "Identified the cluster resource IP address as #{resourceIp} for volume #{vol}")
    # Store it once and check remaining all IP addresses should match this. Otherwise that means given paths are
    # from different cluster pools. exit if it is the case
      # Compare the resourceIp address with the original one 
  end
  return resourceIP, clusterName
end

def processFileAndGetClusterInfo inputFileName, sourceServer, forMigfiles
  clusterIpAddress = nil
  clusterName = nil
  clusterIp = nil
  File.readlines(inputFileName).each do |singlePath|
    volName = nil
    fullPath = nil
    if singlePath != nil and singlePath != ""
      singlePath.strip!
      if forMigfiles
        splitInfo = singlePath.split("\t")
        if splitInfo != nil and splitInfo != "" and splitInfo.lenght == 2
          singlePath = splitInfo[0].strip!
        else
          print_message(FATLA, "Given input file #{inputFile} is not in correct format\n. File should contain list of source and destination path pairs separated by TAB character.")
          exit 1
        end
      end
      if singlePath.include?(":")
        # Must be a volume name. So set volName arg
        volName = singlePath
      else
        fullPath = singlePath
      end
      clusterIp, clusterName = sendForClusterChk(credentialDetails, sourceServer, volName, fullPath)
      if clusterIpAddress == nil
         clusterIpAddress = clusterIp
      elsif clusterIpAddress != clusterIp
        print_message(FATAL, "Given volumes are either from two different cluster pools or one is part of cluster and the other is not. Please check")
        exit 1
      end
    end # if singlepath != nil
  end # File.readlines
end

#This function gets all the NSS/NCP volumes and thier mount points
#The return value is a map["volname"] = [NSS/NCP, /mount/point]
#First tries smstool --list-cluster-volumes to get cluster volumes if cluster IP
#Then tries ldapsearch if not cluster
def getVolumesAndMountPoints credentialDetails, opt
  volList = {}
  ENV["USER_PASSWORD_REMOTE"] = credentialDetails['source-password']
  print_message(DEBUG, "smstool command executed from getVolumesAndMountPoints as LC_ALL=en_US.UTF-8 /opt/novell/sms/bin/smstool -U \"#{credentialDetails['source-username']}\" -R #{opt['s']} --list-cluster-volumes")
  result1 = `LC_ALL=en_US.UTF-8 /opt/novell/sms/bin/smstool -U \"#{credentialDetails['source-username']}\" -R #{opt['s']} --list-cluster-volumes 2>&1`
  if $? == 0 and result1 != nil and result1 != ""
    result = result1.split("\n")
    result.each { |line|
      #If standard output has SMDR debugging statements then dont process and write to file
      #This fix is provided for bug #777005
      if line.include? "SMDR Debug Log" or line.include? "SMDR:###SMSDEBUG###"
        next
      end
      volume, mountPt = line.split("\t")
      volume.chomp!(":") if volume.include?(":")
      if mountPt != nil and volume != nil and mountPt != "" and volume != ""
        volList[volume] = Array["NSS",  mountPt.strip]  #smstool only returns NSS volumes
      end
    }
    if volList != nil and !volList.empty?
        return volList
    end
  end
  print_message(DEBUG, "smstool has not returned any cluster volumes")
  useSecure = true
  useSecure = false if opt['source-unsecure-ldap']
  # Get the source server name which, we can pass it to ldap command
  #host = getHostString(opt['s'], useSecure, opt['source-ldap-port'])
  source_server_name = server_name(opt['s'])
  if source_server_name == nil
    print_message(FATAL, "Unable to get source server name. Ensure eDir is running.")
    exit 1
  end
  context = server_context(opt['s'])
  if context == nil
    print_message(FATAL, "Unable to get source server context. Ensure eDir is running.")
    exit 1
  end
  searchString = source_server_name + "_" + "*"

  #The source server can be a dsfw server, then in that case we have to use dsfw port
  #Fix for BugZilla#742453
  dsfwresult = ""
  #/opt/novell/eDirectory/bin/ldapsearch -x -h 164.99.101.82 -s base -b "" | grep 2.16.840.1.113719.1.513.7.1
  #dsfwcmd = "/opt/novell/eDirectory/bin/ldapsearch -x -h #{@opt['s']} -s base -b \"\" | grep 2.16.840.1.113719.1.513.7.1"
  dsfwcmd = "/usr/bin/ldapsearch -x -h #{@opt['s']} -s base -b \"\" | grep 2.16.840.1.113719.1.513.7.1"
  print_message(INFO, "ldapsearch command executed as #{dsfwcmd}")
  dsfwresult = `#{dsfwcmd}`
  #If the source is NW or non-DSfW OES server, return value will be non-zero
  if $? != 0
      print_message(INFO, "ldapsearch has not identified #{@opt['s']} as DSfW server.")
  end
  if not dsfwresult.nil? and not dsfwresult.empty? and dsfwresult.include?("supportedCapabilities: 2.16.840.1.113719.1.513.7.1")
      port = "1636"
  else
      port = @opt['source-ldap-port']
  end

  #Now get host string
  host = getHostString(@opt['s'], useSecure, port)
  cmd = "ldapsearch -LLL -s sub -H #{host} -x -D \"#{credentialDetails['ldapUserDN']}\" \"(&(#{searchString})(|(objectClass=Volume)(objectClass=ndsVolume)))\" linuxNCPMountPoint -W"
  print_message(DEBUG, "ldapsearch command executed as #{cmd}")
  options = {}
  options[:password] = credentialDetails['source-password']
  result = executeLdapCmd(cmd, options)
  i = 0
  volume = type = mountPt = ""
  while i < result.length
    attrib = result[i]
    encoded = false
    if attrib.include?("::")
      a, v = attrib.split("::", 2)
      encoded = true
    else
      a, v = attrib.split(":",2)
    end
    if v != nil and v!= ""
      v.strip!
      j = i + 1
      while (result[j] != nil and result[j].index(":") == nil)
        v << result[j][1, result[j].length].rstrip
        i = i + 1
        j = j + 1
      end
      if encoded
        val = Base64.decode64(v)
      else
        val = v
      end
      if a == "linuxNCPMountPoint"
        if val.include?("NSS")
          type = "NSS"
        else
          type = "NCP"
        end
        if val.include?("/")
          # val is either nil or does not include "/", so display warning message and continue.
          # In case if source is a OES1 server and volume is XFS mounted, then ldapsearch result
          # will be something like this:
          # 'dn: cn=prpe-fs2_SYS,ou=SERVIDOR,ou=CPD,ou=CODIJUR,o=PRPE  
          # linuxNCPMountPoint: XFS  '
          # Note that it does not inlcude "/"

          mountPt = val[val.index("\/"), val.size]
          if mountPt != nil and volume != nil and mountPt != "" and volume != ""
            volList[volume] = Array[type,  mountPt.strip]
          end
        else
          if volume != nil and volume != ""
            print_message(WARN, "Could not get mount point for volume #{volume}, val = #{val}")
          else
            print_message(WARN, "Could not get mount point for one of the source volume, val = #{val}")
          end
        end
        volume = type = mountPt = ""
      elsif result[i+1] != nil and result[i+1].include?("linuxNCPMountPoint")
        volume = val[source_server_name.length+1..val.index(",")-1]
      end
    else
      if volume != nil and volume != ""
        print_message(WARN, "Could not get mount point for volume #{volume}")
      else
        print_message(WARN, "Could not get mount point for one of the source volume")
      end
    end
    i = i + 1
  end if result != nil
  return volList
end

#If for a path a shadow volume exists then this function returns
#the shadow path. So if the path passed in was /media/nss/DST/test
#and a shodow volume exists /media/shadowfs/DST/ then this function
#will retrun /media/shadowfs/DST/test.
#migfiles when syncing will use the shadow path for comparison
def getShadowFSPath destPath
  if File.size?("/etc/mtab.shadowfs") != nil
    if not defined?(@primary) #this is done so that the XML is parsed only once
      file = File.open("/etc/mtab.shadowfs", 'r')
      doc = REXML::Document.new file
      @primary = []
      doc.elements.each("SHADOWFS_MOUNTPOINTS/MOUNTPOINT/PRIMARY_TREE") { |element|
        element.each { |elem| @primary << elem.to_s.chomp("/") + "/" }
      }
      @shadow = []
      doc.elements.each("SHADOWFS_MOUNTPOINTS/MOUNTPOINT/PATH") { | element|
        element.each { |elem| @shadow << elem.to_s.chomp("/") + "/" }
      }
    end

    @primary.each_index { |i|
      if (destPath.index(@primary[i]) == 0)
        shadowPath = "#{@shadow[i]}#{destPath[@primary[i].length, destPath.length]}"
        return shadowPath
      end
    }
    return nil
  else
    return nil
  end
end

def getDNOfVolume volume
  result = NSS.instance.get_vol_info(volume)
  if result =~ /<ndsVolumeName>(.*)<\/ndsVolumeName>/
    requiredString = $1
    # Here ndsVolumeName will have format as follow
    # .CN=cluster_TESTTGT.O=novell.T=LNX-VM-NCS-TREE.

    # To get serverName we need to ignore leading "." and traverse till the point
    # where volume name starts (_TESTTGT).
    serverName = requiredString.slice(1..requiredString.index("_"+volume)-1)

    # To get server context we need to move till O= (i.e length of serverName and volumeName). Adding
    # 3 for leading ".", "_" and next "." 
    serverContext = requiredString.slice(3+serverName.length+volume.length..requiredString.index(".T=")-1)
    serverContext.gsub!(".", ",") if serverContext != nil and serverContext != ""
    return serverName, serverContext
  end
  print_message(WARN, "Could not get server name and server context from _ADMIN, using default values")
  return nil, nil
end

def readPassword messageToDisplay
  passwd = nil
  # Turn off the echo on terminal
  begin
    $stderr.print messageToDisplay
    if $stdin.isatty # Is there any terminal?
      `stty -echo`
    end
    passwd = $stdin.gets.chomp
    `stty echo 2> /dev/null`
  ensure
    if $stdin.isatty
      `stty echo 2>/dev/null`
    end
  end
  return passwd
end

end

