# Copyright (C) [2006-2007] Novell, Inc.  All Rights Reserved.

# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# IT MAY NOT BE USED, COPIED, DISTRIBUTED, DISCLOSED, ADAPTED, PERFORMED,
# DISPLAYED, COLLECTED, COMPILED, OR LINKED WITHOUT NOVELL'S PRIOR WRITTEN
# CONSENT.  USE OR EXPLOITATION OF THIS WORK WITHOUT AUTHORIZATION COULD
# SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.

# NOVELL PROVIDES THE WORK "AS IS," WITHOUT ANY EXPRESS OR IMPLIED WARRANTY,
# INCLUDING WITHOUT THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE, AND NON-INFRINGEMENT. NOVELL, THE AUTHORS OF THE WORK,
# AND THE OWNERS OF COPYRIGHT IN THE WORK ARE NOT LIABLE FOR ANY CLAIM, DAMAGES,
# OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT, OR OTHERWISE,
# ARISING FROM, OUT OF, OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER
# DEALINGS IN THE WORK.
require 'singleton'
require 'rexml/document'
require 'socket'

module Migration
	MANAGE="/_admin/Manage_NSS/manage.cmd"
	FILES="/_admin/Manage_NSS/files.cmd"
	#These are used in set_attrs and are copied from bits.h of nwos
	READ_ONLY_BIT=		0x00000001
	HIDDEN_BIT=		0x00000002
	SYSTEM_BIT=		0x00000004
	EXECUTE_BIT=		0x00000008
	SUBDIRECTORY_BIT=	0x00000010
	ARCHIVE_BIT=		0x00000020
	SHAREABLE_BIT=		0x00000080	#Valid only on files
	TRANSACTION_BIT=	0x00001000
	IMMEDIATE_PURGE_BIT=	0x00010000
	RENAME_INHIBIT_BIT=	0x00020000
	DELETE_INHIBIT_BIT=	0x00040000
	COPY_INHIBIT_BIT=	0x00080000
	REMOTE_DATA_ACCESS_BIT=	0x00400000	#ie. Data Migration (file only) 
	REMOTE_DATA_INHIBIT_BIT=0x00800000	#ie. Data Migration (file only)
	COMPRESS_FILE_IMMEDIATELY_BIT=0x02000000#immediately try to compress this file or subdirectory 
	DATA_STREAM_IS_COMPRESSED_BIT=0x04000000#per data stream directory entry 
	DO_NOT_COMPRESS_FILE_BIT=0x08000000	#don't compress this file or subdirectory ever
	CANT_COMPRESS_DATA_STREAM_BIT=0x20000000#can't save any space by compressiong this data stream
	ATTR_ARCHIVE_BIT=	0x40000000	#Object Archive Bit  (EAs, OwnerID, Trustees) 
	ZFS_VOLATILE_BIT=	0x80000000	
	class NSS; end
	class Cmd; end
end

class Migration::Cmd
	attr_accessor :name, :xml, :resp_hash, :p, :type

	def initialize(name, xml, type = MANAGE, p = false, resp_hash = nil )
		@name = name
		@xml = xml
		@resp_hash = resp_hash
		@p = p
		@type = type
	end
end

class Migration::NSS
	include Singleton
	include REXML
	
	########begin volume commands############## 
	
	def display_volume vol = nil
		str = ""
		str = vols 
		puts str
	end

	def vol_exists? name
		return false
	end

	def create_volume pool, volume
		#puts "NSS.instance.create_volume #{pool}, #{volume}"
		cmd = <<-END 
		<nssRequest>
		<volume><addVolume state=\"mounted\">
		<volumeName>#{volume}</volumeName>
		<poolName>#{pool}</poolName>
		<context/>
		<ndsPoolName/>
		<ndsName/>
		</addVolume></volume>
		</nssRequest>
		END
	
		$MIGERROR = "volume #{volume}"
		command Cmd.new(:create_volume, cmd, Migration::MANAGE, false, Hash[Migration::EMIGALREADYEXISTS => "ERR_DUPLICATE_VOLUME_NAME",Migration::EMIGBADNAME => "ERR_BAD_VOLUME_NAME_CHARACTER"])
	end

	def delete_volume volume
		cmd = <<-END
		<nssRequest>
		<volume>
		<removeVolume>
		<volumeName>#{volume}</volumeName>
		</removeVolume>
		</volume>
		</nssRequest>
		END

		command Cmd.new(:delete_volume, cmd)
	end

	def set_file_quota filename, quota
		cmd = <<-END
		<fileRequest>
		<directoryQuotas>
		<addQuota>
		<fileName>#{filename}</fileName>
		<quotaAmount>#{quota}</quotaAmount>
		</addQuota>
		</directoryQuotas>
		</fileRequest>
		END

		command Cmd.new(:set_file_quota, cmd, Migration::FILES, false, Hash[Migration::EMIGBADFILENAME => "ERR_PATH_MUST_BE_FULLY_QUALIFIED"])
	end

	def get_file_quota filename
		cmd = <<-END 
		<fileRequest>
		<fileInfo>
		<getFileInfo>
		<fileName>#{filename}</fileName>
		<typeOfInfo>
		<rightsInfo>
		<standardInfo>
		<timeInfo>
		<idInfo>
		<directoryQuotaInfo>
		<quotaAmount>
		<usedAmount>
		</directoryQuotaInfo>
		</typeOfInfo>
		</getFileInfo>
		</fileInfo>
		</fileRequest>
		END
		command Cmd.new(:get_file_quota, cmd, Migration::FILES, true, Hash[Migration::EMIGBADFILENAME => "ERR_PATH_MUST_BE_FULLY_QUALIFIED"])
	end

	def set_user_quota vol, username, quota
		if quota.to_s.include?("NO LIMIT")
			cmd = <<-END
			<nssRequest>
			<userSpaceRestriction>
			<set>
			<volumeName>#{vol}</volumeName>
			<userName>#{username}</userName>
			<noQuota/>
			</set>
			</userSpaceRestriction>
			</nssRequest>
			END
		else
			cmd = <<-END
			<nssRequest>
			<userSpaceRestriction>
			<set>
			<volumeName>#{vol}</volumeName>
			<userName>#{username}</userName>
			<quota>#{quota}</quota>
			</set>
			</userSpaceRestriction>
			</nssRequest>
			END
		end
		command Cmd.new(:set_user_quota, cmd)
	end

	def add_extended_attrs filepath, attrs 
		cmd = <<-END
		<fileRequest>
		<fileInfo>
		<setFileInfo>
		<fileName>#{filepath}</fileName>
		<owner>
		<attributes>
		<readOnly enabled="no"></readOnly>
		<hidden enabled="yes"></hidden>
		<system enabled="no"></system>
		<execute enabled="no"></execute>
		<archive enabled="yes">
		</setFileInfo>
		</fileInfo>
		</fileRequest>
		END
		command Cmd.new(:add_extended_attrs, cmd, Migration::FILES, true, Hash[Migration::EMIGBADFILENAME => "ERR_PATH_MUST_BE_FULLY_QUALIFIED"])
	end


	def set_fileIds filename, owner, modifier 
		localIp = getLocalIPAddress
		if localIp == nil
			print_message(ERROR, "Failed to get IP address of local server")
			raise
		end

		treeName = get_nds_tree localIp
		modif = ""
		creator = ""
		if modifier != nil and owner != nil
			modif = "." + modifier + ".T=" + treeName + "."
			modif = modif.gsub(",", ".")
		end
		if owner != nil and owner != nil
			creator = "." + owner + ".T=" + treeName + "."
			creator = creator.gsub(",", ".")
		end

		
		
		if modifier != nil

			cmd = <<-END
			<fileRequest>
			<fileInfo>
			<setFileInfo>
			<fileName>#{filename}</fileName>
			<idInfo>
			<modifier>#{modif}</modifier>				
			<creator>#{creator}</creator>
			</idInfo>
			</setFileInfo>
			</fileInfo>
			</fileRequest>
			END
					
		end

		if modifier == nil

			cmd = <<-END
			<fileRequest>
			<fileInfo>
			<setFileInfo>
			<fileName>#{filename}</fileName>
			<idInfo>				
			<creator>#{creator}</creator>
			</idInfo>
			</setFileInfo>
			</fileInfo>
			</fileRequest>	
			END

		end
		

		command Cmd.new(:set_fileIds, cmd, Migration::FILES, false, Hash[Migration::EMIGBADFILENAME => "ERR_PATH_MUST_BE_FULLY_QUALIFIED"])
	end

	def vols
		cmd = "<nssRequest><listVolumes/></nssRequest>"
		display_command Cmd.new(:vols, cmd)
	end
	########end volume commands############## 
	
	########begin pool commands############## 
	def display_pool 
		str = ""
		str = free_space
		str += partitions
		str += pools
		str += devices
		return str
	end

	def pool_exists?
		return false
	end

	def create_pool device, pool
		devices
		free_space
		pools
		cmd = <<-END 
		<nssRequest>
		<pool>
		<addPool2 state="active">
		<poolName>#{pool}</poolName>
		<ndsName>
		</ndsName>
		<context>
		</context>
		<devices>
		<addPoolDeviceInfo>
		<objectID>sdc</objectID>
		<size>1248854016</size>
		<lssType>ZLSS</lssType>
		</addPoolDeviceInfo>
		</devices>
		</addPool2>
		</pool>
		</nssRequest>
		END
		command Cmd.new(:create_pool,cmd)
	end

	def delete_pool pool
		cmd = <<-END
		<nssRequest>
		<pool>
		<removePool2>
		<poolName>#{pool}</poolName>
		<removeNDSObject>
		</removeNDSObject>
		</removePool2>
		</pool>
		</nssRequest>
		END
		command Cmd.news(:delete_pool, cmd)
	end

	def default_names pool
		cmd = <<-END
		<nssRequest>
		<getDefaultClusterNames>
		<poolName>#{pool}</poolName>
		</getDefaultClusterNames>
		</nssRequest>
		END
		command Cmd.new(:default_names,cmd)
	end

	def pools
		cmd = "<nssRequest><server><listPools/></server></nssRequest>"
		command Cmd.new(:pools,cmd)
	end

	def devices
		cmd = "<nssRequest><listDevices type=\"all\"/></nssRequest>"
		command Cmd.new(:devices,cmd)
	end

	def partitions
		cmd = "<nssRequest><listPartitions type=\"all\"/></nssRequest>"
		command Cmd.new(:partitions,cmd)
	end
	
	def free_space
		cmd = "<nssRequest><server><getServerFreeSpace/></server></nssRequest>"
		command Cmd.new(:free_space,cmd)
	end
	########end pool commands############## 

	def set_attrs file, attrs
		cmd = <<-END
			<nssRequest>
			<fileRequest> 
			<fileInfo>
			<setFileInfo>
			<fileName>#{file}</fileName>
			<attributes>
			END

		#We don't want to set the remoteDataAccess and dataStreamCompress bits even if set
		#because the files would have been demigrated and decompressed, so those lines are 
		#commented
		cmd = cmd + "<readOnly enabled=\"yes\"/>" if attrs & READ_ONLY_BIT != 0
		cmd = cmd + "<hidden enabled=\"yes\"/>" if attrs & HIDDEN_BIT != 0
		cmd = cmd + "<system enabled=\"yes\"/>" if attrs & SYSTEM_BIT != 0
		cmd = cmd + "<execute enabled=\"yes\"/>" if attrs & EXECUTE_BIT != 0 
		cmd = cmd + "<archive enabled=\"yes\"/>" if attrs & ARCHIVE_BIT != 0
		cmd = cmd + "<sharable enabled=\"yes\"/>" if attrs & SHAREABLE_BIT != 0
		cmd = cmd + "<transaction enabled=\"yes\"/>" if attrs & TRANSACTION_BIT != 0
		cmd = cmd + "<immediatePurge enabled=\"yes\"/>" if attrs & IMMEDIATE_PURGE_BIT != 0
		cmd = cmd + "<renameInhibit enabled=\"yes\"/>" if attrs & RENAME_INHIBIT_BIT != 0
		cmd = cmd + "<deleteInhibit enabled=\"yes\"/>" if attrs & DELETE_INHIBIT_BIT != 0
		cmd = cmd + "<copyInhibit enabled=\"yes\"/>" if attrs & COPY_INHIBIT_BIT != 0
#		cmd = cmd + "<remoteDataAccess enabled=\yes\"/>" if attrs & REMOTE_DATA_ACCESS_BIT != 0
		cmd = cmd + "<remoteDataInhibit enabled=\"yes\"/>" if attrs & REMOTE_DATA_INHIBIT_BIT != 0
		cmd = cmd + "<compressImmediate enabled=\"yes\"/>" if attrs & (COMPRESS_FILE_IMMEDIATELY_BIT + DATA_STREAM_IS_COMPRESSED_BIT) !=0
#		cmd = cmd + "<dataStreamCompress enabled=\"yes\"/>" if attrs & DATA_STREAM_IS_COMPRESSED_BIT != 0
		cmd = cmd + "<doNotCompress enabled=\"yes\"/>" if attrs & DO_NOT_COMPRESS_FILE_BIT != 0
		cmd = cmd + "<noStreamCompress enabled=\"yes\"/>" if attrs & CANT_COMPRESS_DATA_STREAM_BIT != 0
		cmd = cmd + "<attrArchive enabled=\"yes\"/>" if attrs & ATTR_ARCHIVE_BIT != 0
		cmd = cmd + "<volatile enabled=\"yes\"/>" if attrs & ZFS_VOLATILE_BIT != 0
		cmd = cmd + "</attributes></setFileInfo></fileInfo></fileRequest>"
		command Cmd.new(:set_attrs, cmd, Migration::FILES)
                if attrs & (COMPRESS_FILE_IMMEDIATELY_BIT + DATA_STREAM_IS_COMPRESSED_BIT) == DATA_STREAM_IS_COMPRESSED_BIT
                        cmd.gsub!(/compressImmediate enabled="yes"/, "compressImmediate enabled=\"no\"")
                        command Cmd.new(:set_attrs, cmd, Migration::FILES)
                end
	end
  

       def list_pools adminfsFile=MANAGE
                cmd = "<nssRequest>
				<server>
					<listPools/>
				</server>
			</nssRequest>"

		result = command Cmd.new(:list_pools, cmd, adminfsFile)

		a = []
		result.each_line { |line|
			if line.include?("<poolName>")
				line =~ %r{<poolName>(.*)</poolName>}
				a << $1
			end
		}
		return a
	end

	def list_volumes adminfsFile=MANAGE
		cmd = "<nssRequest>
				<volume>
					<listVolumes>
						<volumeName type=\"nss\"/>
					</listVolumes>
				</volume>
			</nssRequest>"

		result = command Cmd.new(:list_volumes, cmd, adminfsFile)
		a = []
		result.each_line { |line|
			if line.include?("<volumeName type=\"nss\">")
				line =~ %r{<volumeName type="nss">(.*)</volumeName>}
				a << $1
			end
		}
		return a
        end

	def get_vol_info vol, adminfsFile=MANAGE
		cmd = "<nssRequest>
				<volume>
					<getVolumeInfo type=\"all\">
						<volumeName>#{vol}</volumeName>
					</getVolumeInfo>
				</volume>
			</nssRequest>"

		command Cmd.new(:get_vol_info, cmd, adminfsFile)
	end

	def display_command cmd
		puts "cmd: #{cmd.xml}"
		File.open MANAGE, File::RDWR do |f|
			f.write("<virtualIO><datastream name=\"command\" /></virtualIO>") 	
			#f.seek(0, IO::SEEK_SET)
			#puts "command: #{f.sysread(10000)}"
			f.write(cmd.xml) 	
			f.seek(0, IO::SEEK_SET)
			puts "command: #{f.sysread(10000)}"
			f.seek(0, IO::SEEK_SET)
			reply  = f.sysread(10000)
			if reply.include? "error" or reply.include? "Error"
				raise SystemCallError.new("nss: command error\n", Migration::ENOTEXIST)
			end
		end
	end

	def command cmd
		puts "cmd.name: #{cmd.name}" if cmd.p
		puts "cmd.xml: #{cmd.xml}" if cmd.p
		puts "cmd.type: #{cmd.type}" if cmd.p
		File.open cmd.type, File::RDWR do |f|
			f.write("<virtualIO><datastream name=\"command\" /></virtualIO>") 	
			#f.seek(0, IO::SEEK_SET)
			#puts "command: #{f.sysread(10000)}"
			f.write(cmd.xml) 	
			f.seek(0, IO::SEEK_SET)
			#puts "command: #{f.sysread(10000)}"
			f.seek(0, IO::SEEK_SET)
			reply  = f.sysread(10000)
			puts reply if cmd.p 
			if reply.include? "error" or reply.include? "Error" or reply.include? "zERR"
				raise MigrationException.new(cmd.name.to_s, "failed:" + reply) 
			end
			unless cmd.resp_hash == nil
				cmd.resp_hash.each do |k,v|
					if reply.include? v
						raise MigrationException.new(k,caller)
					end
				end
			end
			return reply
		end
	end
end

