# Copyright (C) [2006-2007] Novell, Inc.  All Rights Reserved.

# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# IT MAY NOT BE USED, COPIED, DISTRIBUTED, DISCLOSED, ADAPTED, PERFORMED,
# DISPLAYED, COLLECTED, COMPILED, OR LINKED WITHOUT NOVELL'S PRIOR WRITTEN
# CONSENT.  USE OR EXPLOITATION OF THIS WORK WITHOUT AUTHORIZATION COULD
# SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.

# NOVELL PROVIDES THE WORK "AS IS," WITHOUT ANY EXPRESS OR IMPLIED WARRANTY,
# INCLUDING WITHOUT THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE, AND NON-INFRINGEMENT. NOVELL, THE AUTHORS OF THE WORK,
# AND THE OWNERS OF COPYRIGHT IN THE WORK ARE NOT LIABLE FOR ANY CLAIM, DAMAGES,
# OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT, OR OTHERWISE,
# ARISING FROM, OUT OF, OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER
# DEALINGS IN THE WORK.
require 'optparse'

module Migration    
  def Migration.parse_args( args, arg_sym )
    args_def = []
    ordinals = []
    options = Hash.new( false )

    if Migration::Arguments.const_defined? arg_sym.to_s.upcase
       puts "OptionParser: Setting arguments for: #{arg_sym.to_s}" if $MIG_DEBUG
       args_ref = (Migration::Arguments.const_get arg_sym.to_s.upcase.to_sym)
       args_ref.each_index { |x| args_def[x] = args_ref[x].dup }
    else
      raise MigrationException.new("Arguments are not well defined this is a Options bug.")
    end

    opts = OptionParser.new do |opts|
      banner = args_def.shift
      if banner.length > 1
        puts "OptionParser: Banner is long" if $MIG_DEBUG
        opts.banner = Migration::Arguments::PARSE_ARGS[:long]
      else
        puts "OptionParser: Banner is short" if $MIG_DEBUG      
        opts.banner =  Migration::Arguments::PARSE_ARGS[:short]        
      end
  
      opts.separator ""
      opts.separator Migration::Lang::OPTS_SPEC
    
      args_def.each do |arg_def|
        arg_def.push class_types(arg_def.pop)
             
        if arg_def.last == :ordinal or
           arg_def.last == :ordinal_glob
         
          puts "OptionParser: #{arg_def.first} option is of type ordinal" if $MIG_DEBUG 
           
          ordinals << arg_def
          next
        end
      
        key = arg_def.shift
        
        puts "OptionParser: Key '#{key}' and args: #{arg_def.join(',')}" if $MIG_DEBUG
        
        opts.on( *arg_def ) do |o|
          puts "OptionParser:#{key}: #{o}" if $MIG_DEBUG
          
          options[key] = o
        end
      end
      
      opts.separator ""
      opts.separator Migration::Lang::OPTS_COMMON   

      # No argument, shows at tail.  This will print an options summary.
      opts.on_tail( *Migration::Arguments::PARSE_ARGS[:help]) do
        puts opts
        exit 0
      end

      # Another typical switch to print the version.
      opts.on_tail( *Migration::Arguments::PARSE_ARGS[:version]) do
        puts Migration::Version.join('.')
        exit 0
      end      
    end
       
    begin   
      extra_args = opts.parse!(args)
    rescue => message
      raise MigrationException.new( Migration::Lang::E_PROCARGS, {:m => message} )
    end
      
    extra_args.each do |ord_arg| 
      unless ordinals.empty?
        ord = ordinals.shift
        if ord.last == :ordinal
          options[ord.first] = ord_arg
          extra_args.shift
        elsif ord.last == :ordinal_glob
          options[ord.first] = extra_args
          break
        end
      else
        values = {}
        extra_args.each_index { |x| values[x] = extra_args[x]}
        raise MigrationException.new( Migration::Lang::E_INVALIDARGS, values)
      end
    end

    options
  end
  
  private
  def Migration.class_types( type )
    return case type
      when "\:DecimalInteger"
	OptionParser::DecimalInteger
      when "\:OctalInteger"  
	OptionParser::OctalInteger
      when "\:DecimalNumeric"
	OptionParser::DecimalNumeric
      when "\:Ordinal"  "\:ordinal"
      when "\:OrdinalGlob"  "\:ordinal_glob"
      when "\:Object"  
	Object
      when "\:String"
	  String
      when "\:Integer"
	  Integer
      when "\:Float"  
	Float
      when "\:Numeric"
	  Numeric
      when "\:Array"
	  Array
      when "\:TrueClass"
	  TrueClass
      when "\:FalseClass"
	  FalseClass
      end
  end
end
