# Copyright (C) [2006-2007] Novell, Inc.  All Rights Reserved.

# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# IT MAY NOT BE USED, COPIED, DISTRIBUTED, DISCLOSED, ADAPTED, PERFORMED,
# DISPLAYED, COLLECTED, COMPILED, OR LINKED WITHOUT NOVELL'S PRIOR WRITTEN
# CONSENT.  USE OR EXPLOITATION OF THIS WORK WITHOUT AUTHORIZATION COULD
# SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.

# NOVELL PROVIDES THE WORK "AS IS," WITHOUT ANY EXPRESS OR IMPLIED WARRANTY,
# INCLUDING WITHOUT THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE, AND NON-INFRINGEMENT. NOVELL, THE AUTHORS OF THE WORK,
# AND THE OWNERS OF COPYRIGHT IN THE WORK ARE NOT LIABLE FOR ANY CLAIM, DAMAGES,
# OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT, OR OTHERWISE,
# ARISING FROM, OUT OF, OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER
# DEALINGS IN THE WORK.

# :title: Novell Migration Utility - ntuserls
# ==Description: 
# I wish this never had to exist.  The PTY module fails on several different conditions.
# This should help to help get the commands to finish. See the TestCase for a example.
# 

require 'pty'
require 'expect'

class PTYError < StandardError
  attr_accessor :output
  
  def initialize( output )
    @output = output
  end    
  
  # TODO: Remove before ship! DEBUG
  def to_s
    super.to_s + "\nOUTPUT: #{@output}"
  end  
end
           
module PTY
  unless defined? DEFAULT_RETRY
    DEFAULT_RETRY = 2
  end
  unless defined? DEFAULT_REGEX
    DEFAULT_REGEX = %r/Password.*:/
  end

  # Valid options are:
  #   :password => 'plain text password'
  #   :password_regex => %r/Password.*:/
  #   :retry_count => 2
  def PTY.safe_spawn( command, options = {} )
    found_password = false
    io_value = ""  
    retry_count = 0
    values = [] unless block_given?
    
    options[:retry_count] = options[:retry_count] || DEFAULT_RETRY
          
    begin
      PTY.spawn( command ) do | read_io, write_io, pid |
       read_io.sync = true
       write_io.sync = true
 
# options[:passord] will be nil if we already set the password in env
# variable
       if options[:password] != nil
         if options.has_key?( :password )
           options[:password_regex] = options[:password_regex] || DEFAULT_REGEX
             read_io.expect options[:password_regex] do 
             found_password = true
             write_io.puts "#{options[:password]}\r\n"
           end  
         else
           found_password = false
         end
       else
           found_password = true
       end
                          
       begin          
         while io_value = read_io.gets
           io_value.strip!
           
           unless io_value.nil? or io_value.empty?
             if block_given?
               yield io_value
             else
               values << io_value
             end
           end
         end
       # PTY exiting randomly with this exit code
       # This is aprently a very bugy aspect of PTY.spawn. 
       # 
       # It dosent matter if the command exited.  Make sure the 
       # IO pipes are empty.         
       rescue PTY::ChildExited
          #$stderr.puts "PTY::ChildExited, Data"
        retry 
      end
    end 
    # Same bug as above but this time we did not get any data.
    # The command failed before or on the expect statement.  Retry
    # once and then fail with a samba exception
    rescue PTY::ChildExited => error     
      #$stderr.puts "PTY::ChildExited, Main"        
      if retry_count < options[:retry_count]
        retry_count += 1
        retry
      else
        raise PTYError.new( error ), "PTY Session failed to stay alive"
      end  
      
    #This is also thrown some times when there is no problem
    rescue Errno::EIO => error
      #Skip
    rescue PTYError
      raise
    rescue => error
      raise PTYError.new( error ), 
        "Failed to run command: '#{command}'."
    else
      raise PTYError.new( io_value ), "could not find 'Password:' prompt" unless found_password
    end
    
    return values unless block_given?
  end
end
