# Copyright (C) [2006-2007] Novell, Inc.  All Rights Reserved.

# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# IT MAY NOT BE USED, COPIED, DISTRIBUTED, DISCLOSED, ADAPTED, PERFORMED,
# DISPLAYED, COLLECTED, COMPILED, OR LINKED WITHOUT NOVELL'S PRIOR WRITTEN
# CONSENT.  USE OR EXPLOITATION OF THIS WORK WITHOUT AUTHORIZATION COULD
# SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.

# NOVELL PROVIDES THE WORK "AS IS," WITHOUT ANY EXPRESS OR IMPLIED WARRANTY,
# INCLUDING WITHOUT THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE, AND NON-INFRINGEMENT. NOVELL, THE AUTHORS OF THE WORK,
# AND THE OWNERS OF COPYRIGHT IN THE WORK ARE NOT LIABLE FOR ANY CLAIM, DAMAGES,
# OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT, OR OTHERWISE,
# ARISING FROM, OUT OF, OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER
# DEALINGS IN THE WORK.
require 'tracer'

module TurtlePower
	class TurtleParser

		def process_sentence(raw_sentence)
			#begin
				#puts "raw_sentence = #{raw_sentence}"
				#split turtle tokens
				splindex = raw_sentence.index ">"
				#puts "splindex = #{splindex}"
				if splindex == nil 
					return
				end
				subject = raw_sentence.slice(0,splindex)
				subject = subject.delete("<").delete(">")
				#puts "subject = #{subject}"
				
				#process predicate
				predicate_line = raw_sentence.slice(splindex+1,raw_sentence.length).chop.strip
				
				raw_predicates = predicate_line.split(";")
				#puts "raw_predicates = #{raw_predicates}"
				
				predicates = Array.new
				raw_predicates.each do |raw_predicate|
					#build predicate
					splindex = raw_predicate.index(">")
					verb = raw_predicate.slice(0,splindex).delete("<").delete(">").strip
					#puts "verb = #{verb}"
					raw_objects = raw_predicate.slice(splindex+1,raw_predicate.length)			
					objects = raw_objects.split("\",")
					objects.each_index {|i| objects[i] =  objects[i].delete("<").delete(">").delete("\"").delete(";").strip}
					
					predicates << Predicate.new(verb, objects)
				end
				
				#add to sentences
				sentence = Sentence.new(subject, predicates)
				@sentences << sentence 
				return sentence
				 
			#rescue Exception => error
			#	puts "processing error: #{error}"
			#end
		end
=begin	
		def parse(turtlefile)
			@sentences = Array.new
			File.open turtlefile,"r" do |f|
				#get turtle sentence
				while raw_sentence = f.gets(" .")
					raw_sentence = raw_sentence.strip
					#puts "raw_sentence = #{raw_sentence}"
					#puts "raw_sentence[0] = #{raw_sentence[0]}"
					process_sentence(raw_sentence)  unless raw_sentence[0] == 35 
				end
			end
			@sentences
		end
=end
		def parse(turtlefile)
			@sentences = Array.new
			if turtlefile.class == String
				input = File.open turtlefile,"r" 
			else
				input = turtlefile
			end
			parseIO(input)
			input.close if turtlefile.class == String
		end

		def parseIO(input)
			begin
				@sentences = Array.new
				#get turtle sentence
				while raw_sentence = input.gets(" .")
					raw_sentence = raw_sentence.strip
					#puts "raw_sentence = #{raw_sentence}"
					#puts "raw_sentence[0] = #{raw_sentence[0]}"
					process_sentence(raw_sentence)  unless raw_sentence[0] == 35 
				end
				return @sentences
			rescue
				raise SystemCallError.new("turtlepower: invalid input file",Errno::ENOENT::Errno) 
			end
		end

		def get_sentences_with_subject subject
			sentences = Array.new
			sentences = @sentences.find_all {|sentence| subject == sentence.subject }  		
		end

		def get_sentences_with_verb verb
			new_sentences = Array.new
			@sentences.each_index {|i| 
				found = false;
				@sentences[i].predicates.each_index {|j| 
					if @sentences[i].predicates[j].verb == verb and found == false  
						new_sentences << @sentences[i]
						found = true
					end
				}
			}
			return new_sentences
		end

		def get_sentences_with_verb_match verb
			new_sentences = Array.new
			@sentences.each_index {|i| 
				found = false;
				@sentences[i].predicates.each_index {|j| 
					if @sentences[i].predicates[j].verb.include? verb and found == false  
						new_sentences << @sentences[i]
						found = true
					end
				}
			}
			return new_sentences
		end

		def get_sentences_with_object object
			new_sentences = Array.new
			@sentences.each_index {|i| 
				found = false;
				@sentences[i].predicates.each_index {|j| 
					@sentences[i].predicates[j].objects.each_index {|k| 
						#puts "s[#{i}]:#{@sentences[i].subject}.p[#{j}]:#{@sentences[i].predicates[j].verb}.o[#{k}]:#{@sentences[i].predicates[j].objects[k]}"
						if @sentences[i].predicates[j].objects[k] ==  object and found == false  
							new_sentences << @sentences[i]
							found = true
						end
					}
				}
			}
			return new_sentences
		end
		
		def get_sentences_with_object_match object
			new_sentences = Array.new
			@sentences.each_index {|i| 
				found = false;
				@sentences[i].predicates.each_index {|j| 
					@sentences[i].predicates[j].objects.each_index {|k| 
						if @sentences[i].predicates[j].objects[k].include? object and found == false  
							new_sentences << @sentences[i]
							found = true
						end
					}
				}
			}
			return new_sentences
		end
		
		def to_str
			str = ""
			sentences.each {|s| str += s.to_str}
			str
		end

		def to_xml
			xml = ""
			sentences.each {|s| xml += s.to_xml}
			xml += "<turtle-xml>" + xml + "</turtle-xml>"
		end

		def to_yaml
			yaml = ""
			sentences.each {|s| yaml += s.to_yaml}
			yaml += yaml
		end
		
		attr_reader :sentences
		#private :process_sentence
	end

	class Sentence
		def initialize subject, predicates
			@subject = subject
			@predicates = predicates
		end
		
		def to_str
			#Tracer.new.on do
			predicate_string = "" 
			@predicates.each_index {|i|
				#puts "@predicates[#{i}] = #{@predicates[i].to_str}"
				predicate_string += @predicates[i].to_str
				#puts "predicate_string = #{predicate_string}"
				if @predicates.length > 1 and i <= predicates.length
					predicate_string += ";"
				end
				
			}
			return "<#{@subject}> #{predicate_string} ." 
			#end
		end
		
		def to_xml
			#Tracer.new.on do
			predicate_xml = "" 
			@predicates.each_index {|i|
				predicate_xml += @predicates[i].to_xml
			}
			return "<sentence><subject>#{@subject}</subject> #{predicate_xml}</sentence>" 
			#end
		end

		def to_yaml
			#Tracer.new.on do
			predicate_yaml = "" 
			@predicates.each_index {|i|
				predicate_yaml += @predicates[i].to_yaml
			}
			return "#{@subject}\n#{predicate_yaml}" 
			#end
		end

		def get_predicates_with_verb verb
			new_predicates = Array.new
			@predicates.each_index {|i| 
				found = false;
				if @predicates[i].verb == verb and found == false  
					new_predicates << @predicates[i]
					found = true
				end
			}
			return new_predicates
		end

		def get_predicates_with_verb_match verb
			new_predicates = Array.new
			@predicates.each_index {|i| 
				found = false;
				if @predicates[i].verb.include? verb and found == false  
					new_predicates << @predicates[i]
					found = true
				end
			}
			return new_predicates
		end

		def get_predicates_with_object_match object
			new_predicates = Array.new
			@predicates.each_index {|i| 
				found = false;
				@predicates[i].objects.each_index {|j| 
					if @predicates[i].objects[j] ==  object and found == false  
						new_predicates << @predicates[i]
						found = true
					end
				}
			}
			return new_predicates
		end
		
		def get_predicates_with_object_match object
			new_predicates = Array.new
			@predicates.each_index {|i| 
				found = false;
				@predicates[i].objects.each_index {|k| 
					if @predicates[i].objects[k].include? object and found == false  
						new_predicates << @predicates[i]
						found = true
					end
				}
			}
			return new_predicates
		end
		
		attr_reader :subject, :predicates
		attr_writer :subject, :predicates
	end

	class Predicate
		def initialize verb, objects
			@verb = verb
			@objects = objects
		end

		def comma_objects
			c_objects = Array.new
			@objects.each_index {|i| c_objects << @objects[i] + "," unless i == @objects.length}
			#c_objects.last(1) = c_objects.last(1).chop
			#puts "c_objects = #{c_objects}"
			return c_objects
		end

		def to_str
			object_string = ""
			@objects.each_index {|i|
				#puts "@objects[#{i}] = #{objects[i]}"
				object_string += "\"" + @objects[i] + "\""
				#puts "object_string = #{object_string}"
				if @objects.length > 1 and i <= @objects.length
					object_string += ","
				end
			}
			return "<#{@verb}> #{object_string}" 
		end
		
		def to_xml
			object_xml = ""
			@objects.each_index {|i|
				object_xml += "<object>" + @objects[i] + "</object>"
			}
			return "<predicate><verb>#{@verb}</verb>#{object_xml}</predicate>" 
		end

		def to_yaml
			object_yaml = ""
			@objects.each_index {|i|
				object_yaml += "\t#{@verb.gsub!(":","-")}: #{@objects[i]}\n"
			}
			return object_yaml
		end

		attr_reader :verb, :objects
		attr_writer :verb, :objects
	end

	class CaptainTurtle
		def parse sentence_file, command_file
			@sentences = TurtleParser.new.parse sentence_file
			@commands = TurtleParser.new.parse command_file
		end
		
		attr_reader :sentences, :commands
		attr_writer :sentences, :commands
	end

	#commands is essentially a hash.
	#What is the use case to execute a command?
	#e.g. 
	class Commands
		
	end
	
end

