# Copyright (C) [2006-2007] Novell, Inc.  All Rights Reserved.

# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# IT MAY NOT BE USED, COPIED, DISTRIBUTED, DISCLOSED, ADAPTED, PERFORMED,
# DISPLAYED, COLLECTED, COMPILED, OR LINKED WITHOUT NOVELL'S PRIOR WRITTEN
# CONSENT.  USE OR EXPLOITATION OF THIS WORK WITHOUT AUTHORIZATION COULD
# SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.

# NOVELL PROVIDES THE WORK "AS IS," WITHOUT ANY EXPRESS OR IMPLIED WARRANTY,
# INCLUDING WITHOUT THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE, AND NON-INFRINGEMENT. NOVELL, THE AUTHORS OF THE WORK,
# AND THE OWNERS OF COPYRIGHT IN THE WORK ARE NOT LIABLE FOR ANY CLAIM, DAMAGES,
# OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT, OR OTHERWISE,
# ARISING FROM, OUT OF, OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER
# DEALINGS IN THE WORK.
require 'singleton'
#require 'ruby-trace/start/global'

module Migration
	NCPCONF = "/etc/opt/novell/ncpserv.conf"
	class Volumes; end
	class Volume; end


	def Migration.create_nssvolume
		File.open("/_admin/Manage_NSS/manage.cmd",File::RDWR) do |f|
			f.syswrite("<virtualIO><define></virtualIO>") 	

			puts "command: #{f.sysread(2000)}"
		end
	end
end

class Migration::Volumes
	include Singleton
	include Enumerable
	
	attr_accessor :volumes


	def initialize()
		@volumes = []
		vols = []
		shadows = []
		File.open(NCPCONF) {|f|
			lines = f.readlines
			
			lines.each {|l|
				unless l.include?(";")
					if l.include?("/usr/novell") 
						vols << l
					elsif l.include?("/media/nss")
						vols << l
					end
					if l.include?("SHADOW_VOLUME")
						shadows << l
					end
				end
			}
		}

		vols.each do |v|
			vattrs = v.split
			vol = Volume.new(vattrs[1])
			vol.vol_path = vattrs[2]
			if vol.vol_path.include?("/media/nss")
				vol.nss_vol = true
			end
			shadows.each do |s|
				sattrs = s.split
				if sattrs[1] == vol.vol
					vol.shadow_path = sattrs[2]
					#p "vol.shadow_path: #{vol.shadow_path}"
					shd = vol.shadow_path.slice(Migration.mnt_vol_dir.length,vol.shadow_path.length)
					shd = shd.slice(0,shd.rindex("/"))
					vol.shadow_source = shd
					#p "vol.shadow_source: #{vol.shadow_source}"	
					vol.enable_state = true
				else
					vol.enable_state = false
				end
			end
			vol.commited = true
			@volumes << vol	
		end
		@volumes
	end
	
	def each
		@volumes.each do |v|
			yield v
		end
	end

	def each_index 
		@volumes.each_index do |i|
			yield i
		end
	end

	def [] (idx)
		@volumes[idx]
	end

	def delete_at(idx)
		@volumes.delete_at(idx)
	end

	def << (volume)
		@volumes << volume
	end

	def enable_shadow(shadow_source, shadow_vol, shadow_user, shadow_pwd, target_vol = nil, nss_vol = false, pool_name = nil, device_name = nil, vol_size = nil)
	#def enable_shadow shadow_source, volume, username, password, opt = nil
		#note: volumes may already exist because they have been created without shadows
		exists = false
		nss_vol = false if nss_vol == nil 

		if target_vol == nil
			@volumes.each_index do |i|
				v = @volumes[i]
				if @volumes[i].vol == Migration.vol_name(shadow_source, shadow_vol) 
					#p "current state:#{v.vol} #{v.vol_path} #{v.shadow_path} #{v.enable_state}"
					@volumes[i].enable_shadow(shadow_source, shadow_vol, shadow_user, shadow_pwd, target_vol, nss_vol, pool_name, device_name, vol_size)
					exists = true
				end
			end
		else
			@volumes.each_index do |i|
				v = @volumes[i]
				if @volumes[i].vol == target_vol
					#p "current state:#{v.vol} #{v.vol_path} #{v.shadow_path} #{v.enable_state} nss_vol: #{nss_vol}"
					@volumes[i].enable_shadow(shadow_source, shadow_vol, shadow_user, shadow_pwd, target_vol, nss_vol, pool_name, device_name, vol_size)
					exists = true
				end
			end
		end
		v = nil
		unless exists 
			if target_vol == nil
				v = Volume.new(shadow_vol)
			else
				v = Volume.new(target_vol)
			end
			#p "creating state:#{v.vol} #{v.vol_path} #{v.shadow_path} #{v.enable_state}"
			v.enable_shadow(shadow_source, shadow_vol, shadow_user, shadow_pwd, target_vol, nss_vol, pool_name, device_name, vol_size)
			#p "new state:#{v.vol} #{v.vol_path} #{v.shadow_path} #{v.enable_state}"
			@volumes << v
			#p "enable_shadow stack: #{caller(0)}" 
		end
	end

	def disable_shadow source, volume, opt = nil
		exists = false
		if opt == nil
			@volumes.each_index do |i|
				if @volumes[i].vol == Migration.vol_name(source, volume)
					#p "@volumes[i].vol: #{@volumes[i].vol}"
					@volumes[i].disable_shadow 
					#@volumes[i].commit
					exists = true
				end
			end
		else
			@volumes.each_index do |i|
				v = @volumes[i]
				if @volumes[i].vol == opt
					#p "current state:#{v.vol} #{v.vol_path} #{v.shadow_path} #{v.enable_state}"
					@volumes[i].disable_shadow
					exists = true
				end
			end
		end
		unless exists
			raise SystemCallError.new("disable_shadow failed to disable the volume, the #{Migration.vol_name(source,volume)} volume doesn't exist\n", Migration::ENOTEXIST)
		end
	end

	def enable_copy_now source, volume, filter
		copy_on_access
		exists = false
		@volumes.each_index do |i|
			v = @volumes[i]
			#if @volumes[i].vol == Migration.vol_name(source, volume)
			#p "#{v.vol} #{v.vol_path} #{v.shadow_path} #{v.enable_state}"
			#p "volume: #{volume} #{Migration.vol_name(source, volume)} #{v.enable_state}"
			if v.vol == volume or v.vol == Migration.vol_name(source, volume) and v.enable_state == true
				#p "within if statement: #{v.vol} #{v.vol_path} #{v.shadow_path} #{v.enable_state}"
				v.copy_now filter
			end
		end
	end

	def copy_on_access 
		File.open("#{NCPCONF}", File::CREAT|File::WRONLY, 0600) do |file|
			ncpconf = IO.readlines NCPCONF
			#puts "before ncpconf processing: #{ncpconf}"
			unless ncpconf.include? "SHIFT_ACCESSED_SHADOW_FILES  1\n"
				idx = 0
				ncpconf.each_index do |i|
					if ncpconf[i].include? "NCP_FILE_SERVER_NAME"
						idx = i + 1
					end
				end
				#if idx == 0
				#	idx = ncpconf.length
				
				#p "idx: #{idx}"
				ncpconf.insert(idx,"SHIFT_ACCESSED_SHADOW_FILES  1\n")
				#ncpconf << "SHIFT_ACCESSED_SHADOW_FILES  1\n" 
				#p "before join ncpconf: #{ncpconf}"
				ncpconf = ncpconf.join
			end
			#puts "ncpconf: #{ncpconf}"
			file.write(ncpconf)
		end
	end

	def display_volumes yaml = false
		if yaml
			#TODO: needs filtering on this
			YAML.dump(@volumes, $stdout)	
		else	
			@volumes.each { |v|
			if v.shadow_path  == nil
				puts "<class:volume> <attr:vol> \"#{v.vol}\" <attr:vol_path> \"#{v.vol_path}\" <attr:enable_state> \"#{v.enable_state}\" ."
			else
				puts "<class:volume> <attr:vol> \"#{v.vol}\" <attr:path> \"#{v.vol_path}\"; <attr:shadow_path> \"#{v.shadow_path}\"; <attr:enable_state> \"#{v.enable_state}\" ."
			end
		}
		end
	end

	def commit
		ncpconf = nil
		File.open "#{NCPCONF}",File::RDONLY do |file|
			ncpconf = file.readlines	
		end

		@volumes.each do |v|
			#p "before if enable_state: #{v.to_str}"
			if v.commited == false and v.enable_state == false 
				#p "disable: #{v.to_str}"
				if ncpconf.include? "SHADOW_VOLUME #{v.vol} #{v.shadow_path}\n"
					idx = ncpconf.index "SHADOW_VOLUME #{v.vol} #{v.shadow_path}\n"
					ncpconf.slice! idx
				else
					raise SystemCallError.new("commit failed to disable the volume, the shadow volume #{v.vol} doesn't exist\n", Migration::EALREADYDISABLED)
				end
				
				#raise SystemCallError.new("volume: cannot disable, the volume #{self.vol} doesn't exist\n", Migration::EALREADYDISABLED)
				#puts "Migration.vol_umount(#{v.shadow_mnt_path})" 
				included = false
				ncpconf.each do |l|
					if l.include? "#{v.shadow_source}"
						included = true
					end
				end
				Migration.vol_umount(v.shadow_mnt_path) unless included
				Migration.vol_persumount(v.shadow_source, v.shadow_user, v.shadow_pwd, v.shadow_mnt_path) unless included
				v.commited = true
			end

			if v.commited == false and v.enable_state == true
				ncpconf << "VOLUME #{v.vol} #{v.vol_path}\n" unless ncpconf.include? "VOLUME #{v.vol} #{v.vol_path}\n"
=begin
				if v.nss_vol == true
					if v.nss_device == nil
						#query for first device in list?

					end
					if v.nss_pool == nil
						v.nss_pool = "pool"
					end
					# need to check if pool exists
					unless Migration.pool_exists? v.nss_pool
						Migration.create_nsspool v.nss_pool
					end
					unless Migration.vol_exists? v.vol
						Migration.create_volume v.nss_pool, v.vol
					end
				end
=end
				idx = ncpconf.index "VOLUME #{v.vol} #{v.vol_path}\n"
				#ncpconf << "SHADOW_VOLUME #{v.vol} #{v.shadow_path}\n" 
				unless ncpconf.include? "SHADOW_VOLUME #{v.vol} #{v.shadow_path}\n"
					ncpconf.insert(idx+1, "SHADOW_VOLUME #{v.vol} #{v.shadow_path}\n") 
				else
					raise SystemCallError.new("commit to failed to enable the volume, the shadow volume #{v.vol} already exists\n", Migration::EALREADYENABLED)
				end
				#p "Dir.mkdir(#{v.vol_path}) unless File.exists?(#{v.vol_path})"
				Dir.mkdir(v.vol_path) unless File.exists?(v.vol_path)
				
				#puts "Migration.vol_mount(#{v.shadow_source}, #{v.shadow_mnt_path}, #{v.shadow_user}, #{v.shadow_pwd})"
				Migration.vol_mount(v.shadow_source, v.shadow_vol, v.shadow_mnt_path, v.shadow_user, v.shadow_pwd)
				Migration.vol_persmount(v.shadow_source, v.shadow_vol, v.shadow_mnt_path, v.shadow_user, v.shadow_pwd)

				v.commited = true
			end
		end
		ncpconf = ncpconf.join
		#puts ncpconf
		File.open "#{NCPCONF}",File::CREAT|File::WRONLY|File::TRUNC, 0600 do |file|
			file.write(ncpconf)	
		end
		`/usr/bin/systemctl restart ndsd.service 2>&1`
	end
end

class Migration::Volume

	attr_accessor :vol, :vol_path, :enable_state, :commited, :gen_vol_from_source
	attr_accessor :shadow_source, :shadow_vol, :shadow_path, :shadow_user, :shadow_pwd
	attr_accessor :nss_vol, :pool_name, :device_name, :vol_size

	#private :shadow_pwd
	def to_str
		"#{self} vol: #{vol} vol_path: #{vol_path}, shadow_source: #{shadow_source} shadow_path: #{shadow_path}, shadow_mnt_path: #{shadow_mnt_path} enable_state: #{enable_state}, commited: #{commited}"
	end

	def initialize(vol, shadow_source = nil, shadow_vol = nil, shadow_user = nil, shadow_pwd = nil)
		@vol, @shadow_source, @shadow_vol, @shadow_user, @shadow_pwd = vol, shadow_source, shadow_vol, shadow_user, shadow_pwd
		self.enable_state = false
		self.commited = true
		self.gen_vol_from_source = true
	end

	def enable_shadow(shadow_source, shadow_vol, shadow_user, shadow_pwd, target_vol = nil, nss_vol = false, pool_name = nil, device_name = nil, vol_size = nil)
		@shadow_source, @shadow_vol, @shadow_user, @shadow_pwd = shadow_source, shadow_vol, shadow_user, shadow_pwd
		
		self.enable_state = true
		self.commited = false

		
		self.nss_vol = nss_vol
		self.pool_name = pool_name
		self.device_name = device_name
		self.vol_size = vol_size

		#p "self.nss_vol: #{self.nss_vol}"
		#p "nss_vol: #{nss_vol}"
		#p "target_vol: #{target_vol}"
		self.gen_vol_from_source = false unless target_vol == nil

		if self.gen_vol_from_source == true		
			#p "target_vol == nil"
			self.vol = Migration.vol_name(shadow_source, shadow_vol)
			self.vol_path = Migration.target_vol_dir(shadow_source, shadow_vol) 
			self.shadow_vol = shadow_vol
			self.shadow_path = Migration.shadow_vol_dir(shadow_source,shadow_vol) 
			#p "self.shadow_path: #{self.shadow_path}"
		elsif self.nss_vol == false
			self.vol = target_vol
			#p "nss_vol: #{self.nss_vol} self.vol: #{self.vol}, Migration.target_dir: #{Migration.target_dir}"
			self.vol_path = Migration.target_dir + "/" + self.vol
			self.shadow_vol = shadow_vol
			self.shadow_path = Migration.mnt_vol_dir + shadow_source +"/" + shadow_vol
		else
			self.vol = target_vol
			#p "self.vol: #{self.vol}, Migration.target_dir: #{Migration.target_dir}"
			self.vol_path = "/media/nss/" + self.vol
			self.shadow_vol = shadow_vol
			self.shadow_path = Migration.mnt_vol_dir + shadow_source +"/" + shadow_vol
		end
	end

	def disable_shadow 
		#p "volume:disable_shadow self.enable_state: #{self.enable_state}"
		self.enable_state = false
		self.commited = false
	end

	def shadow_mnt_path
		path = nil
		unless self.shadow_path == nil
			#if self.gen_vol_from_source
					path = self.shadow_path.slice(0, self.shadow_path.rindex("/")) 
					#path = self.shadow_path
			#else
			#	path = self.shadow_path
			#end
		end
	end

	def copy_now(pattern = nil)
		pattern = "*" if pattern == nil
		#puts "ncpcon shadow #{self.vol} operation=mp pattern=#{pattern} 2>&1"
		`ncpcon shadow #{self.vol} operation=mp pattern=#{pattern} 2>&1`
		#`ncpcon shadow #{self.vol} operation=mp pattern=#{pattern}`
	end
end
