# Copyright (C) [2006-2007] Novell, Inc.  All Rights Reserved.

# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# IT MAY NOT BE USED, COPIED, DISTRIBUTED, DISCLOSED, ADAPTED, PERFORMED,
# DISPLAYED, COLLECTED, COMPILED, OR LINKED WITHOUT NOVELL'S PRIOR WRITTEN
# CONSENT.  USE OR EXPLOITATION OF THIS WORK WITHOUT AUTHORIZATION COULD
# SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.

# NOVELL PROVIDES THE WORK "AS IS," WITHOUT ANY EXPRESS OR IMPLIED WARRANTY,
# INCLUDING WITHOUT THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE, AND NON-INFRINGEMENT. NOVELL, THE AUTHORS OF THE WORK,
# AND THE OWNERS OF COPYRIGHT IN THE WORK ARE NOT LIABLE FOR ANY CLAIM, DAMAGES,
# OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT, OR OTHERWISE,
# ARISING FROM, OUT OF, OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER
# DEALINGS IN THE WORK.
module Migration
  module Windows
    $:.unshift File.expand_path(File.join(File.dirname(__FILE__)))  
    require 'exceptions'
    $:.shift
    
    class DirectoryTree
      class Node
        include Enumerable
        attr_accessor :label, :container, :children
        @@path = Array.new
        
        def initialize( label, container = nil )
          @label = label
          @container = container
          @children = Array.new
        end
      
        def each
          @children.each { |node| yield node }
        end
        
        def <=>( other )
          @label <=> other.label
        end
        
        def add_child( child )
          node = Node.new( child )
          @children << node
          node
        end
        
        def recurse( &block )
          yield @container
          @children.each { |child| child.recurse( &block ) }
        end  
        
        def recurse_nodes( &block )
          yield self
          unless self.leaf?
            @@path.push self
            @children.each { |child| child.recurse_nodes( &block ) }
            @@path.pop
          end
        end 
        
        def to_s
          @label
        end 
                
        def leaf?
          @children.empty?
        end
        
        def current_path
          @@path.join("\\")
        end
        
        def current_parent
          @@path.last
        end
      end
    
      class DirectoryEnumerator
        attr_accessor :directory_tree
        def initialize( directory_tree )
          @directory_tree = directory_tree
        end
        def recurse( &block )
          @directory_tree.root.recurse( &block )
        end
        def recurse_nodes( &block )
          @directory_tree.root.recurse_nodes do |node|
            yield node.container
          end
        end
        def current_path
          @directory_tree.root.current_path
        end
        def current_parent
          @directory_tree.root.current_parent.container
        end        
      end    
    
      attr_reader :root
    
      def initialize
        @root = Node.new( SHARE_ROOT_PLACE_HOLDER )
      end  
      def build_from_ntfs_collection( collection )    
        collection.each do |ntfs_object|
          path_values = ntfs_object.path.split(/\\/)
          path_values.delete_if { |x| x.empty? or x.nil? }
                  
          node, extra_values = self.find_last_value_of( path_values )
          
          if extra_values.nil? 
            if node.label == SHARE_ROOT_PLACE_HOLDER
              node.container = ntfs_object
            else extra_values.nil?
              raise WindowsError.new, "Duplicate object found: #{values.to_s}", caller
            end
          else
            extra_values.each do |value|
              node = node.add_child( value )
            end
            node.container = ntfs_object
          end
        end
      end  
      
      def find_last_value_of( values = [] )
        last_node, current_node = @root, @root
        while find_node = values.shift
          last_node = current_node
          current_node = current_node.find { |node| node.label == find_node }
          
          if current_node.nil?
            values.unshift find_node
            return last_node, values
          end
        end
        
        return current_node, nil
      end
      def get_enumerator
        DirectoryEnumerator.new( self )
      end 
    end
  end
end
