# Copyright (C) [2006-2007] Novell, Inc.  All Rights Reserved.

# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# IT MAY NOT BE USED, COPIED, DISTRIBUTED, DISCLOSED, ADAPTED, PERFORMED,
# DISPLAYED, COLLECTED, COMPILED, OR LINKED WITHOUT NOVELL'S PRIOR WRITTEN
# CONSENT.  USE OR EXPLOITATION OF THIS WORK WITHOUT AUTHORIZATION COULD
# SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.

# NOVELL PROVIDES THE WORK "AS IS," WITHOUT ANY EXPRESS OR IMPLIED WARRANTY,
# INCLUDING WITHOUT THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE, AND NON-INFRINGEMENT. NOVELL, THE AUTHORS OF THE WORK,
# AND THE OWNERS OF COPYRIGHT IN THE WORK ARE NOT LIABLE FOR ANY CLAIM, DAMAGES,
# OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT, OR OTHERWISE,
# ARISING FROM, OUT OF, OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER
# DEALINGS IN THE WORK.

# :title: Novell Migration Utility - group_object
# ==Description: 
# A class that contains information for a Domain group object
# * group name
# * description
# * attribute
# * RID
# * Array of group members
#  
module Migration
  module Windows
    module Domain
      class Group
        attr_accessor(:group_name, :description, :members)
        
        def initialize(name = "", description = "", members = [])
          @group_name = name
          @description = description
          @members = members
        end
        
        def ==(other)
          return false unless self.group_name == other.group_name
          return false unless self.description == other.description
          return false unless self.members == other.members    

          return true   
        end
        
        def to_yaml_type
          "!novell.com,1984/generic_group"
        end  
              
        def to_yaml_properties
          ['@group_name','@description', '@members']
        end          
      end
      
      class WindowsGroup < Group
        attr_accessor(:attribute, :rid)
        
        def initialize(name = "", description = "", members = [], rid = "0x0", attribute = 0)
          @rid = rid
          @attribute = attribute
          super(name, description, members)
        end
        
        def ==(other)
          return false unless self.rid == other.rid
          return false unless self.attribute == other.attribute
          super(other)
        end
        def to_yaml_type
          "!novell.com,1984/windows_group"
        end        
        #def to_yaml_properties
        #  super + ['@attribute']
        #end        
      end
      
      class NovellGroup < Group
        attr_accessor(:owner, :context)

        def initialize(name = "", context = "", owner= "", members = [], description = "")
          @owner = owner
          @context = context
          super(name, description, members)
        end
        
        def to_yaml_type
          "!novell.com,1984/novell_group"
        end 
        def to_yaml_properties
          super + ['@owner', '@context']
        end                         
      end
    end
  end
end
