# Copyright (C) [2006-2007] Novell, Inc.  All Rights Reserved.

# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# IT MAY NOT BE USED, COPIED, DISTRIBUTED, DISCLOSED, ADAPTED, PERFORMED,
# DISPLAYED, COLLECTED, COMPILED, OR LINKED WITHOUT NOVELL'S PRIOR WRITTEN
# CONSENT.  USE OR EXPLOITATION OF THIS WORK WITHOUT AUTHORIZATION COULD
# SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.

# NOVELL PROVIDES THE WORK "AS IS," WITHOUT ANY EXPRESS OR IMPLIED WARRANTY,
# INCLUDING WITHOUT THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE, AND NON-INFRINGEMENT. NOVELL, THE AUTHORS OF THE WORK,
# AND THE OWNERS OF COPYRIGHT IN THE WORK ARE NOT LIABLE FOR ANY CLAIM, DAMAGES,
# OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT, OR OTHERWISE,
# ARISING FROM, OUT OF, OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER
# DEALINGS IN THE WORK.

# :title: Novell Migration Utility - ntuserls
# ==Description: 
# A collection of module methods to deal with Windows domain SID's and RID's
# 
module Migration
  module Windows
    module Domain
      require "base64"
      
      # Takes a base64 _encoded_sid_ and tranforms the SID in to the standard 
      # SID representation.  Specifically for retrieving Active Directory ldap
      # based SID's.
      def Domain.encoded_text_to_SID( encoded_sid )
        #Decode 64 bit encoded hex string
        return text_to_SID( Base64.decode64( encoded_sid ) )
      end
      
      def Domain.text_to_SID( text_sid )
        # SID anatomy:
        # Byte Position
        # 0   : SID Structure Revision Level (SRL)
        # 1   : Number of Subauthority/Relative Identifier
        # 2-7 : Identifier Authority Value (IAV) [48 bits]
        # 8-x : Variable number of Subauthority or Relative Identifier (RID) [32bits]
        # 
        # Example:
        # 
        # <Domain>\Administrator
        # Pos  :    0 |  1 |  2  3  4  5  6  7 |  8  9 10 11 | 12 13 14 15 | 16 17 18 19 | 20 21 22 23 | 24 25 26 27
        # Value:   01 | 05 | 00 00 00 00 00 05 | 15 00 00 00 | 06 4E 7D 7F | 11 57 56 7A | 04 11 C5 20 | F4 01 00 00
        # str  : S- 1 |    |                -5 | -21         | -2138918406 | -2052478737 | -549785860  | -500 
        # 
        # <Machine/Buildin>\Backup Operator
        # Pos  :    0 |  1 |  2  3  4  5  6  7 |  8  9 10 11 | 12 13 14 15 
        # Value:   01 | 05 | 00 00 00 00 00 05 | 20 00 00 00 | 02 27 00 00 
        # str  :    1 |    |                -5 | -32         | -551 

        #Retrieve the SID Structure Revision Level
        string_sid = "S" + "-" + text_sid[0].to_s
      
        sid_chunk = "".hex
      
        #Retrieve the Identifier Authority Value (IAV)
        7.downto(2) {|i| sid_chunk += text_sid[i] }
        string_sid += "-" + sid_chunk.to_i.to_s
       
        return string_sid if text_sid.size == 8 
       
        sub_auth = 0
       
        # Get the variable number of Subauthority RIDS's
        11.step( text_sid.size - 1, 4 ) { |i|
          sub_auth = 0
          0.upto(3) { |j| 
            sub_auth = sub_auth * 256 + text_sid[ i - j ]
          }
          string_sid += "-" + sub_auth.to_s
        }
        
        return string_sid
      end
      
      # Takes the standard representation of a SID "S-#-#-#-.." and retrieves the RID.
      def Domain.SID_to_RID( sid )          
         return "0x" + sid.split('-').last.to_i.to_s(16)
      end
    end
  end
end
