# Copyright (C) [2006-2007] Novell, Inc.  All Rights Reserved.

# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# IT MAY NOT BE USED, COPIED, DISTRIBUTED, DISCLOSED, ADAPTED, PERFORMED,
# DISPLAYED, COLLECTED, COMPILED, OR LINKED WITHOUT NOVELL'S PRIOR WRITTEN
# CONSENT.  USE OR EXPLOITATION OF THIS WORK WITHOUT AUTHORIZATION COULD
# SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.

# NOVELL PROVIDES THE WORK "AS IS," WITHOUT ANY EXPRESS OR IMPLIED WARRANTY,
# INCLUDING WITHOUT THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE, AND NON-INFRINGEMENT. NOVELL, THE AUTHORS OF THE WORK,
# AND THE OWNERS OF COPYRIGHT IN THE WORK ARE NOT LIABLE FOR ANY CLAIM, DAMAGES,
# OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT, OR OTHERWISE,
# ARISING FROM, OUT OF, OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER
# DEALINGS IN THE WORK.

# :title: Novell Migration Utility - ntuserls
# ==Description: 
# A class that contains information for a Domain user object
# * user name
# * full name
# * home drive
# * directory drive
# * profile path
# * logon script
# * description
# * users RID
# * group RID
#   
module Migration
  module Windows
    module Domain
      class User
        attr_accessor(:user_name, :full_name,
          :profile_path, :logon_script, :description)
        
        def initialize(name = "", full_name = "", 
            profile ="", logon_script = "", description = "")
          @user_name = name
          @full_name = full_name
          @profile_path = profile
          @logon_script = logon_script
          @description = description
        end      

        def ==(other)
          return false unless self.user_name == other.user_name
          return false unless self.full_name == other.full_name     
          return false unless self.profile_path == other.profile_path    
          return false unless self.logon_script == other.logon_script
          return false unless self.description == other.description  
          return true                  
        end
        
        def to_yaml_type
          "!novell.com,1984/generic_user"
        end   
        
        def to_yaml_properties
          ['@user_name', '@full_name', '@profile_path', 
            '@logon_script', '@description']
        end               
      end
      
      class WindowsUser < User
        attr_accessor(:home_drive, :dir_drive, :user_rid, :group_rid)
        
        def initialize(name = "", full_name = "", home_drive = "", dir_drive = "", 
            profile ="", logon_script = "", description = "", user_rid = "0x0", 
            group_rid = "0x0")
          @home_drive = home_drive
          @dir_drive = dir_drive
          @user_rid = user_rid
          @group_rid = group_rid
          
          super(name, full_name, profile, logon_script, description)
        end

        def ==(other)
          return false unless self.home_drive == other.home_drive
          return false unless self.dir_drive == other.dir_drive
          return false unless self.user_rid == other.user_rid
          return false unless self.group_rid == other.group_rid
          
          super(other)
        end

        def to_yaml_type
          "!novell.com,1984/windows_user"
        end   
             
        def to_yaml_properties
          super + ['@home_drive', '@dir_drive']
        end          
      end
      
      class NovellUser < User
        attr_accessor(:first_name, :last_name, :context, :home_volume, 
          :home_path, :primary_group)
          
        def initialize(name = "", full_name = "", profile ="", logon_script = "", 
          description = "", first_name = "", last_name = "", context = "",
          home_volume = "", home_path = "", primary_group = "")
          @first_name = first_name
          @last_name = last_name
          @context = context
          @home_volume = home_volume
          @home_path = home_path
          @primary_group = primary_group
          
          super(name, full_name, profile, logon_script, description)
        end          
          
        def to_yaml_type
          "!novell.com,1984/novell_user"
        end  
              
        def to_yaml_properties
          super + ['@first_name', '@last_name','@context', '@home_volume', 
          '@home_path', '@primary_group']
        end             
      end      
      
#      class ActiveDirectory_user < User_object
#        def initialize
#          @distinguished_name = ""
#          @sid = ""        
#          @guid = ""        
#          @member_of = []
#          @principal_name = ""        
#          @samaccount_name  = ""        
#          @description = ""        
#          @name = ""        
#          @given_name = ""        
#          @initials = ""        
#          @title = ""        
#          @email_address = ""        
#          @street_address = ""        
#          @post_office_box = ""        
#          @city = ""        
#          @st = ""        
#          @postal_code = 0
#          @country = ""        
#          @company = ""        
#          @department = ""        
#          @office_name = ""        
#          @phone_mobile = ""        
#          @phone_primary = ""        
#          @phone_pager = ""        
#          @phone_home  = ""        
#          @codepage = 0
#          @profile_path = ""        
#          @home_page  = ""        
#          @manager = ""        
#        end
#      
#        def to_yaml_type
#          "!novell.com,1984/active_directory_user"
#        end        
#        #def to_yaml_properties
#        #  [ '@user_name','@full_name','@home_drive', '@dir_drive', 
#        #    '@profile_path', '@logon_script', '@description',
#        #    '@user_rid', '@group_rid']
#        #end          
#      end      
    end
  end
end
