# Copyright (C) [2006-2007] Novell, Inc.  All Rights Reserved.

# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# IT MAY NOT BE USED, COPIED, DISTRIBUTED, DISCLOSED, ADAPTED, PERFORMED,
# DISPLAYED, COLLECTED, COMPILED, OR LINKED WITHOUT NOVELL'S PRIOR WRITTEN
# CONSENT.  USE OR EXPLOITATION OF THIS WORK WITHOUT AUTHORIZATION COULD
# SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.

# NOVELL PROVIDES THE WORK "AS IS," WITHOUT ANY EXPRESS OR IMPLIED WARRANTY,
# INCLUDING WITHOUT THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE, AND NON-INFRINGEMENT. NOVELL, THE AUTHORS OF THE WORK,
# AND THE OWNERS OF COPYRIGHT IN THE WORK ARE NOT LIABLE FOR ANY CLAIM, DAMAGES,
# OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT, OR OTHERWISE,
# ARISING FROM, OUT OF, OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER
# DEALINGS IN THE WORK.

# :title: Novell Migration Utility - ntuserls
# ==Description: 
# Class representing a NTFS/NSS ACE.  Depending on what ACE is being used
# NTFS_Ace or NSS_Ace it will act acordingly to that specific instance.
# 
module Migration
  module Windows
    module Rights
      $:.unshift File.expand_path(File.join(File.dirname(__FILE__)))
      require 'ntfs_rights'        
      require 'nss_rights'     
      $:.shift  
                    
      $:.unshift File.expand_path(File.join(File.dirname(__FILE__), '..'))
      require 'exceptions'
      $:.shift 
                                        
      # TODO: Add rdoc       
      class Ace < Struct
        def yaml_as # :nodoc:
          "tag:yaml.org,2002:map"
        end        
        def to_yaml_type # :nodoc:
          if self.is_a? Ace::NTFS_Ace
            return "!novell.com,1984/ntfs_ace"
          elsif self.is_a? Ace::NSS_Ace
            return "!novell.com,1984/nss_ace"
          end
        end                     
        def Ace.yaml_new( val ) # :nodoc:
          result = nil
          if val.has_key? "type" and val.has_key? "flags"
            unless defined? Ace::NTFS_Ace
              Ace.new( "NTFS_Ace", :ace, :name, :inheritance )
            end        
            result = Ace::NTFS_Ace.new
            result.ace = Migration::Windows::Rights::NTFS_rights.new
            
            val.each_pair do |k,v|  
              if k === "type" or k === "flags" or  k === "mask"
                result.ace.from_y( v )
              elsif k === "name"
                result.name = v
              else
                raise "Invalid right value for NTFS Ace: #{v}", caller              
              end
              result.inheritance = nil
            end
          else 
            unless defined? Ace::NSS_Ace
              Ace.new( "NSS_Ace", :mask, :name, :rights )
            end  
            result = Ace::NSS_Ace.new

            result.rights = Migration::Windows::Rights::NSS_rights.new
            result.mask = Migration::Windows::Rights::NSS_rights.new                                        
  
            val.each_pair do |k,v|
              if k === "name"
                result.name = v
              elsif k === "rights"
                result.rights.from_s( v )
              elsif k === "mask"
                result.mask.from_s( v )              
              else
                raise RightsError, "Invalid right value for NSS Ace: #{v}", caller
              end
            end
          end    
          result
        end
        def to_yaml( opts = {} ) # :nodoc:
          YAML::quick_emit( object_id, opts ) do |out|
            out.map( taguri, self.to_yaml_style ) do |map|
              if self.is_a? Ace::NTFS_Ace
                ace = self.ace.to_ary()
                map.add( "name", self.name )
                map.add( "type", ace[0] )
                map.add( "flags", ace[1] )
                map.add( "mask", ace[2] )
              elsif self.is_a? Ace::NSS_Ace
                map.add( "name", self.name )
                map.add( "rights", self.rights.to_s )
                map.add( "mask", self.mask.to_s )
              end
            end
          end
        end
        
        def ==( other ) # :nodoc:
          if self.is_a? Ace::NTFS_Ace
            return false unless self.name == other.name 
            return false unless self.ace.raw_type == other.ace.raw_type
            return false unless self.ace.raw_rights == other.ace.raw_rights 
            return true
          elsif self.is_a? Ace::NSS_Ace
            return false unless self.name == other.name 
            return false unless self.rights.raw_rights == other.rights.raw_rights
            return false unless self.mask.raw_rights == other.mask.raw_rights
            return true            
          else
            raise RightsError, "Invalid ACE type: #{other.class}", caller
          end
        end
      end  
      
      unless defined? Ace::NTFS_Ace
        Ace.new( "NTFS_Ace", :ace, :name, :inheritance )         
      end    
      unless defined? Ace::NSS_Ace
        Ace.new( "NSS_Ace", :mask, :name, :rights )
      end            

###########TEMP#########3
class NTFS_quota 
        attr_accessor(:name, :value )
        def yaml_as # :nodoc:
          "tag:yaml.org,2002:map"
        end
        def to_yaml_type # :nodoc:
            return "!novell.com,1984/ntfs_quota"
        end

        def to_yaml( opts = {} ) # :nodoc:
          YAML::quick_emit( object_id, opts ) do |out|
            out.map( taguri, self.to_yaml_style ) do |map|
                map.add( "name", self.name )
                map.add( "value", self.value)
              end
            end
        end

        def ==( other ) # :nodoc:
            return false unless self.name == other.name
            return false unless self.value == other.value
            return true
        end
      end
#####################END OF TEMP##########
    end
  end
end
