# Copyright (C) [2006-2007] Novell, Inc.  All Rights Reserved.

# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# IT MAY NOT BE USED, COPIED, DISTRIBUTED, DISCLOSED, ADAPTED, PERFORMED,
# DISPLAYED, COLLECTED, COMPILED, OR LINKED WITHOUT NOVELL'S PRIOR WRITTEN
# CONSENT.  USE OR EXPLOITATION OF THIS WORK WITHOUT AUTHORIZATION COULD
# SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.

# NOVELL PROVIDES THE WORK "AS IS," WITHOUT ANY EXPRESS OR IMPLIED WARRANTY,
# INCLUDING WITHOUT THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE, AND NON-INFRINGEMENT. NOVELL, THE AUTHORS OF THE WORK,
# AND THE OWNERS OF COPYRIGHT IN THE WORK ARE NOT LIABLE FOR ANY CLAIM, DAMAGES,
# OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT, OR OTHERWISE,
# ARISING FROM, OUT OF, OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER
# DEALINGS IN THE WORK.

# :title: Novell Migration Utility - ntuserls
# ==Description: 
# Class representing a NSS file system object.
# 

module Migration
  module Windows
    module Rights 
      class NSS_object      
        attr_accessor(:path, :owner, :group, :acl, :volume, :attrs, :quotas)
        
        def initialize(volume = "", path = "")
          @volume = volume
          @path = path
          @acl = []
          @quotas = []
          self.switch_seperators          
        end

        def ==(other)
          return false unless self.volume == other.volume
          return false unless self.path == other.path 
          return false unless self.acl == other.acl
	  return false unless self.attrs == other.attrs
	  return false unless self.quotas == other.quotas
          return true
        end
        
        def add_ace(nss_ace)
          return nil if nss_ace.nil?
          @acl << nss_ace
        end        

        def add_quota(nss_quota)
          @quotas << nss_quota
        end        
        
        def to_yaml_type # :nodoc:
          "!novell.com,1984/nss_rights_object"
        end        
         
        def to_yaml_properties # :nodoc:
          ['@volume', '@path', '@acl']
        end 
        
	def set_attrs (attr)
		@attrs = attr
	end

        def to_maprights( context , type )
          output = {} unless block_given?

         vol = @volume

          @acl.each do |ace|
            if block_given?
	      if @path == SHARE_ROOT_PLACE_HOLDER
	        yield "- dst-file: \"#{vol}\""
	      else
                yield "- dst-file: \"#{vol}" + "#{@path}\""
              end
              yield "  owner: cn=#{ace.name},#{context}"
              yield "  rights: #{ace.rights.to_s}"
              yield "  mask: #{ace.mask.to_s}"
	      yield "  attrs: #{@attrs}"
              yield "  type: #{type}"
              yield "  src-type: windows"
            else
	      if @path == SHARE_ROOT_PLACE_HOLDER
		output['dst-file']="- dst-file: \"#{vol}\""
	      else
                output['dst-file']="- dst-file: \"#{vol}" + "#{@path}\""
              end
              output['owner'] = "cn=#{ace.name},#{context}"
              output['rights'] = ace.rights.to_s
              output['mask'] = ace.mask.to_s
	      output['attrs']= "#{@attrs}"
              output['type'] = "#{type}"
              output['src-type'] = "windows"
            end
          end
	# Need to include the file/dir in output to set attrs values at destination
          if @acl.empty? 
            if block_given?
              if @path == SHARE_ROOT_PLACE_HOLDER
		yield "- dst-file: \"#{vol}\""
	      else
                yield "- dst-file: \"#{vol}" + "#{@path}\""
              end
	      yield "  attrs: #{@attrs}"
              yield "  type: #{type}"
            else
	      if @path == SHARE_ROOT_PLACE_HOLDER
		output['dst-file']="- dst-file: \"#{vol}\""
	      else
                output['dst-file']="- dst-file: \"#{vol}" + "#{@path}\""
              end
	      output['attrs']= "#{@attrs}"
              output['type'] = "#{type}"
            end
          end
 
        @quotas.each do |ntfs_quota|
            if block_given?
	      if @path == SHARE_ROOT_PLACE_HOLDER
	        yield "- dst-file: \"#{vol}\""
	      else
                yield "- dst-file: \"#{vol}" + "#{@path}\""
              end
              yield "  owner: cn=#{ntfs_quota.name},#{context}"
	      yield "  user-quota: #{ntfs_quota.value}"
              yield "  type: #{type}"
            else
	      if @path == SHARE_ROOT_PLACE_HOLDER
		output['dst-file']="- dst-file: \"#{vol}\""
	      else
                output['dst-file']="- dst-file: \"#{vol}" + "#{@path}\""
              end
              output['owner'] = "cn=#{ntfs_quota.name},#{context}"
	      output['user-quota']= "#{ntfs_quota.value}"
              output['type'] = "#{type}"
	      print "ntfs_quota.name = #{ntfs_quota.name},#{context}\n"
	      print "ntfs_quota.value = #{ntfs_quota.value}\n"
            end
        end
          output unless block_given?
        end      
        
        def switch_seperators
          @path.gsub!('\\', '/')
          @path.strip!
          @path.gsub!(/\/$/, '')
        end
      end
    end
  end
end
