# Copyright (C) [2006-2007] Novell, Inc.  All Rights Reserved.

# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# IT MAY NOT BE USED, COPIED, DISTRIBUTED, DISCLOSED, ADAPTED, PERFORMED,
# DISPLAYED, COLLECTED, COMPILED, OR LINKED WITHOUT NOVELL'S PRIOR WRITTEN
# CONSENT.  USE OR EXPLOITATION OF THIS WORK WITHOUT AUTHORIZATION COULD
# SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.

# NOVELL PROVIDES THE WORK "AS IS," WITHOUT ANY EXPRESS OR IMPLIED WARRANTY,
# INCLUDING WITHOUT THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE, AND NON-INFRINGEMENT. NOVELL, THE AUTHORS OF THE WORK,
# AND THE OWNERS OF COPYRIGHT IN THE WORK ARE NOT LIABLE FOR ANY CLAIM, DAMAGES,
# OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT, OR OTHERWISE,
# ARISING FROM, OUT OF, OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER
# DEALINGS IN THE WORK.

# :title: Novell Migration Utility - ntuserls
# ==Description: 
# Class representing rights for NSS
# 
module Migration
  module Windows
    module Rights
      $:.unshift File.expand_path(File.join(File.dirname(__FILE__)))
      require 'nss_values'     
      $:.shift 
       
      $:.unshift File.expand_path(File.join(File.dirname(__FILE__), '..'))
      require 'exceptions'
      $:.shift           
      
      class NSS_rights
        include Migration::Windows::Rights::NSS
        
        attr_reader :raw_rights
        
        def initialize( rights = nil)
          if rights.nil?
            @raw_rights = 0x0
          else
            self.from_s( rights )
          end
        end
        
        def +( other )
          if other.class === self 
            @raw_rights |= other.raw_rights
          else
            raise RightsError, 
              "Cannot add #{other.class} to NSS rights. Invalid + operation", caller
          end
        end
        def -( other )  
          if other.kind_of? self     
            self.remove_supervisor if other.has_supervisor?
            self.remove_read if other.has_read?
            self.remove_write if other.has_write?
            self.remove_create if other.has_create?
            self.remove_erase if other.has_erase?
            self.remove_modify if other.has_modify?
            self.remove_file_scan if other.has_file_scan?
            self.remove_access_control if other.has_access_control?
          else
            raise RightsError, 
              "Cannot remove #{other.class} from NSS rights. Invalid - operation.", caller
          end          
        end
  
        # Returns the contents of _raw_rights_ as a formatted
        # rights string "SRWC.."
        # 
        def to_s
          return nil if @raw_rights == 0x0
          rights = ""
          
          raw = @raw_rights
          val = MAX_NSS_RIGHT
          
          8.times do 
            if raw / val > 0
              rights += case ( val )
                            when nil,  ""
                            when 0x0,  ""
                            when NSS_SUPERVISOR  
                              NSS_SUPERVISOR_C
                            when NSS_READ  
                              NSS_READ_C
                            when NSS_WRITE  
                              NSS_WRITE_C
                            when NSS_CREATE  
                              NSS_CREATE_C
                            when NSS_ERASE  
                            NSS_ERASE_C   
                            when NSS_MODIFY  
                              NSS_MODIFY_C
                            when NSS_FILE_SCAN  
                              NSS_FILE_SCAN_C
                            when NSS_ACCESS_CONTROL  
                              NSS_ACCESS_CONTROL_C     
                            else
                              raise RightsError, "Invalid right 0x#{@raw_rights.to_i.to_s(2)}, #{@raw_rights} for NSS rights.", caller
                            end
            end
            raw = raw % val
            val /= 2
          end
          return rights
        end  

        # Takes a rights string in the format of to_s and 
        # converts it to raw rights
        # 
        def from_s( rights_string )
          return nil if rights_string.nil?
          @raw_rights = 0
          rights_string.upcase!
          
          rights_string.split(//).each do |right|
            @raw_rights |= case right
                           when " " 
                             0x0
                           when NSS_SUPERVISOR_C  
                             NSS_SUPERVISOR
                           when NSS_READ_C  
                             NSS_READ
                           when NSS_WRITE_C  
                             NSS_WRITE
                           when NSS_CREATE_C  
                             NSS_CREATE
                           when NSS_ERASE_C  
                             NSS_ERASE   
                           when NSS_MODIFY_C  
                             NSS_MODIFY
                           when NSS_FILE_SCAN_C  
                             NSS_FILE_SCAN
                           when NSS_ACCESS_CONTROL_C  
                             NSS_ACCESS_CONTROL     
                           else
                             raise RightsError, "Invalid right #{right} for NSS rights.", caller
                           end
          end
        end

        # Takes an array of NSS rights in string form and adds
        # them to raw rights
        # 
        def add_rights( rights )
          return nil if rights.nil?
          
          rights.each do |right|
            @raw_rights |= case right
                           when " "
                             0x0
                           when "NSS_SUPERVISOR"  
                             NSS_SUPERVISOR
                           when "NSS_READ"  
                             NSS_READ
                           when "NSS_WRITE"  
                             NSS_WRITE
                           when "NSS_CREATE"  
                             NSS_CREATE
                           when "NSS_ERASE"  
                             NSS_ERASE   
                           when "NSS_MODIFY"  
                             NSS_MODIFY
                           when "NSS_FILE_SCAN"  
                             NSS_FILE_SCAN
                           when "NSS_ACCESS_CONTROL"  
                             NSS_ACCESS_CONTROL     
                           else
                             raise RightsError, "Invalid right #{right} for NSS rights.", caller
                           end
          end
        end       
        def add_supervisor
          @raw_rights |= NSS_SUPERVISOR
        end
        def add_read
          @raw_rights |= NSS_READ        
        end
        def add_write
          @raw_rights |= NSS_WRITE        
        end
        def add_create
          @raw_rights |= NSS_CREATE        
        end
        def add_erase
          @raw_rights |= NSS_ERASE        
        end
        def add_modify
          @raw_rights |= NSS_MODIFY        
        end
        def add_file_scan
          @raw_rights |= NSS_FILE_SCAN        
        end
        def add_access_control
          @raw_rights |= NSS_ACCESS_CONTROL
        end
        def add_all
          #Supervisor should not be a standard add all right
          #self.add_supervisor
          self.add_read
          self.add_write
          self.add_erase
          self.add_create
          self.add_modify
          self.add_file_scan
          self.add_access_control
        end

        # Takes an array of NSS rights in string form and removes
        # them from raw rights
        # 
        def remove_rights( rights )
          return nil if rights.nil?

          rights.each do |right|
            case right
            when " " 
               0x0
             when "NSS_SUPERVISOR"  
               self.remove_supervisor
             when "NSS_READ"  
               self.remove_read
             when "NSS_WRITE"  
               self.remove_write
             when "NSS_CREATE"  
               self.remove_create
             when "NSS_ERASE"  
               self.remove_erase
             when "NSS_MODIFY"  
               self.remove_modify
             when "NSS_FILE_SCAN"  
               self.remove_file_scan
             when "NSS_ACCESS_CONTROL"  
               self.remove_access_control  
             else
               raise RightsError, "Invalid right #{right} for NSS rights.", caller
            end
          end
        end           
        def remove_supervisor
          @raw_rights ^= NSS_SUPERVISOR if self.contains?( NSS_SUPERVISOR )
        end
        def remove_read
          @raw_rights ^= NSS_READ if self.contains?( NSS_READ )      
        end
        def remove_write
          @raw_rights ^= NSS_WRITE if self.contains?( NSS_WRITE )
        end
        def remove_create
          @raw_rights ^= NSS_CREATE if self.contains?( NSS_CREATE )
        end
        def remove_erase
          @raw_rights ^= NSS_ERASE if self.contains?( NSS_ERASE )        
        end
        def remove_modify
          @raw_rights ^= NSS_MODIFY if self.contains?( NSS_MODIFY )
        end
        def remove_file_scan
          @raw_rights ^= NSS_FILE_SCAN if self.contains?( NSS_FILE_SCAN )
        end
        def remove_access_control
          @raw_rights ^= NSS_ACCESS_CONTROL if self.contains?( NSS_ACCESS_CONTROL )
        end        
        def remove_all
          @raw_rights = 0x0
        end
 
        def contains?( raw_right )
          if(@raw_rights & raw_right) == raw_right then true
          else false
          end
        end        
        
        def has_supervisor?
          self.contains?( NSS_SUPERVISOR )
        end
        def has_read?
          self.contains?( NSS_READ )
        end
        def has_write?
          self.contains?( NSS_WRITE )
        end
        def has_create?
          self.contains?( NSS_CREATE )
        end
        def has_erase?
          self.contains?( NSS_ERASE )
        end
        def has_modify?
          self.contains?( NSS_MODIFY )
        end
        def has_file_scan?
          self.contains?( NSS_FILE_SCAN )
        end
        def has_access_control?
          self.contains?( NSS_ACCESS_CONTROL )
        end

        def empty?
          @raw_rights === 0 ? true : false
        end
      end
    end
  end
end
