# Copyright (C) [2006-2007] Novell, Inc.  All Rights Reserved.

# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# IT MAY NOT BE USED, COPIED, DISTRIBUTED, DISCLOSED, ADAPTED, PERFORMED,
# DISPLAYED, COLLECTED, COMPILED, OR LINKED WITHOUT NOVELL'S PRIOR WRITTEN
# CONSENT.  USE OR EXPLOITATION OF THIS WORK WITHOUT AUTHORIZATION COULD
# SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.

# NOVELL PROVIDES THE WORK "AS IS," WITHOUT ANY EXPRESS OR IMPLIED WARRANTY,
# INCLUDING WITHOUT THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE, AND NON-INFRINGEMENT. NOVELL, THE AUTHORS OF THE WORK,
# AND THE OWNERS OF COPYRIGHT IN THE WORK ARE NOT LIABLE FOR ANY CLAIM, DAMAGES,
# OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT, OR OTHERWISE,
# ARISING FROM, OUT OF, OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER
# DEALINGS IN THE WORK.

# :title: Novell Migration Utility - ntuserls
# ==Description: 
# Class representing a NTFS file system object.
# 
module Migration
  module Windows
    module Rights
      $:.unshift File.expand_path(File.join(File.dirname(__FILE__)))
      require 'ace'
      require 'ntfs_rights' 
      $:.shift  

      $:.unshift File.expand_path(File.join(File.dirname(__FILE__), '..'))
      require 'exceptions'
      $:.shift 
      
      # TODO: Add rdoc
      class NTFS_object
       
        attr_accessor( :path, :revision, :owner, :group, :acl, :attrs, :quotas)
        
        def initialize
          @acl = Array.new
          @quotas = Array.new
        end
              
        def ==( other )
          return false unless self.path == other.path
          return false unless self.revision == other.revision
          return false unless self.owner == other.owner
          return false unless self.group == other.group
          return false unless self.acl == other.acl
	  return false unless self.attrs == other.attrs
	  return false unless self.quotas == other.quotas
          return true
        end        
        
        def add_ace( name, ace )
          @acl << Ace::NTFS_Ace.new( ace, name , nil)
        end

        def add_quotas( quota )
          @quotas << quota
        end
        
        # Returns a list of users attached to this object
        def get_user_list
          user_list = []
          
          @acl.each { |ntfs_ace| 
            user_list << ntfs_ace.name
          }
          user_list.compact!
          return [] if user_list.empty? or user_list.nil?
          return user_list.uniq
        end

        def get_user_list_from_quota
          
          user_quota_list = []
          @quotas.each do |ntfs_quota|
            user_quota_list << ntfs_quota
          end 
          user_quota_list.compact!
          return [] if user_quota_list.empty? or user_quota_list.nil?
          return user_quota_list.uniq
        end
                    

       def set_attr (atr)
		@attrs = atr
	end 
        # Finds all the ACL's associated with a user name
        def find_user_acl( name )
          @acl.find_all { |ntfs_ace| ntfs_ace.name == name }
        end
        
        # Finds a specific ACE
        def find_ace( ace )
          @acl.find { |ntfs_ace| ntfs_ace == ace }
        end
        
        def is_directory?
          path =~ /^\\.*\\$/ ? true : false
        end
        
        def to_yaml_type # :nodoc:
          "!novell.com,1984/ntfs_rights_object"
        end 
               
        def to_yaml_properties # :nodoc:
          [ '@path', '@revision', '@owner', '@group', '@acl', '@attrs', '@quotas' ]
        end
      end
    end
  end
end
