# Copyright (C) [2006-2007] Novell, Inc.  All Rights Reserved.

# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# IT MAY NOT BE USED, COPIED, DISTRIBUTED, DISCLOSED, ADAPTED, PERFORMED,
# DISPLAYED, COLLECTED, COMPILED, OR LINKED WITHOUT NOVELL'S PRIOR WRITTEN
# CONSENT.  USE OR EXPLOITATION OF THIS WORK WITHOUT AUTHORIZATION COULD
# SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.

# NOVELL PROVIDES THE WORK "AS IS," WITHOUT ANY EXPRESS OR IMPLIED WARRANTY,
# INCLUDING WITHOUT THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE, AND NON-INFRINGEMENT. NOVELL, THE AUTHORS OF THE WORK,
# AND THE OWNERS OF COPYRIGHT IN THE WORK ARE NOT LIABLE FOR ANY CLAIM, DAMAGES,
# OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT, OR OTHERWISE,
# ARISING FROM, OUT OF, OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER
# DEALINGS IN THE WORK.

# :title: Novell Migration Utility - ntuserls
# ==Description: 
# Module for NTFS file system informaiton
# * Access Types
# * Inheritance Flags
# * Standard Rights
# * NTFS 4.0 Rights
# * NTFS 5.0, 5.1 Atomic Rights
# * NTFS 5.0, 5.1 Molecular Rights
# 
module Migration
  module Windows
    module Rights
      module NTFS
        $:.unshift File.expand_path(File.join(File.dirname(__FILE__), '..'))
        require 'exceptions'
        $:.shift               
        
        ###############################################################
        #WinNT.h mappings
        #Access Types
        ###############################################################
        class NTFS_Type < Hash 
          def initialize
            self["NTFS_TYPE_ALLOW"]                   = 0x0000
            self["NTFS_TYPE_DENY"]                    = 0x0001
            self["NTFS_TYPE_SYSTEM_AUDIT"]            = 0x0002
            self["NTFS_TYPE_ALLOWED_OBJECT"]          = 0x0005 
            self["NTFS_TYPE_DENIED_OBJECT"]           = 0x0006
            self["NTFS_TYPE_SYSTEM_AUDIT_OBJECT"]     = 0x0007
          end
        end
        
        ###############################################################
        #WinNT.h mappings
        #Inheritance Flags
        ###############################################################
        MAX_NTFS_FLAGS = 0x80

        class NTFS_Flags < Hash
          def initialize
            self["NTFS_FLAG_OBJECT_INHERIT_ACE"]        = 0x0001
            self["NTFS_FLAG_CONTAINER_INHERIT_ACE"]     = 0x0002
            self["NTFS_FLAG_NO_PROPIGATE_INHERIT_ACE"]  = 0x0004
            self["NTFS_FLAG_INHERIT_ONLY_ACE"]          = 0x0008
            self["NTFS_FLAG_INHERITED_ACE"]             = 0x0010
            self["NTFS_FLAG_VALID_INHERIT_ACE"]         = 0x001F # Souldn't this be 0x0020?
            self["NTFS_FLAG_ADS_SUCCESSFUL_ACCESS"]     = 0x0040
            self["NTFS_FLAG_ADS_FAILED_ACCESS"]         = 0x0080       
          end
        end
      
        ###############################################################
        #WinNT.h mappings
        #Standard Rights 
        ###############################################################
        MAX_NTFS_MASKS = 0x80000000

        class NTFS_Masks < Hash
          def initialize
            self["NTFS_DELETE"]                         = 0x00010000
            self["NTFS_READ_CONTROL"]                   = 0x00020000
            self["NTFS_WRITE_DAC"]                      = 0x00040000
            self["NTFS_WRITE_OWNER"]                    = 0x00080000
            self["NTFS_SYNCHRONIZE"]                    = 0x00100000
            self["NTFS_STANDARD_RIGHTS_REQUIRED"]       = 0x000F0000
            self["NTFS_STANDARD_READ"]                  = "NTFS_READ_CONTROL"
            self["NTFS_STANDARD_WRITE"]                 = "NTFS_READ_CONTROL"
            self["NTFS_STANDARD_EXECUTE"]               = "NTFS_READ_CONTROL"
            self["NTFS_STANDARD_RIGHTS_ALL"]            = 0x001F0000
            self["NTFS_SPECIFIC_RIGHTS_ALL"]            = 0x0000FFFF
            self["NTFS_ACCESS_SYSTEM_SECURITY"]         = 0x01000000
            self["NTFS_MAXIMUM_ALLOWED"]                = 0x02000000
            self["NTFS_GENERIC_READ"]                   = 0x80000000
            self["NTFS_GENERIC_WRITE"]                  = 0x40000000
            self["NTFS_GENERIC_EXECUTE"]                = 0x20000000
            self["NTFS_GENERIC_ALL"]                    = 0x10000000
            self["NTFS_FILE_READ_DATA"]                 = 0x0001   
            self["NTFS_FILE_LIST_DIRECTORY"]            = "NTFS_FILE_LIST_DIRECTORY"
            self["NTFS_FILE_WRITE_DATA"]                = 0x0002  
            self["NTFS_FILE_ADD_FILE"]                  = "NTFS_FILE_WRITE_DATA"
            self["NTFS_FILE_APPEND_DATA"]               = 0x0004   
            self["NTFS_FILE_ADD_SUBDIRECTORY"]          = "NTFS_FILE_ADD_SUBDIRECTORY"
            self["NTFS_FILE_CREATE_PIPE_INSTANCE"]      = "NTFS_FILE_ADD_SUBDIRECTORY"
            self["NTFS_FILE_READ_EA"]                   = 0x0008   
            self["NTFS_FILE_WRITE_EA"]                  = 0x0010   
            self["NTFS_FILE_EXECUTE"]                   = 0x0020   
            self["NTFS_FILE_TRAVERSE"]                  = "NTFS_FILE_EXECUTE"
            self["NTFS_FILE_DELETE_CHILD"]              = 0x0040   
            self["NTFS_FILE_READ_ATTRIBUTES"]           = 0x0080   
            self["NTFS_FILE_WRITE_ATTRIBUTES"]          = 0x0100   
            self["NTFS_FILE_ALL_ACCESS"]                = self["NTFS_STANDARD_RIGHTS_REQUIRED"] | 
                                                          self["NTFS_SYNCHRONIZE"] | 0x1FF                  #0x001f01ff  
            self["NTFS_FILE_GENERIC_READ"]              = self["NTFS_READ_CONTROL"] | self["NTFS_FILE_READ_DATA"] | 
                                                          self["NTFS_FILE_READ_ATTRIBUTES"] | 
                                                          self["NTFS_FILE_READ_EA"] | self["NTFS_SYNCHRONIZE"]
            self["NTFS_FILE_GENERIC_WRITE"]             = self["NTFS_READ_CONTROL"] | self["NTFS_FILE_WRITE_DATA"] | 
                                                          self["NTFS_FILE_WRITE_ATTRIBUTES"] | self["NTFS_FILE_WRITE_EA"] | 
                                                          self["NTFS_FILE_APPEND_DATA"] | self["NTFS_SYNCHRONIZE"]
            self["NTFS_FILE_GENERIC_EXECUTE"]           = self["NTFS_READ_CONTROL"] | self["NTFS_FILE_READ_ATTRIBUTES"] |
                                                          self["NTFS_FILE_EXECUTE"] | self["NTFS_SYNCHRONIZE"]
            #self["NTFS_FILE_SHARE_READ"]                = 0x00000001  
            #self["NTFS_FILE_SHARE_WRITE"]               = 0x00000002
            #self["NTFS_FILE_SHARE_DELETE"]              = 0x00000004         
      
            ###############################################################
            #NTFS 4.0 - WINDOWS NT 4.0
            ###############################################################
            self["NT4_FULL_CONTROL"]                    = "NTFS_FILE_ALL_ACCESS"
            self["NT4_READ"]                            = self["NTFS_READ_CONTROL"] |                 #0x001200a9
                                                          self["NTFS_FILE_EXECUTE"] |
                                                          self["NTFS_FILE_READ_ATTRIBUTES"] | self["NTFS_FILE_READ_DATA"] | 
                                                          self["NTFS_FILE_READ_EA"] | self["NTFS_SYNCHRONIZE"]                   
            self["NT4_LIST"]                            = "NT4_READ"     
            self["NT4_ADD"]                             = self["NTFS_READ_CONTROL"] |                 #0x001201b6
                                                          self["NTFS_FILE_WRITE_ATTRIBUTES"] |
                                                          self["NTFS_FILE_WRITE_EA"] | self["NTFS_FILE_EXECUTE"] | 
                                                          self["NTFS_FILE_READ_ATTRIBUTES"] |
                                                          self["NTFS_FILE_WRITE_DATA"] | self["NTFS_FILE_WRITE_DATA"] |
                                                          self["NTFS_FILE_APPEND_DATA"] |
                                                          self["NTFS_SYNCHRONIZE"]                   
            #NT4_ADD_AND_READ                    = MOLECULAR_ADD | MOLECULAR_READ
            self["NT4_CHANGE"]                          = self["NTFS_DELETE"] | self["NTFS_READ_CONTROL"] |   #0x001301bf
                                                          self["NTFS_FILE_WRITE_ATTRIBUTES"] |
                                                          self["NTFS_FILE_WRITE_EA"] | self["NTFS_FILE_EXECUTE"] | 
                                                          self["NTFS_FILE_EXECUTE"] | self["NTFS_FILE_READ_ATTRIBUTES"] |                                   
                                                          self["NTFS_FILE_READ_DATA"] | self["NTFS_FILE_WRITE_DATA"] |
                                                          self["NTFS_FILE_APPEND_DATA"] | self["NTFS_FILE_READ_EA"] |                                             
                                                          self["NTFS_SYNCHRONIZE"]                   
            self["NT4_NO_ACCESS"]                       = "NTFS_FILE_ALL_ACCESS"
      
            ###############################################################
            #NTFS 5.0/5.1 - WINDOWS 2000/2003      
            #Advanced / Atomic rights section
            ###############################################################
            self["ATOMIC_LIST_FOLDER_READ_DATA"]        = "NTFS_FILE_READ_DATA"
            self["ATOMIC_CREATE_FILES_WRITE_DATA"]      = "NTFS_FILE_WRITE_DATA"         
            self["ATOMIC_CREATE_FOLDERS_APPEND_DATA"]   = "NTFS_FILE_APPEND_DATA"
            self["ATOMIC_READ_EXTENDED_ATTRIBUTES"]     = "NTFS_FILE_READ_EA"                   
            self["ATOMIC_WRITE_EXTENDED_ATTRIBUTES"]    = "NTFS_FILE_WRITE_EA"                  
            self["ATOMIC_TRAVERSE_FOLDER_EXECUTE_FILE"] = "NTFS_FILE_EXECUTE"               
            self["ATOMIC_READ_ATTRIBUTES"]              = "NTFS_FILE_READ_ATTRIBUTES"           
            self["ATOMIC_WRITE_ATTRIBUTES"]             = "NTFS_FILE_WRITE_ATTRIBUTES"          
            self["ATOMIC_DELETE"]                       = "NTFS_DELETE"                       
            self["ATOMIC_READ_PERMISSIONS"]             = "NTFS_READ_CONTROL"
            self["ATOMIC_CHANGE_PERMISSIONS"]           = "NTFS_WRITE_DAC"                     
            self["ATOMIC_TAKE_OWNERSHIP"]               = "NTFS_WRITE_OWNER"                   
            self["ATOMIC_FULL_CONTROL"]                 = "NTFS_FILE_ALL_ACCESS"
            self["ATOMIC_READ"]                         = "NTFS_FILE_GENERIC_READ"
            self["ATOMIC_WRITE"]                        = "NTFS_FILE_GENERIC_WRITE"
            self["ATOMIC_EXECUTE"]                      = "NTFS_FILE_GENERIC_EXECUTE"    
      
            ###############################################################
            #NTFS 5.0/5.1 - WINDOWS 2000/2003
            #Standard / Molecular rights
            ###############################################################
            self["MOLECULAR_READ"]                      = "NTFS_FILE_GENERIC_READ"            
            self["MOLECULAR_WRITE"]                     = "NTFS_FILE_GENERIC_WRITE"           #0x00120116 -> 0x00100116 ??
            self["MOLECULAR_LIST_FOLDER_CONTENTS"]      = "NT4_READ"           
            self["MOLECULAR_READ_AND_EXECUTE"]          = "NT4_READ"
            self["MOLECULAR_MODIFY"]                    = "NT4_CHANGE"                        
            self["MOLECULAR_FULL_CONTROL"]              = "NTFS_FILE_ALL_ACCESS" 
          end
          
          def lcr_value( key )
            if self.has_key?( key )
              if self[key].class == String
                return self[self[key]]
              else
                return self[key]
              end
            else
              raise RightsError, "Invalid least common NTFS right: #{key}"
            end
          end
          def lcr_key( key )        
            if self.has_key?( key )
              if self[key].class == String
                return self[ key ]
              else
                return key
              end
            else
              raise RightsError, "Invalid least common NTFS right: #{key}"
            end
          end
          def lcr_only
            self.delete_if { |k,v| v.class == String }
          end
        end          
      end
    end
  end
end
