# Copyright (C) [2006-2007] Novell, Inc.  All Rights Reserved.

# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# IT MAY NOT BE USED, COPIED, DISTRIBUTED, DISCLOSED, ADAPTED, PERFORMED,
# DISPLAYED, COLLECTED, COMPILED, OR LINKED WITHOUT NOVELL'S PRIOR WRITTEN
# CONSENT.  USE OR EXPLOITATION OF THIS WORK WITHOUT AUTHORIZATION COULD
# SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.

# NOVELL PROVIDES THE WORK "AS IS," WITHOUT ANY EXPRESS OR IMPLIED WARRANTY,
# INCLUDING WITHOUT THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE, AND NON-INFRINGEMENT. NOVELL, THE AUTHORS OF THE WORK,
# AND THE OWNERS OF COPYRIGHT IN THE WORK ARE NOT LIABLE FOR ANY CLAIM, DAMAGES,
# OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT, OR OTHERWISE,
# ARISING FROM, OUT OF, OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER
# DEALINGS IN THE WORK.

# :title: Novell Migration Utility - ntuserls
# ==Description: 
# Translator takes the default map file or a specfied one and loades a new rights map.
# It then will translate a NTFS right to a NSS right
# 
module Migration
  module Windows
    module Rights
      $:.unshift File.expand_path(File.join(File.dirname(__FILE__))) 
      require 'ace'     
      require 'nss_rights' 
      require 'nss_object'  
      require 'ntfs_values'   
      $:.shift        
      
      $:.unshift File.expand_path(File.join(File.dirname(__FILE__), '..'))
      require 'exceptions'
      $:.shift 
      
      require 'yaml'   
      
      #Default map used for mapping rights
      DEFAULT_MAP = File.expand_path(File.join(File.dirname(__FILE__), 
          '..', 'etc', 'generic_map.yaml'))      
      
      InheritedRight = Struct.new(:explicit, :irm, :file, :directory )
      
      class Translator
        class Rights_map < Hash
          def initialize( yaml_map = DEFAULT_MAP )
            reverse_map = YAML.load_file( yaml_map )
            ntfs_masks = NTFS::NTFS_Masks.new
            
            self.merge!( ntfs_masks.lcr_only )
            self.each_key { |k| self[k] = [] }
            
            reverse_map.each_pair do |k,v|
              unless v.nil? or v.empty?
                v.each do |ntfs_right|              
                  self[ ntfs_masks.lcr_key( ntfs_right ) ] << k
                end
              end
            end
            self.each_value { |v| v.uniq! }
          end
        end      
        
        def initialize( type, map_file = nil )
          if type == :inherited
            @type = true
          elsif type == :static
            @type = false
          else
            raise "WRONG TYPE!!!!!!!!!!!!!"
          end
           
          if  map_file.nil?
            @rights_map = Rights_map.new                
          else
            @rights_map = Rights_map.new( map_file )
          end
        end
        
        def map( ntfs_ace )      
          nss_rights = []
          ntfs_ace.ace.get_rights.each do |right|
            ntfs_rights = @rights_map[right]
            unless ntfs_rights.nil?
              nss_rights << ntfs_rights
            end
          end
          nss_rights.flatten!
          nss_rights.uniq!

          nss_rights
        end

        def discover( right, parent = nil ) 
          ir = InheritedRight.new( false, false, false, false )
        
          # The right has a inheritance flag set some where.  We do not
          # know where it is yet but it is a inheritance flag 
          if right.has_inheritance? 
            #####################################################    
            # Grab the sub folders and files that are inherited
            #####################################################      # 
            if right.has_ntfs_flag_inherited_ace?
              # Folders that have inheritable rights
              if right.has_ntfs_flag_container_inherit_ace?
                #Folders objects will inherit the folders ace
                if right.has_ntfs_flag_object_inherit_ace?
                  #Also togle the bit
                  #puts "Inherited: Folder/Object: Inherited ACE: Check for inheritance flag for explicit rights "
                  ir.explicit = true if not parent.nil? and parent.inheritance.directory
                else
                  #ACE only applies to folders only          
                  #puts "Inhertied: Folder: Explicit ACE : Full IRM" 
                  ir.explicit = true
                  ir.irm = true             
                end 
              #ACL on folder that applies to files only  
              elsif right.has_ntfs_flag_object_inherit_ace? and
                right.has_ntfs_flag_inherit_only_ace?
                # This folder and files: Sub folder
                #puts "Inherited: Folder only applies to files: flag for files explicit ace"
                ir.file = true                               
              elsif right.has_ntfs_flag_inherited_ace?
                ir.explicit = parent.inheritance.file unless parent.nil?
              end 
            
            #####################################################
            # Not an in herited ace this is a root ace
            ##################################################### 
            else 
              # Grab all folders
              if right.has_ntfs_flag_container_inherit_ace?
                # Is this a full inheritance ace?
                if right.has_ntfs_flag_object_inherit_ace?
                  if right.has_ntfs_flag_inherit_only_ace?
                    #puts "Folder: Applies to Objects/Folders only: Flag for explicit aces on folders or files!"
                    ir.file = true            
                    ir.directory = true
                  else
                    #puts "Folder: Explicit ACE: NO IRM"
                    ir.explicit = true            
                  end
                elsif right.has_ntfs_flag_inherit_only_ace?
                  # Will be caught by the subfolders and flagged for full irm.
                  # Do nothing
                  # puts "Folder: Applies to Sub Folders only: Can be skipped"
                else
                  #puts "Folder: Folder only Explicit ACE: FULL IRM"
                  ir.explicit = true
                  ir.irm = true          
                end
              elsif right.has_ntfs_flag_object_inherit_ace?
                unless right.has_ntfs_flag_inherit_only_ace?
                  #Flag for inheritance on files
                  #applies to This folder and files.  Does the folder need a ACE with full irm?
                  #puts "Folder: Explicit ACE full IRM?"
                  ir.explicit = true
                  ir.irm = true
                  ir.file = true
                else
                  #This folder and file root!
                  ir.file = true
                end
              else
                raise RightsError, "Cannot translate #{right.class}.  Invalid inheritance type", caller
                #puts "OBJECT/FOLDER: Explict ACE full IRM"
                #ir.explicit = true
                #ir.irm = true
              end
            end
          else
            #puts "OBJECT/FOLDER: Explicit ACE full IRM"
            ir.explicit = true
            ir.irm = true
          end
          
          ir
        end
        
        def sorter( user_acl )
          id = []   # Inherited Deny
          ia = []   # Inherited Allow
          ed = []   # Explicit Deny
          ea = []   # Explicit Allow
          
          #Find the freaking acl types.
          user_acl.each do |ntfs_ace|          
            if ntfs_ace.ace.has_inheritance? 
              if ntfs_ace.ace.has_ntfs_type_allow?
                ia << ntfs_ace
              elsif ntfs_ace.ace.has_ntfs_type_deny?
                id << ntfs_ace
              else
                raise RightsError, "NTFS Right type is currently unsupported: #{ntfs_ace.ace.raw_type}", caller
              end
            else
              if ntfs_ace.ace.has_ntfs_type_allow?
                ea << ntfs_ace
              elsif ntfs_ace.ace.has_ntfs_type_deny?
                ed << ntfs_ace
              else
                raise RightsError, "NTFS Right type is currently unsupported: #{ntfs_ace.ace.raw_type}", caller
              end    
            end
          end
          
          return id, ia, ed, ea        
        end
        
        def blender( user_acl, parent )
          nss_rights = NSS_rights.new
          nss_irm = NSS_rights.new
          
          if @type
            user_acl.each { |ace|  ace.inheritance = discover( ace.ace,
                parent.nil? ? nil : parent.find_ace( ace )) }
                  
            id, ia, ed, ea = sorter( user_acl )
                      
            #ORDER MATTERS!
            # Process inherited allow
            ia.each do |ia_ace|
              nss_rights.add_rights( self.map( ia_ace )) if ia_ace.inheritance.explicit
              nss_irm.add_rights( self.map( ia_ace )) if ia_ace.inheritance.irm 
            end 
            # Process inherited deny
            id.each do |id_ace|
              nss_rights.remove_rights( self.map( id_ace )) if id_ace.inheritance.explicit
              nss_irm.add_rights( self.map( id_ace)) if id_ace.inheritance.irm
            end
            # Process explicit allow
            ea.each do |ea_ace|
              nss_rights.add_rights( self.map( ea_ace )) 
              nss_irm.add_rights( self.map( ea_ace )) 
            end
            # Process explicit deny
            ed.each do |ed_ace|
              nss_rights.remove_rights( self.map( ed_ace ))
              nss_irm.add_rights( self.map( ed_ace )) 
            end
          else 
            nss_irm.add_all
          
            user_acl.each do |ace|
              if ace.ace.has_ntfs_type_allow?
                nss_rights.add_rights( self.map( ace ))
              elsif ace.ace.has_ntfs_type_deny?
                nss_rights.remove_rights( self.map( ace ))
              else
                raise RightsError, "Invalid NTFS ACE type #{ace}. ACE must be either Allow or Deny", caller
              end
            end            
          end
          
          if nss_irm.empty? and nss_rights.empty?
            nil
          else
            Ace::NSS_Ace.new( nss_irm, user_acl.first.name, nss_rights )
          end          
        end
       # we do not need tree as it is increasing memory usage 
       # This function now will take ntfs_object as its argument and process it
        #def translate_tree( tree_enumerator, volume )
        def translate_tree( ntfs_object, volume )
          unless block_given?
            raise RightsError, "Block must be given to translate tree.", caller
          end
          
            if ntfs_object.nil?
              return
            end
            nss_object = NSS_object.new( volume, ntfs_object.path )
              
	    nss_object.set_attrs( ntfs_object.attrs)
	    #nss_object.set_quota( ntfs_object.quota)
            ntfs_object.get_user_list_from_quota.each do |ntfs_quota|
           # quota = ntfs_object.get_quota(user)
              nss_object.add_quota(ntfs_quota)
            end
            ntfs_object.get_user_list.each do |user|
              nss_object.add_ace( self.blender( 
                ntfs_object.find_user_acl( user ), 
                nil ))
            end
            
            yield nss_object
        end        
      end
    end 
  end
end
