# Copyright (C) [2006-2007] Novell, Inc.  All Rights Reserved.

# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# IT MAY NOT BE USED, COPIED, DISTRIBUTED, DISCLOSED, ADAPTED, PERFORMED,
# DISPLAYED, COLLECTED, COMPILED, OR LINKED WITHOUT NOVELL'S PRIOR WRITTEN
# CONSENT.  USE OR EXPLOITATION OF THIS WORK WITHOUT AUTHORIZATION COULD
# SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.

# NOVELL PROVIDES THE WORK "AS IS," WITHOUT ANY EXPRESS OR IMPLIED WARRANTY,
# INCLUDING WITHOUT THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE, AND NON-INFRINGEMENT. NOVELL, THE AUTHORS OF THE WORK,
# AND THE OWNERS OF COPYRIGHT IN THE WORK ARE NOT LIABLE FOR ANY CLAIM, DAMAGES,
# OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT, OR OTHERWISE,
# ARISING FROM, OUT OF, OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER
# DEALINGS IN THE WORK.

# :title: Novell Migration Utility - ntuserls
# ==Description: 
# Module methods for using Samba's smbcacls program.  
# 
module Migration
  module Windows
    module SambaLib   
      # Uses smbclient to retrieve a listing of folders and files from the source servers share. 
      # 
      # :call-seq:
      #   get_directory_listing -> array
      #   
      # Returns a sorted array of directory and file listings
      def get_netbios_info     
        self.command( :nmblookup ) do |line|
          case line 
          when /^(.*)\s+<00>\s-\s+[A-Z]\s<ACTIVE>/
            @netbios_name = $1
          when /^(.*)\s+<00>\s-\s<GROUP>\s[A-Z]\s<ACTIVE>/   
            @domain_member = true #if $1.strip.downcase == @domain.downcase
          when /<1c>/
            @dc = true
          when /<1b>/
            @pdc = true
          else
          end
        end       
      end
      
      # Translates netbios information into a readable hash.
      def get_netbios_translation
        netbios = Hash.new( false )
        
        self.command( :nmblookup ) do |line|
          case line 
          when /^(.*)\s+<00>\s-\s+[A-Z]\s<ACTIVE>/
            netbios[:computer] = $1.strip
          when /^(.*)\s+<00>\s-\s<GROUP>\s[A-Z]\s<ACTIVE>/   
            netbios[:domain] = $1.strip
          when /<20>/
            netbios[:server] = true
          when /<1c>/
            netbios[:dc] = true
          when /<1b>/
            netbios[:pdc] = true
          when /<1d>/
            netbios[:browser_master] = true
          when /<1e>/
            netbios[:browser] = true
          when /MSBrowse/
            netbios[:browser_domain] = true
          else
          end        
        end
        return netbios
      end 
    end
  end
end
