# Copyright (C) [2006-2007] Novell, Inc.  All Rights Reserved.

# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# IT MAY NOT BE USED, COPIED, DISTRIBUTED, DISCLOSED, ADAPTED, PERFORMED,
# DISPLAYED, COLLECTED, COMPILED, OR LINKED WITHOUT NOVELL'S PRIOR WRITTEN
# CONSENT.  USE OR EXPLOITATION OF THIS WORK WITHOUT AUTHORIZATION COULD
# SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.

# NOVELL PROVIDES THE WORK "AS IS," WITHOUT ANY EXPRESS OR IMPLIED WARRANTY,
# INCLUDING WITHOUT THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE, AND NON-INFRINGEMENT. NOVELL, THE AUTHORS OF THE WORK,
# AND THE OWNERS OF COPYRIGHT IN THE WORK ARE NOT LIABLE FOR ANY CLAIM, DAMAGES,
# OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT, OR OTHERWISE,
# ARISING FROM, OUT OF, OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER
# DEALINGS IN THE WORK.

module Migration
  module Windows
    $:.unshift File.expand_path(File.join(File.dirname(__FILE__), '..', '..'))
    require 'safe_pty'   
    require 'keystore'  
    $:.shift

    $:.unshift File.expand_path(File.join(File.dirname(__FILE__), '..' ))
    require 'exceptions'     
    $:.shift
   
    $:.unshift File.expand_path(File.join(File.dirname(__FILE__)))
    require 'nmblookup'
    require 'rpcclient'  
    require 'smbcacls'
    require 'smbclient'
    $:.shift   
    
    class Samba
      include Migration::Windows::SambaLib
      
      def initialize( source, share, usecasa = false )
        @source = source
        @share = share
        
        @domain_member = false
        @dc = false 
        @pdc = false
        @netbios_name = ""
        
        # Collection of Domain SID to User name mappings
        @sids = Hash.new       
        # Domain RID to user names/groups
        @rid_map = Hash.new     
 	@credentials = KeyStore.credential( @source, :cn, usecasa )        
        
        if @credentials.nil? or @credentials[:username].empty?
          raise ArgumentError, "Credentials for host #{@soruce} are empty.", caller
        end
            
        self.get_netbios_info  
        unless @share.nil?
          raise SambaError, 
            "The share #{@share} does not exist on the #{@source} server or invalid credentials.", 
            caller unless self.has_share?( @share )
        end
      end
        
      def is_member_of_domain?
        @domain_member
      end
      
      def is_dc?
        @dc
      end
      
      def is_pdc?
        @pdc
      end
      
      # Checks the given RID against the _domain_object_list_ to see if the RID exists in the Domain.
      # 
      # :call-seq:
      #   check_for_valid_domain_obj( rid ) -> String
      #   
      # Returns the user or group name or _INVALID_DOMAIN_OBJECT_ if the RID cannot be found
      def map_rid( rid )
        if @rid_map.empty?
          @rid_map = self.get_domain_users
          @rid_map.merge!( self.get_domain_groups )
        end
              
        if @rid_map.has_key? rid 
          return @rid_map[rid]
        else 
          return INVALID_DOMAIN_OBJECT  
        end
      end      
      
      # Checks the given RID against the _domain_object_list_ to see if the RID exists in the Domain.
      # 
      # :call-seq:
      #   check_for_valid_domain_obj( rid ) -> String
      #   
      # Returns the rid if valid or _INVALID_DOMAIN_OBJECT_ if the RID cannot be found
      def check_rid( rid )
        if @rid_map.empty?
          @rid_map = self.get_domain_users
          @rid_map.merge!( self.get_domain_groups )
        end
              
        if @rid_map.has_key? rid 
          return rid
        else 
          return INVALID_DOMAIN_OBJECT  
        end
      end        
      
      def command( type, resource = "" )
        values = Array.new unless block_given?
        
       
        
        options = {}
        
        ENV["PASSWD"] = @credentials[:password]
	options[:password] = nil
        command = case type
                  when "\:rpcclient"
                    "rpcclient #{@source} -U '#{@credentials[:username]}' -c \"#{resource}\""

                  when "\:smbcacls"
                    "smbcacls --numeric -U #{@credentials[:username]} //#{@source}/#{@share} \"#{resource}\""
                  when "\:smbclient"
                    "smbclient -U #{@username} #{@credentials[:username]} #{resource}"

                  when "\:nmblookup" 
                    "nmblookup -A #{@source}"
                  when "\:smbcquotas"
                    "smbcquotas -U #{@credentials[:username]} //#{@source}/#{@share} -L"
                  else
                    raise SambaError.new( type ), "Invalid command type #{type.to_s}"
                  end
        
        begin
          PTY.safe_spawn( command, options ) do |line|
            raise SambaError.new( line ), " error occured while executing the command #{command}", caller if
              line.include? "NT_STATUS_CONNECTION_REFUSED"        
          
            if block_given?
              yield line
            else
              values << line
            end
          end
        rescue => error
          raise SambaError.new( error ), caller
        end
        
        options.clear
        
        return values unless block_given?   
      end
    end
  end
end
