# Copyright (C) [2006-2007] Novell, Inc.  All Rights Reserved.

# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# IT MAY NOT BE USED, COPIED, DISTRIBUTED, DISCLOSED, ADAPTED, PERFORMED,
# DISPLAYED, COLLECTED, COMPILED, OR LINKED WITHOUT NOVELL'S PRIOR WRITTEN
# CONSENT.  USE OR EXPLOITATION OF THIS WORK WITHOUT AUTHORIZATION COULD
# SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.

# NOVELL PROVIDES THE WORK "AS IS," WITHOUT ANY EXPRESS OR IMPLIED WARRANTY,
# INCLUDING WITHOUT THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE, AND NON-INFRINGEMENT. NOVELL, THE AUTHORS OF THE WORK,
# AND THE OWNERS OF COPYRIGHT IN THE WORK ARE NOT LIABLE FOR ANY CLAIM, DAMAGES,
# OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT, OR OTHERWISE,
# ARISING FROM, OUT OF, OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER
# DEALINGS IN THE WORK.

# :title: Novell Migration Utility - ntuserls
# ==Description: 
# Module methods for using Samba's smbcacls program.  
# 
module Migration
  module Windows
    module SambaLib
      $:.unshift File.expand_path(File.join(File.dirname(__FILE__), '..'))
#      require 'constants'
      require 'rights/ntfs_object'
      require 'rights/ntfs_rights'
      require 'domain/sid'
      $:.shift
    
      include Migration::Windows
    
      # Uses smbclient to retrieve a listing of the source servers share.  
      # 
      # :call-seq:
      #   get_permissions( object_path ) -> NTFS_object
      #   
      # Returns a NTFS_object containing information about the object
      def get_permissions( object_path, share = nil )        
        ntfs_object = Rights::NTFS_object.new
        ntfs_object.path = object_path
        path = object_path.clone
                    
        unless share.nil?
          original_share = @share
          @share = share
        end
                
        path.sub!( /\\$/, '' )

        self.command( :smbcacls, "#{path}" ).each do |line| 
          case line
          when /^REVISION:[0-9]+$/ 
            ntfs_object.revision = (line.split(':')).last.to_i
          when /^OWNER:S[0-9\-]*$/
            ntfs_object.owner = self.map_rid(
              Domain::SID_to_RID( line.split(':').last ))
          when /^GROUP:S[0-9\-]*$/
            ntfs_object.group = self.map_rid(
              Domain::SID_to_RID( line.split(':').last ))
          when /^ACL:S[0-9\-]*:[0-1]+\/[0-9]+\/0x[0-9a-fA-F]*$/ 
            acl_entry = line.split(':').slice(1..2)
            rid = self.map_rid( Domain::SID_to_RID( acl_entry.first ))
            unless rid == INVALID_DOMAIN_OBJECT
              ntfs_object.add_ace( rid, 
                Rights::NTFS_rights.new( acl_entry.last ))
            end
          end
        end
              
        @share = original_share unless share.nil?
       
        return ntfs_object
      end

      def get_quota( path,ntfs_object )        
        #ntfs_object = Rights::NTFS_object.new
        #ntfs_object.path = object_path
        #path = object_path.clone
        #path.sub!( /\\$/, '' )

        self.command( :smbcquotas, "#{path}" ).each do |line| 
	   if ((line.include?("Quotas are not enabled on this share")) or (line.include?("Failed to open")) or (line.include?("session request to #{@source} failed")))
		return ntfs_object
	   end
		tmp = line.split(":")
		return ntfs_object if tmp.size != 2
		ntfs_quota_obj = Rights::NTFS_quota.new
                tmpuser = tmp[0].split("\\")
		ntfs_quota_obj.name = tmpuser.last.strip
		tmpquota = tmp[1].split("/")
		ntfs_quota_obj.value = tmpquota[2].strip	   
		ntfs_object.add_quotas(ntfs_quota_obj)

	end
	return ntfs_object
   end

    end
  end
end
