# Copyright (C) [2006-2007] Novell, Inc.  All Rights Reserved.

# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# IT MAY NOT BE USED, COPIED, DISTRIBUTED, DISCLOSED, ADAPTED, PERFORMED,
# DISPLAYED, COLLECTED, COMPILED, OR LINKED WITHOUT NOVELL'S PRIOR WRITTEN
# CONSENT.  USE OR EXPLOITATION OF THIS WORK WITHOUT AUTHORIZATION COULD
# SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.

# NOVELL PROVIDES THE WORK "AS IS," WITHOUT ANY EXPRESS OR IMPLIED WARRANTY,
# INCLUDING WITHOUT THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE, AND NON-INFRINGEMENT. NOVELL, THE AUTHORS OF THE WORK,
# AND THE OWNERS OF COPYRIGHT IN THE WORK ARE NOT LIABLE FOR ANY CLAIM, DAMAGES,
# OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT, OR OTHERWISE,
# ARISING FROM, OUT OF, OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER
# DEALINGS IN THE WORK.

# :title: Novell Migration Utility - ntuserls
# ==Description: 
# Module methods for using Samba's smbcacls program.  
# 
module Migration
  module Windows
    module SambaLib   
      # Authenticates against the given server to see if the credentials are valid.  
      # 
      # :call-seq:
      #   test_smbclient -> boolean
      #   
      # Returns true for valid, false for not valid or error
      def test_smbclient
        self.command( :smbclient )
        
        return true
      end    
    
      # Uses smbclient to retrieve a listing of folders and files from the source servers share. 
      # 
      # :call-seq:
      #   get_directory_listing -> array
      #   
      # Returns a sorted array of directory and file listings
      def get_directory_listing
        client_values = Array.new   
	attr_values =Array.new
        current_directory = ""
        needattrs = 0

        self.command( :smbclient, 
          "-c \"recurse; prompt; ls *\" //#{@source}/#{@share}"  ) do |line|
	
	if needattrs == 1
		atrs = 0x0
		dirname = line.split[0].strip
		if dirname == "."
			atributes = line.split[1].strip
			unless atributes.nil?
				atrs |= 0x00000001 if atributes.include? 'R'
				atrs |= 0x00000002 if atributes.include? 'H'
				atrs |= 0x02000000 if atributes.include? 'C'
			end
		end
	attr_values << atrs
	needattrs = 0
	next
	end	
          case line          
          when nil, ""
            next
          #when /^\.[\s]+?[A-Z].[\s]+?[0-9]+?[\s]+?[MTWTFSa-z]{3,3}/ 
          #  next
          #when /^Domain=\[/  
          #  next
          #when /^\.\.[\s]+?[A-Z].[\s]+?[0-9]+?[\s]+?[MTWTFSa-z]{3,3}/  
          #  next
          #when /^[0-9]+?\sblocks\sof\ssize [0-9]+?\.[\s]+?[0-9]+?\sblocks\savailable$/
          #  next
        when /^\\/ 
            client_values << current_directory = line + "\\"
	    needattrs = 1
      		
        else /^[\\\/\:\*\?\"\>\<\|][\s]+?[AHRS\-]./
            #Find "A        0  Wed Aug 30 10:05:22 2006"
            #Removed D for directory mapping.  Not unicode safe
            match = /[AHRS\-]+?[\s]+?[0-9]+?[\s]{2}[MTWTFSa-z]{3}\s[\w]{3}\s+?[0-9]{0,2}\s[0-9]{0,2}:[0-9]{0,2}:[0-9]{0,2}\s[0-9]{4}$/
            matched_file = line.sub( match, '' ).strip!
            unless matched_file.nil?
	   	remstr = line.slice( matched_file.length, line.length).strip!
		atributes = remstr.split[0].strip
		atrs = 0x0
		unless atributes.nil?
			atrs |= 0x00000001 if atributes.include? 'R'
			atrs |= 0x00000002 if atributes.include? 'H'
			atrs |= 0x02000000 if atributes.include? 'C'
		end
		client_values << current_directory + matched_file
		attr_values << atrs

            end
          end
        end       
        
       # client_values.sort!
        return client_values, attr_values
      end 

      # Returns a true/false if the specifed server has the share
      def has_share?( share )
        self.command( :smbclient, "--list=#{@source}" ) do |line|
          if line =~ /(.+)\s+Disk/
            return true if $1.strip.casecmp( share) == 0
          end
        end
        
        return false        
      end   
      
      # Retrieves an array of the shares from the server
      def get_shares  
        shares = []
        self.command( :smbclient, "--list=#{@source}" ) do |line|
          if line =~ /(.+)\s+Disk/
            $1.strip!
            unless $1.include?( 'NETLOGON') or $1.include?('SYSVOL') or $1.include?('Login')
              shares << $1
            end
          end
        end    
        return shares
      end  
    end
  end
end
