# Copyright (C) [2006-2007] Novell, Inc.  All Rights Reserved.

# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# IT MAY NOT BE USED, COPIED, DISTRIBUTED, DISCLOSED, ADAPTED, PERFORMED,
# DISPLAYED, COLLECTED, COMPILED, OR LINKED WITHOUT NOVELL'S PRIOR WRITTEN
# CONSENT.  USE OR EXPLOITATION OF THIS WORK WITHOUT AUTHORIZATION COULD
# SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.

# NOVELL PROVIDES THE WORK "AS IS," WITHOUT ANY EXPRESS OR IMPLIED WARRANTY,
# INCLUDING WITHOUT THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE, AND NON-INFRINGEMENT. NOVELL, THE AUTHORS OF THE WORK,
# AND THE OWNERS OF COPYRIGHT IN THE WORK ARE NOT LIABLE FOR ANY CLAIM, DAMAGES,
# OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT, OR OTHERWISE,
# ARISING FROM, OUT OF, OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER
# DEALINGS IN THE WORK.
require 'yaml'

$:.unshift File.expand_path(File.join(File.dirname(__FILE__), 'windows'))
require 'rights/ace'
require 'rights/ntfs_object'
require 'rights/nss_object'
require 'domain/user_object'
require 'domain/group_object'
$:.shift     

module Migration
  module Arguments
  end
  module Lang
    def Lang.get_string(str, values) 
      eval('"' + str + '"')
    end 
  end
end


module YAML
  # The following addes the specific custom object mappings to YAML
  YAML.add_domain_type( "novell.com,1984", "ntfs_rights_object" ) do |type, val|
    YAML.object_maker( Migration::Windows::Rights::NTFS_object, val )
  end
  YAML.add_domain_type( "novell.com,1984", "ntfs_ace" ) do |type, val|
    Migration::Windows::Rights::Ace.yaml_new( val )
  end
  YAML.add_domain_type( "novell.com,1984", "ntfs_quota" ) do |type, val|
    YAML.object_maker( Migration::Windows::Rights::NTFS_quota, val )
  end
  YAML.add_domain_type( "novell.com,1984", "nss_rights_object" ) do |type, val|
    YAML.object_maker( Migration::Windows::Rights::NSS_object, val )
  end   
  YAML.add_domain_type( "novell.com,1984", "nss_ace" ) do |type, val|
    Migration::Windows::Rights::Ace.yaml_new( val )
  end     
  YAML.add_domain_type( "novell.com,1984", "windows_user" ) do |type, val|
    YAML.object_maker( Migration::Windows::Domain::WindowsUser, val )
  end
  YAML.add_domain_type( "novell.com,1984", "novell_user" ) do |type, val|
    YAML.object_maker( Migration::Windows::Domain::NovellUser, val )
  end  
  YAML.add_domain_type( "novell.com,1984", "windows_group" ) do |type, val|
    YAML.object_maker( Migration::Windows::Domain::WindowsGroup, val )
  end
  YAML.add_domain_type( "novell.com,1984", "novell_group" ) do |type, val|
    YAML.object_maker( Migration::Windows::Domain::NovellGroup, val )
  end	   	      
    
  # Addes a new method to YAML for ease in processing YAML documents
  # 
  # :call-seq:
  #   YAML::load_windows_yaml( stream ) -> array
  #   YAML::load_windows_yaml( stream ) {|val| ... } -> nil
  #     
  def YAML.load_windows_yaml( io )
    document_array = Array.new unless block_given?
        
    YAML::load_documents( io ) do  |doc|
      if block_given?
        yield doc
      else
        document_array << doc
      end
	end
		
	return document_array unless block_given?
  end
  
  def YAML.load_language(file)
    documents = []
    begin
      File.open(file,'r') do |io|
        YAML::load_documents( io ) do |doc|
          documents << doc
        end
      end
      
      # Create arguments lists
      documents.first.each do |args|
        arg_list = nil
        
        id = args.delete :id
        
        if id == :parse_args
          arg_list = args
        else
          arg_list = []
          if args.has_key? :header    
            arg_list << args[:header]
            args.delete :header
          end
        
          args.each do |k,v|
            v.unshift k      
            arg_list << v
          end
        end  
        Migration::Arguments.const_set( id.to_s.upcase, arg_list.freeze )
          
      end
      
      documents.shift
     
      # Create language strings
      documents.first.each do |k,v|
        Migration::Lang.const_set(k,v.freeze)
      end
    rescue => e
      puts e
    end
  end  
end
